<?php

return [
    '🧑🏻‍❤‍💋‍🧑🏼' => 'ambung: wong, wong, kulit putih, kulit putih langsep',
    '🧑🏻‍❤‍💋‍🧑🏽' => 'ambung: wong, wong, kulit putih, kulit kuning',
    '🧑🏻‍❤‍💋‍🧑🏾' => 'ambung: wong, wong, kulit putih, kulit sawo mateng',
    '🧑🏻‍❤‍💋‍🧑🏿' => 'ambung: wong, wong, kulit putih, kulit ireng',
    '🧑🏼‍❤‍💋‍🧑🏻' => 'ambung: wong, wong, kulit putih langsep, kulit putih',
    '🧑🏼‍❤‍💋‍🧑🏽' => 'ambung: wong, wong, kulit putih langsep, kulit kuning',
    '🧑🏼‍❤‍💋‍🧑🏾' => 'ambung: wong, wong, kulit putih langsep, kulit sawo mateng',
    '🧑🏼‍❤‍💋‍🧑🏿' => 'ambung: wong, wong, kulit putih langsep, kulit ireng',
    '🧑🏽‍❤‍💋‍🧑🏻' => 'ambung: wong, wong, kulit kuning, kulit putih',
    '🧑🏽‍❤‍💋‍🧑🏼' => 'ambung: wong, wong, kulit kuning, kulit putih langsep',
    '🧑🏽‍❤‍💋‍🧑🏾' => 'ambung: wong, wong, kulit kuning, kulit sawo mateng',
    '🧑🏽‍❤‍💋‍🧑🏿' => 'ambung: wong, wong, kulit kuning, kulit ireng',
    '🧑🏾‍❤‍💋‍🧑🏻' => 'ambung: wong, wong, kulit sawo mateng, kulit putih',
    '🧑🏾‍❤‍💋‍🧑🏼' => 'ambung: wong, wong, kulit sawo mateng, kulit putih langsep',
    '🧑🏾‍❤‍💋‍🧑🏽' => 'ambung: wong, wong, kulit sawo mateng, kulit kuning',
    '🧑🏾‍❤‍💋‍🧑🏿' => 'ambung: wong, wong, kulit sawo mateng, kulit ireng',
    '🧑🏿‍❤‍💋‍🧑🏻' => 'ambung: wong, wong, kulit ireng, kulit putih',
    '🧑🏿‍❤‍💋‍🧑🏼' => 'ambung: wong, wong, kulit ireng, kulit putih langsep',
    '🧑🏿‍❤‍💋‍🧑🏽' => 'ambung: wong, wong, kulit ireng, kulit kuning',
    '🧑🏿‍❤‍💋‍🧑🏾' => 'ambung: wong, wong, kulit ireng, kulit sawo mateng',
    '👨🏻‍❤‍💋‍👨🏻' => 'ambung: wong lanang, wong lanang, kulit putih',
    '👨🏻‍❤‍💋‍👨🏼' => 'ambung: wong lanang, wong lanang, kulit putih, kulit putih langsep',
    '👨🏻‍❤‍💋‍👨🏽' => 'ambung: wong lanang, wong lanang, kulit putih, kulit kuning',
    '👨🏻‍❤‍💋‍👨🏾' => 'ambung: wong lanang, wong lanang, kulit putih, kulit sawo mateng',
    '👨🏻‍❤‍💋‍👨🏿' => 'ambung: wong lanang, wong lanang, kulit putih, kulit ireng',
    '👨🏼‍❤‍💋‍👨🏻' => 'ambung: wong lanang, wong lanang, kulit putih langsep, kulit putih',
    '👨🏼‍❤‍💋‍👨🏼' => 'ambung: wong lanang, wong lanang, kulit putih langsep',
    '👨🏼‍❤‍💋‍👨🏽' => 'ambung: wong lanang, wong lanang, kulit putih langsep, kulit kuning',
    '👨🏼‍❤‍💋‍👨🏾' => 'ambung: wong lanang, wong lanang, kulit putih langsep, kulit sawo mateng',
    '👨🏼‍❤‍💋‍👨🏿' => 'ambung: wong lanang, wong lanang, kulit putih langsep, kulit ireng',
    '👨🏽‍❤‍💋‍👨🏻' => 'ambung: wong lanang, wong lanang, kulit kuning, kulit putih',
    '👨🏽‍❤‍💋‍👨🏼' => 'ambung: wong lanang, wong lanang, kulit kuning, kulit putih langsep',
    '👨🏽‍❤‍💋‍👨🏽' => 'ambung: wong lanang, wong lanang, kulit kuning',
    '👨🏽‍❤‍💋‍👨🏾' => 'ambung: wong lanang, wong lanang, kulit kuning, kulit sawo mateng',
    '👨🏽‍❤‍💋‍👨🏿' => 'ambung: wong lanang, wong lanang, kulit kuning, kulit ireng',
    '👨🏾‍❤‍💋‍👨🏻' => 'ambung: wong lanang, wong lanang, kulit sawo mateng, kulit putih',
    '👨🏾‍❤‍💋‍👨🏼' => 'ambung: wong lanang, wong lanang, kulit sawo mateng, kulit putih langsep',
    '👨🏾‍❤‍💋‍👨🏽' => 'ambung: wong lanang, wong lanang, kulit sawo mateng, kulit kuning',
    '👨🏾‍❤‍💋‍👨🏾' => 'ambung: wong lanang, wong lanang, kulit sawo mateng',
    '👨🏾‍❤‍💋‍👨🏿' => 'ambung: wong lanang, wong lanang, kulit sawo mateng, kulit ireng',
    '👨🏿‍❤‍💋‍👨🏻' => 'ambung: wong lanang, wong lanang, kulit ireng, kulit putih',
    '👨🏿‍❤‍💋‍👨🏼' => 'ambung: wong lanang, wong lanang, kulit ireng, kulit putih langsep',
    '👨🏿‍❤‍💋‍👨🏽' => 'ambung: wong lanang, wong lanang, kulit ireng, kulit kuning',
    '👨🏿‍❤‍💋‍👨🏾' => 'ambung: wong lanang, wong lanang, kulit ireng, kulit sawo mateng',
    '👨🏿‍❤‍💋‍👨🏿' => 'ambung: wong lanang, wong lanang, kulit ireng',
    '👩🏻‍❤‍💋‍👨🏻' => 'ambung: wong wadon, wong lanang, kulit putih',
    '👩🏻‍❤‍💋‍👨🏼' => 'ambung: wong wadon, wong lanang, kulit putih, kulit putih langsep',
    '👩🏻‍❤‍💋‍👨🏽' => 'ambung: wong wadon, wong lanang, kulit putih, kulit kuning',
    '👩🏻‍❤‍💋‍👨🏾' => 'ambung: wong wadon, wong lanang, kulit putih, kulit sawo mateng',
    '👩🏻‍❤‍💋‍👨🏿' => 'ambung: wong wadon, wong lanang, kulit putih, kulit ireng',
    '👩🏼‍❤‍💋‍👨🏻' => 'ambung: wong wadon, wong lanang, kulit putih langsep, kulit putih',
    '👩🏼‍❤‍💋‍👨🏼' => 'ambung: wong wadon, wong lanang, kulit putih langsep',
    '👩🏼‍❤‍💋‍👨🏽' => 'ambung: wong wadon, wong lanang, kulit putih langsep, kulit kuning',
    '👩🏼‍❤‍💋‍👨🏾' => 'ambung: wong wadon, wong lanang, kulit putih langsep, kulit sawo mateng',
    '👩🏼‍❤‍💋‍👨🏿' => 'ambung: wong wadon, wong lanang, kulit putih langsep, kulit ireng',
    '👩🏽‍❤‍💋‍👨🏻' => 'ambung: wong wadon, wong lanang, kulit kuning, kulit putih',
    '👩🏽‍❤‍💋‍👨🏼' => 'ambung: wong wadon, wong lanang, kulit kuning, kulit putih langsep',
    '👩🏽‍❤‍💋‍👨🏽' => 'ambung: wong wadon, wong lanang, kulit kuning',
    '👩🏽‍❤‍💋‍👨🏾' => 'ambung: wong wadon, wong lanang, kulit kuning, kulit sawo mateng',
    '👩🏽‍❤‍💋‍👨🏿' => 'ambung: wong wadon, wong lanang, kulit kuning, kulit ireng',
    '👩🏾‍❤‍💋‍👨🏻' => 'ambung: wong wadon, wong lanang, kulit sawo mateng, kulit putih',
    '👩🏾‍❤‍💋‍👨🏼' => 'ambung: wong wadon, wong lanang, kulit sawo mateng, kulit putih langsep',
    '👩🏾‍❤‍💋‍👨🏽' => 'ambung: wong wadon, wong lanang, kulit sawo mateng, kulit kuning',
    '👩🏾‍❤‍💋‍👨🏾' => 'ambung: wong wadon, wong lanang, kulit sawo mateng',
    '👩🏾‍❤‍💋‍👨🏿' => 'ambung: wong wadon, wong lanang, kulit sawo mateng, kulit ireng',
    '👩🏿‍❤‍💋‍👨🏻' => 'ambung: wong wadon, wong lanang, kulit ireng, kulit putih',
    '👩🏿‍❤‍💋‍👨🏼' => 'ambung: wong wadon, wong lanang, kulit ireng, kulit putih langsep',
    '👩🏿‍❤‍💋‍👨🏽' => 'ambung: wong wadon, wong lanang, kulit ireng, kulit kuning',
    '👩🏿‍❤‍💋‍👨🏾' => 'ambung: wong wadon, wong lanang, kulit ireng, kulit sawo mateng',
    '👩🏿‍❤‍💋‍👨🏿' => 'ambung: wong wadon, wong lanang, kulit ireng',
    '👩🏻‍❤‍💋‍👩🏻' => 'ambung: wong wadon, wong wadon, kulit putih',
    '👩🏻‍❤‍💋‍👩🏼' => 'ambung: wong wadon, wong wadon, kulit putih, kulit putih langsep',
    '👩🏻‍❤‍💋‍👩🏽' => 'ambung: wong wadon, wong wadon, kulit putih, kulit kuning',
    '👩🏻‍❤‍💋‍👩🏾' => 'ambung: wong wadon, wong wadon, kulit putih, kulit sawo mateng',
    '👩🏻‍❤‍💋‍👩🏿' => 'ambung: wong wadon, wong wadon, kulit putih, kulit ireng',
    '👩🏼‍❤‍💋‍👩🏻' => 'ambung: wong wadon, wong wadon, kulit putih langsep, kulit putih',
    '👩🏼‍❤‍💋‍👩🏼' => 'ambung: wong wadon, wong wadon, kulit putih langsep',
    '👩🏼‍❤‍💋‍👩🏽' => 'ambung: wong wadon, wong wadon, kulit putih langsep, kulit kuning',
    '👩🏼‍❤‍💋‍👩🏾' => 'ambung: wong wadon, wong wadon, kulit putih langsep, kulit sawo mateng',
    '👩🏼‍❤‍💋‍👩🏿' => 'ambung: wong wadon, wong wadon, kulit putih langsep, kulit ireng',
    '👩🏽‍❤‍💋‍👩🏻' => 'ambung: wong wadon, wong wadon, kulit kuning, kulit putih',
    '👩🏽‍❤‍💋‍👩🏼' => 'ambung: wong wadon, wong wadon, kulit kuning, kulit putih langsep',
    '👩🏽‍❤‍💋‍👩🏽' => 'ambung: wong wadon, wong wadon, kulit kuning',
    '👩🏽‍❤‍💋‍👩🏾' => 'ambung: wong wadon, wong wadon, kulit kuning, kulit sawo mateng',
    '👩🏽‍❤‍💋‍👩🏿' => 'ambung: wong wadon, wong wadon, kulit kuning, kulit ireng',
    '👩🏾‍❤‍💋‍👩🏻' => 'ambung: wong wadon, wong wadon, kulit sawo mateng, kulit putih',
    '👩🏾‍❤‍💋‍👩🏼' => 'ambung: wong wadon, wong wadon, kulit sawo mateng, kulit putih langsep',
    '👩🏾‍❤‍💋‍👩🏽' => 'ambung: wong wadon, wong wadon, kulit sawo mateng, kulit kuning',
    '👩🏾‍❤‍💋‍👩🏾' => 'ambung: wong wadon, wong wadon, kulit sawo mateng',
    '👩🏾‍❤‍💋‍👩🏿' => 'ambung: wong wadon, wong wadon, kulit sawo mateng, kulit ireng',
    '👩🏿‍❤‍💋‍👩🏻' => 'ambung: wong wadon, wong wadon, kulit ireng, kulit putih',
    '👩🏿‍❤‍💋‍👩🏼' => 'ambung: wong wadon, wong wadon, kulit ireng, kulit putih langsep',
    '👩🏿‍❤‍💋‍👩🏽' => 'ambung: wong wadon, wong wadon, kulit ireng, kulit kuning',
    '👩🏿‍❤‍💋‍👩🏾' => 'ambung: wong wadon, wong wadon, kulit ireng, kulit sawo mateng',
    '👩🏿‍❤‍💋‍👩🏿' => 'ambung: wong wadon, wong wadon, kulit ireng',
    '🧑🏻‍🫯‍🧑🏼' => 'wong gulat: kulit putih, kulit putih langsep',
    '🧑🏻‍🫯‍🧑🏽' => 'wong gulat: kulit putih, kulit kuning',
    '🧑🏻‍🫯‍🧑🏾' => 'wong gulat: kulit putih, kulit sawo mateng',
    '🧑🏻‍🫯‍🧑🏿' => 'wong gulat: kulit putih, kulit ireng',
    '🧑🏼‍🫯‍🧑🏻' => 'wong gulat: kulit putih langsep, kulit putih',
    '🧑🏼‍🫯‍🧑🏽' => 'wong gulat: kulit putih langsep, kulit kuning',
    '🧑🏼‍🫯‍🧑🏾' => 'wong gulat: kulit putih langsep, kulit sawo mateng',
    '🧑🏼‍🫯‍🧑🏿' => 'wong gulat: kulit putih langsep, kulit ireng',
    '🧑🏽‍🫯‍🧑🏻' => 'wong gulat: kulit kuning, kulit putih',
    '🧑🏽‍🫯‍🧑🏼' => 'wong gulat: kulit kuning, kulit putih langsep',
    '🧑🏽‍🫯‍🧑🏾' => 'wong gulat: kulit kuning, kulit sawo mateng',
    '🧑🏽‍🫯‍🧑🏿' => 'wong gulat: kulit kuning, kulit ireng',
    '🧑🏾‍🫯‍🧑🏻' => 'wong gulat: kulit sawo mateng, kulit putih',
    '🧑🏾‍🫯‍🧑🏼' => 'wong gulat: kulit sawo mateng, kulit putih langsep',
    '🧑🏾‍🫯‍🧑🏽' => 'wong gulat: kulit sawo mateng, kulit kuning',
    '🧑🏾‍🫯‍🧑🏿' => 'wong gulat: kulit sawo mateng, kulit ireng',
    '🧑🏿‍🫯‍🧑🏻' => 'wong gulat: kulit ireng, kulit putih',
    '🧑🏿‍🫯‍🧑🏼' => 'wong gulat: kulit ireng, kulit putih langsep',
    '🧑🏿‍🫯‍🧑🏽' => 'wong gulat: kulit ireng, kulit kuning',
    '🧑🏿‍🫯‍🧑🏾' => 'wong gulat: kulit ireng, kulit sawo mateng',
    '🧑🏻‍❤‍🧑🏼' => 'pasangan lan tandha ati: wong, wong, kulit putih, kulit putih langsep',
    '🧑🏻‍❤‍🧑🏽' => 'pasangan lan tandha ati: wong, wong, kulit putih, kulit kuning',
    '🧑🏻‍❤‍🧑🏾' => 'pasangan lan tandha ati: wong, wong, kulit putih, kulit sawo mateng',
    '🧑🏻‍❤‍🧑🏿' => 'pasangan lan tandha ati: wong, wong, kulit putih, kulit ireng',
    '🧑🏼‍❤‍🧑🏻' => 'pasangan lan tandha ati: wong, wong, kulit putih langsep, kulit putih',
    '🧑🏼‍❤‍🧑🏽' => 'pasangan lan tandha ati: wong, wong, kulit putih langsep, kulit kuning',
    '🧑🏼‍❤‍🧑🏾' => 'pasangan lan tandha ati: wong, wong, kulit putih langsep, kulit sawo mateng',
    '🧑🏼‍❤‍🧑🏿' => 'pasangan lan tandha ati: wong, wong, kulit putih langsep, kulit ireng',
    '🧑🏽‍❤‍🧑🏻' => 'pasangan lan tandha ati: wong, wong, kulit kuning, kulit putih',
    '🧑🏽‍❤‍🧑🏼' => 'pasangan lan tandha ati: wong, wong, kulit kuning, kulit putih langsep',
    '🧑🏽‍❤‍🧑🏾' => 'pasangan lan tandha ati: wong, wong, kulit kuning, kulit sawo mateng',
    '🧑🏽‍❤‍🧑🏿' => 'pasangan lan tandha ati: wong, wong, kulit kuning, kulit ireng',
    '🧑🏾‍❤‍🧑🏻' => 'pasangan lan tandha ati: wong, wong, kulit sawo mateng, kulit putih',
    '🧑🏾‍❤‍🧑🏼' => 'pasangan lan tandha ati: wong, wong, kulit sawo mateng, kulit putih langsep',
    '🧑🏾‍❤‍🧑🏽' => 'pasangan lan tandha ati: wong, wong, kulit sawo mateng, kulit kuning',
    '🧑🏾‍❤‍🧑🏿' => 'pasangan lan tandha ati: wong, wong, kulit sawo mateng, kulit ireng',
    '🧑🏿‍❤‍🧑🏻' => 'pasangan lan tandha ati: wong, wong, kulit ireng, kulit putih',
    '🧑🏿‍❤‍🧑🏼' => 'pasangan lan tandha ati: wong, wong, kulit ireng, kulit putih langsep',
    '🧑🏿‍❤‍🧑🏽' => 'pasangan lan tandha ati: wong, wong, kulit ireng, kulit kuning',
    '🧑🏿‍❤‍🧑🏾' => 'pasangan lan tandha ati: wong, wong, kulit ireng, kulit sawo mateng',
    '🧑🏻‍🐰‍🧑🏼' => 'wong nganggo kuping terwelu: kulit putih, kulit putih langsep',
    '🧑🏻‍🐰‍🧑🏽' => 'wong nganggo kuping terwelu: kulit putih, kulit kuning',
    '🧑🏻‍🐰‍🧑🏾' => 'wong nganggo kuping terwelu: kulit putih, kulit sawo mateng',
    '🧑🏻‍🐰‍🧑🏿' => 'wong nganggo kuping terwelu: kulit putih, kulit ireng',
    '🧑🏼‍🐰‍🧑🏻' => 'wong nganggo kuping terwelu: kulit putih langsep, kulit putih',
    '🧑🏼‍🐰‍🧑🏽' => 'wong nganggo kuping terwelu: kulit putih langsep, kulit kuning',
    '🧑🏼‍🐰‍🧑🏾' => 'wong nganggo kuping terwelu: kulit putih langsep, kulit sawo mateng',
    '🧑🏼‍🐰‍🧑🏿' => 'wong nganggo kuping terwelu: kulit putih langsep, kulit ireng',
    '🧑🏽‍🐰‍🧑🏻' => 'wong nganggo kuping terwelu: kulit kuning, kulit putih',
    '🧑🏽‍🐰‍🧑🏼' => 'wong nganggo kuping terwelu: kulit kuning, kulit putih langsep',
    '🧑🏽‍🐰‍🧑🏾' => 'wong nganggo kuping terwelu: kulit kuning, kulit sawo mateng',
    '🧑🏽‍🐰‍🧑🏿' => 'wong nganggo kuping terwelu: kulit kuning, kulit ireng',
    '🧑🏾‍🐰‍🧑🏻' => 'wong nganggo kuping terwelu: kulit sawo mateng, kulit putih',
    '🧑🏾‍🐰‍🧑🏼' => 'wong nganggo kuping terwelu: kulit sawo mateng, kulit putih langsep',
    '🧑🏾‍🐰‍🧑🏽' => 'wong nganggo kuping terwelu: kulit sawo mateng, kulit kuning',
    '🧑🏾‍🐰‍🧑🏿' => 'wong nganggo kuping terwelu: kulit sawo mateng, kulit ireng',
    '🧑🏿‍🐰‍🧑🏻' => 'wong nganggo kuping terwelu: kulit ireng, kulit putih',
    '🧑🏿‍🐰‍🧑🏼' => 'wong nganggo kuping terwelu: kulit ireng, kulit putih langsep',
    '🧑🏿‍🐰‍🧑🏽' => 'wong nganggo kuping terwelu: kulit ireng, kulit kuning',
    '🧑🏿‍🐰‍🧑🏾' => 'wong nganggo kuping terwelu: kulit ireng, kulit sawo mateng',
    '👨🏻‍🫯‍👨🏼' => 'wong lanang gulat: kulit putih, kulit putih langsep',
    '👨🏻‍🫯‍👨🏽' => 'wong lanang gulat: kulit putih, kulit kuning',
    '👨🏻‍🫯‍👨🏾' => 'wong lanang gulat: kulit putih, kulit sawo mateng',
    '👨🏻‍🫯‍👨🏿' => 'wong lanang gulat: kulit putih, kulit ireng',
    '👨🏼‍🫯‍👨🏻' => 'wong lanang gulat: kulit putih langsep, kulit putih',
    '👨🏼‍🫯‍👨🏽' => 'wong lanang gulat: kulit putih langsep, kulit kuning',
    '👨🏼‍🫯‍👨🏾' => 'wong lanang gulat: kulit putih langsep, kulit sawo mateng',
    '👨🏼‍🫯‍👨🏿' => 'wong lanang gulat: kulit putih langsep, kulit ireng',
    '👨🏽‍🫯‍👨🏻' => 'wong lanang gulat: kulit kuning, kulit putih',
    '👨🏽‍🫯‍👨🏼' => 'wong lanang gulat: kulit kuning, kulit putih langsep',
    '👨🏽‍🫯‍👨🏾' => 'wong lanang gulat: kulit kuning, kulit sawo mateng',
    '👨🏽‍🫯‍👨🏿' => 'wong lanang gulat: kulit kuning, kulit ireng',
    '👨🏾‍🫯‍👨🏻' => 'wong lanang gulat: kulit sawo mateng, kulit putih',
    '👨🏾‍🫯‍👨🏼' => 'wong lanang gulat: kulit sawo mateng, kulit putih langsep',
    '👨🏾‍🫯‍👨🏽' => 'wong lanang gulat: kulit sawo mateng, kulit kuning',
    '👨🏾‍🫯‍👨🏿' => 'wong lanang gulat: kulit sawo mateng, kulit ireng',
    '👨🏿‍🫯‍👨🏻' => 'wong lanang gulat: kulit ireng, kulit putih',
    '👨🏿‍🫯‍👨🏼' => 'wong lanang gulat: kulit ireng, kulit putih langsep',
    '👨🏿‍🫯‍👨🏽' => 'wong lanang gulat: kulit ireng, kulit kuning',
    '👨🏿‍🫯‍👨🏾' => 'wong lanang gulat: kulit ireng, kulit sawo mateng',
    '👨🏻‍❤‍👨🏻' => 'pasangan lan tandha ati: wong lanang, wong lanang, kulit putih',
    '👨🏻‍❤‍👨🏼' => 'pasangan lan tandha ati: wong lanang, wong lanang, kulit putih, kulit putih langsep',
    '👨🏻‍❤‍👨🏽' => 'pasangan lan tandha ati: wong lanang, wong lanang, kulit putih, kulit kuning',
    '👨🏻‍❤‍👨🏾' => 'pasangan lan tandha ati: wong lanang, wong lanang, kulit putih, kulit sawo mateng',
    '👨🏻‍❤‍👨🏿' => 'pasangan lan tandha ati: wong lanang, wong lanang, kulit putih, kulit ireng',
    '👨🏼‍❤‍👨🏻' => 'pasangan lan tandha ati: wong lanang, wong lanang, kulit putih langsep, kulit putih',
    '👨🏼‍❤‍👨🏼' => 'pasangan lan tandha ati: wong lanang, wong lanang, kulit putih langsep',
    '👨🏼‍❤‍👨🏽' => 'pasangan lan tandha ati: wong lanang, wong lanang, kulit putih langsep, kulit kuning',
    '👨🏼‍❤‍👨🏾' => 'pasangan lan tandha ati: wong lanang, wong lanang, kulit putih langsep, kulit sawo mateng',
    '👨🏼‍❤‍👨🏿' => 'pasangan lan tandha ati: wong lanang, wong lanang, kulit putih langsep, kulit ireng',
    '👨🏽‍❤‍👨🏻' => 'pasangan lan tandha ati: wong lanang, wong lanang, kulit kuning, kulit putih',
    '👨🏽‍❤‍👨🏼' => 'pasangan lan tandha ati: wong lanang, wong lanang, kulit kuning, kulit putih langsep',
    '👨🏽‍❤‍👨🏽' => 'pasangan lan tandha ati: wong lanang, wong lanang, kulit kuning',
    '👨🏽‍❤‍👨🏾' => 'pasangan lan tandha ati: wong lanang, wong lanang, kulit kuning, kulit sawo mateng',
    '👨🏽‍❤‍👨🏿' => 'pasangan lan tandha ati: wong lanang, wong lanang, kulit kuning, kulit ireng',
    '👨🏾‍❤‍👨🏻' => 'pasangan lan tandha ati: wong lanang, wong lanang, kulit sawo mateng, kulit putih',
    '👨🏾‍❤‍👨🏼' => 'pasangan lan tandha ati: wong lanang, wong lanang, kulit sawo mateng, kulit putih langsep',
    '👨🏾‍❤‍👨🏽' => 'pasangan lan tandha ati: wong lanang, wong lanang, kulit sawo mateng, kulit kuning',
    '👨🏾‍❤‍👨🏾' => 'pasangan lan tandha ati: wong lanang, wong lanang, kulit sawo mateng',
    '👨🏾‍❤‍👨🏿' => 'pasangan lan tandha ati: wong lanang, wong lanang, kulit sawo mateng, kulit ireng',
    '👨🏿‍❤‍👨🏻' => 'pasangan lan tandha ati: wong lanang, wong lanang, kulit ireng, kulit putih',
    '👨🏿‍❤‍👨🏼' => 'pasangan lan tandha ati: wong lanang, wong lanang, kulit ireng, kulit putih langsep',
    '👨🏿‍❤‍👨🏽' => 'pasangan lan tandha ati: wong lanang, wong lanang, kulit ireng, kulit kuning',
    '👨🏿‍❤‍👨🏾' => 'pasangan lan tandha ati: wong lanang, wong lanang, kulit ireng, kulit sawo mateng',
    '👨🏿‍❤‍👨🏿' => 'pasangan lan tandha ati: wong lanang, wong lanang, kulit ireng',
    '👨🏻‍🐰‍👨🏼' => 'wong lanang nganggo kuping terwelu: kulit putih, kulit putih langsep',
    '👨🏻‍🐰‍👨🏽' => 'wong lanang nganggo kuping terwelu: kulit putih, kulit kuning',
    '👨🏻‍🐰‍👨🏾' => 'wong lanang nganggo kuping terwelu: kulit putih, kulit sawo mateng',
    '👨🏻‍🐰‍👨🏿' => 'wong lanang nganggo kuping terwelu: kulit putih, kulit ireng',
    '👨🏼‍🐰‍👨🏻' => 'wong lanang nganggo kuping terwelu: kulit putih langsep, kulit putih',
    '👨🏼‍🐰‍👨🏽' => 'wong lanang nganggo kuping terwelu: kulit putih langsep, kulit kuning',
    '👨🏼‍🐰‍👨🏾' => 'wong lanang nganggo kuping terwelu: kulit putih langsep, kulit sawo mateng',
    '👨🏼‍🐰‍👨🏿' => 'wong lanang nganggo kuping terwelu: kulit putih langsep, kulit ireng',
    '👨🏽‍🐰‍👨🏻' => 'wong lanang nganggo kuping terwelu: kulit kuning, kulit putih',
    '👨🏽‍🐰‍👨🏼' => 'wong lanang nganggo kuping terwelu: kulit kuning, kulit putih langsep',
    '👨🏽‍🐰‍👨🏾' => 'wong lanang nganggo kuping terwelu: kulit kuning, kulit sawo mateng',
    '👨🏽‍🐰‍👨🏿' => 'wong lanang nganggo kuping terwelu: kulit kuning, kulit ireng',
    '👨🏾‍🐰‍👨🏻' => 'wong lanang nganggo kuping terwelu: kulit sawo mateng, kulit putih',
    '👨🏾‍🐰‍👨🏼' => 'wong lanang nganggo kuping terwelu: kulit sawo mateng, kulit putih langsep',
    '👨🏾‍🐰‍👨🏽' => 'wong lanang nganggo kuping terwelu: kulit sawo mateng, kulit kuning',
    '👨🏾‍🐰‍👨🏿' => 'wong lanang nganggo kuping terwelu: kulit sawo mateng, kulit ireng',
    '👨🏿‍🐰‍👨🏻' => 'wong lanang nganggo kuping terwelu: kulit ireng, kulit putih',
    '👨🏿‍🐰‍👨🏼' => 'wong lanang nganggo kuping terwelu: kulit ireng, kulit putih langsep',
    '👨🏿‍🐰‍👨🏽' => 'wong lanang nganggo kuping terwelu: kulit ireng, kulit kuning',
    '👨🏿‍🐰‍👨🏾' => 'wong lanang nganggo kuping terwelu: kulit ireng, kulit sawo mateng',
    '👩🏻‍🫯‍👩🏼' => 'wong wadon gulat: kulit putih, kulit putih langsep',
    '👩🏻‍🫯‍👩🏽' => 'wong wadon gulat: kulit putih, kulit kuning',
    '👩🏻‍🫯‍👩🏾' => 'wong wadon gulat: kulit putih, kulit sawo mateng',
    '👩🏻‍🫯‍👩🏿' => 'wong wadon gulat: kulit putih, kulit ireng',
    '👩🏼‍🫯‍👩🏻' => 'wong wadon gulat: kulit putih langsep, kulit putih',
    '👩🏼‍🫯‍👩🏽' => 'wong wadon gulat: kulit putih langsep, kulit kuning',
    '👩🏼‍🫯‍👩🏾' => 'wong wadon gulat: kulit putih langsep, kulit sawo mateng',
    '👩🏼‍🫯‍👩🏿' => 'wong wadon gulat: kulit putih langsep, kulit ireng',
    '👩🏽‍🫯‍👩🏻' => 'wong wadon gulat: kulit kuning, kulit putih',
    '👩🏽‍🫯‍👩🏼' => 'wong wadon gulat: kulit kuning, kulit putih langsep',
    '👩🏽‍🫯‍👩🏾' => 'wong wadon gulat: kulit kuning, kulit sawo mateng',
    '👩🏽‍🫯‍👩🏿' => 'wong wadon gulat: kulit kuning, kulit ireng',
    '👩🏾‍🫯‍👩🏻' => 'wong wadon gulat: kulit sawo mateng, kulit putih',
    '👩🏾‍🫯‍👩🏼' => 'wong wadon gulat: kulit sawo mateng, kulit putih langsep',
    '👩🏾‍🫯‍👩🏽' => 'wong wadon gulat: kulit sawo mateng, kulit kuning',
    '👩🏾‍🫯‍👩🏿' => 'wong wadon gulat: kulit sawo mateng, kulit ireng',
    '👩🏿‍🫯‍👩🏻' => 'wong wadon gulat: kulit ireng, kulit putih',
    '👩🏿‍🫯‍👩🏼' => 'wong wadon gulat: kulit ireng, kulit putih langsep',
    '👩🏿‍🫯‍👩🏽' => 'wong wadon gulat: kulit ireng, kulit kuning',
    '👩🏿‍🫯‍👩🏾' => 'wong wadon gulat: kulit ireng, kulit sawo mateng',
    '👩🏻‍❤‍👨🏻' => 'pasangan lan tandha ati: wong wadon, wong lanang, kulit putih',
    '👩🏻‍❤‍👨🏼' => 'pasangan lan tandha ati: wong wadon, wong lanang, kulit putih, kulit putih langsep',
    '👩🏻‍❤‍👨🏽' => 'pasangan lan tandha ati: wong wadon, wong lanang, kulit putih, kulit kuning',
    '👩🏻‍❤‍👨🏾' => 'pasangan lan tandha ati: wong wadon, wong lanang, kulit putih, kulit sawo mateng',
    '👩🏻‍❤‍👨🏿' => 'pasangan lan tandha ati: wong wadon, wong lanang, kulit putih, kulit ireng',
    '👩🏼‍❤‍👨🏻' => 'pasangan lan tandha ati: wong wadon, wong lanang, kulit putih langsep, kulit putih',
    '👩🏼‍❤‍👨🏼' => 'pasangan lan tandha ati: wong wadon, wong lanang, kulit putih langsep',
    '👩🏼‍❤‍👨🏽' => 'pasangan lan tandha ati: wong wadon, wong lanang, kulit putih langsep, kulit kuning',
    '👩🏼‍❤‍👨🏾' => 'pasangan lan tandha ati: wong wadon, wong lanang, kulit putih langsep, kulit sawo mateng',
    '👩🏼‍❤‍👨🏿' => 'pasangan lan tandha ati: wong wadon, wong lanang, kulit putih langsep, kulit ireng',
    '👩🏽‍❤‍👨🏻' => 'pasangan lan tandha ati: wong wadon, wong lanang, kulit kuning, kulit putih',
    '👩🏽‍❤‍👨🏼' => 'pasangan lan tandha ati: wong wadon, wong lanang, kulit kuning, kulit putih langsep',
    '👩🏽‍❤‍👨🏽' => 'pasangan lan tandha ati: wong wadon, wong lanang, kulit kuning',
    '👩🏽‍❤‍👨🏾' => 'pasangan lan tandha ati: wong wadon, wong lanang, kulit kuning, kulit sawo mateng',
    '👩🏽‍❤‍👨🏿' => 'pasangan lan tandha ati: wong wadon, wong lanang, kulit kuning, kulit ireng',
    '👩🏾‍❤‍👨🏻' => 'pasangan lan tandha ati: wong wadon, wong lanang, kulit sawo mateng, kulit putih',
    '👩🏾‍❤‍👨🏼' => 'pasangan lan tandha ati: wong wadon, wong lanang, kulit sawo mateng, kulit putih langsep',
    '👩🏾‍❤‍👨🏽' => 'pasangan lan tandha ati: wong wadon, wong lanang, kulit sawo mateng, kulit kuning',
    '👩🏾‍❤‍👨🏾' => 'pasangan lan tandha ati: wong wadon, wong lanang, kulit sawo mateng',
    '👩🏾‍❤‍👨🏿' => 'pasangan lan tandha ati: wong wadon, wong lanang, kulit sawo mateng, kulit ireng',
    '👩🏿‍❤‍👨🏻' => 'pasangan lan tandha ati: wong wadon, wong lanang, kulit ireng, kulit putih',
    '👩🏿‍❤‍👨🏼' => 'pasangan lan tandha ati: wong wadon, wong lanang, kulit ireng, kulit putih langsep',
    '👩🏿‍❤‍👨🏽' => 'pasangan lan tandha ati: wong wadon, wong lanang, kulit ireng, kulit kuning',
    '👩🏿‍❤‍👨🏾' => 'pasangan lan tandha ati: wong wadon, wong lanang, kulit ireng, kulit sawo mateng',
    '👩🏿‍❤‍👨🏿' => 'pasangan lan tandha ati: wong wadon, wong lanang, kulit ireng',
    '👩🏻‍❤‍👩🏻' => 'pasangan lan tandha ati: wong wadon, wong wadon, kulit putih',
    '👩🏻‍❤‍👩🏼' => 'pasangan lan tandha ati: wong wadon, wong wadon, kulit putih, kulit putih langsep',
    '👩🏻‍❤‍👩🏽' => 'pasangan lan tandha ati: wong wadon, wong wadon, kulit putih, kulit kuning',
    '👩🏻‍❤‍👩🏾' => 'pasangan lan tandha ati: wong wadon, wong wadon, kulit putih, kulit sawo mateng',
    '👩🏻‍❤‍👩🏿' => 'pasangan lan tandha ati: wong wadon, wong wadon, kulit putih, kulit ireng',
    '👩🏼‍❤‍👩🏻' => 'pasangan lan tandha ati: wong wadon, wong wadon, kulit putih langsep, kulit putih',
    '👩🏼‍❤‍👩🏼' => 'pasangan lan tandha ati: wong wadon, wong wadon, kulit putih langsep',
    '👩🏼‍❤‍👩🏽' => 'pasangan lan tandha ati: wong wadon, wong wadon, kulit putih langsep, kulit kuning',
    '👩🏼‍❤‍👩🏾' => 'pasangan lan tandha ati: wong wadon, wong wadon, kulit putih langsep, kulit sawo mateng',
    '👩🏼‍❤‍👩🏿' => 'pasangan lan tandha ati: wong wadon, wong wadon, kulit putih langsep, kulit ireng',
    '👩🏽‍❤‍👩🏻' => 'pasangan lan tandha ati: wong wadon, wong wadon, kulit kuning, kulit putih',
    '👩🏽‍❤‍👩🏼' => 'pasangan lan tandha ati: wong wadon, wong wadon, kulit kuning, kulit putih langsep',
    '👩🏽‍❤‍👩🏽' => 'pasangan lan tandha ati: wong wadon, wong wadon, kulit kuning',
    '👩🏽‍❤‍👩🏾' => 'pasangan lan tandha ati: wong wadon, wong wadon, kulit kuning, kulit sawo mateng',
    '👩🏽‍❤‍👩🏿' => 'pasangan lan tandha ati: wong wadon, wong wadon, kulit kuning, kulit ireng',
    '👩🏾‍❤‍👩🏻' => 'pasangan lan tandha ati: wong wadon, wong wadon, kulit sawo mateng, kulit putih',
    '👩🏾‍❤‍👩🏼' => 'pasangan lan tandha ati: wong wadon, wong wadon, kulit sawo mateng, kulit putih langsep',
    '👩🏾‍❤‍👩🏽' => 'pasangan lan tandha ati: wong wadon, wong wadon, kulit sawo mateng, kulit kuning',
    '👩🏾‍❤‍👩🏾' => 'pasangan lan tandha ati: wong wadon, wong wadon, kulit sawo mateng',
    '👩🏾‍❤‍👩🏿' => 'pasangan lan tandha ati: wong wadon, wong wadon, kulit sawo mateng, kulit ireng',
    '👩🏿‍❤‍👩🏻' => 'pasangan lan tandha ati: wong wadon, wong wadon, kulit ireng, kulit putih',
    '👩🏿‍❤‍👩🏼' => 'pasangan lan tandha ati: wong wadon, wong wadon, kulit ireng, kulit putih langsep',
    '👩🏿‍❤‍👩🏽' => 'pasangan lan tandha ati: wong wadon, wong wadon, kulit ireng, kulit kuning',
    '👩🏿‍❤‍👩🏾' => 'pasangan lan tandha ati: wong wadon, wong wadon, kulit ireng, kulit sawo mateng',
    '👩🏿‍❤‍👩🏿' => 'pasangan lan tandha ati: wong wadon, wong wadon, kulit ireng',
    '👩🏻‍🐰‍👩🏼' => 'wong wadon nganggo kuping terwelu: kulit putih, kulit putih langsep',
    '👩🏻‍🐰‍👩🏽' => 'wong wadon nganggo kuping terwelu: kulit putih, kulit kuning',
    '👩🏻‍🐰‍👩🏾' => 'wong wadon nganggo kuping terwelu: kulit putih, kulit sawo mateng',
    '👩🏻‍🐰‍👩🏿' => 'wong wadon nganggo kuping terwelu: kulit putih, kulit ireng',
    '👩🏼‍🐰‍👩🏻' => 'wong wadon nganggo kuping terwelu: kulit putih langsep, kulit putih',
    '👩🏼‍🐰‍👩🏽' => 'wong wadon nganggo kuping terwelu: kulit putih langsep, kulit kuning',
    '👩🏼‍🐰‍👩🏾' => 'wong wadon nganggo kuping terwelu: kulit putih langsep, kulit sawo mateng',
    '👩🏼‍🐰‍👩🏿' => 'wong wadon nganggo kuping terwelu: kulit putih langsep, kulit ireng',
    '👩🏽‍🐰‍👩🏻' => 'wong wadon nganggo kuping terwelu: kulit kuning, kulit putih',
    '👩🏽‍🐰‍👩🏼' => 'wong wadon nganggo kuping terwelu: kulit kuning, kulit putih langsep',
    '👩🏽‍🐰‍👩🏾' => 'wong wadon nganggo kuping terwelu: kulit kuning, kulit sawo mateng',
    '👩🏽‍🐰‍👩🏿' => 'wong wadon nganggo kuping terwelu: kulit kuning, kulit ireng',
    '👩🏾‍🐰‍👩🏻' => 'wong wadon nganggo kuping terwelu: kulit sawo mateng, kulit putih',
    '👩🏾‍🐰‍👩🏼' => 'wong wadon nganggo kuping terwelu: kulit sawo mateng, kulit putih langsep',
    '👩🏾‍🐰‍👩🏽' => 'wong wadon nganggo kuping terwelu: kulit sawo mateng, kulit kuning',
    '👩🏾‍🐰‍👩🏿' => 'wong wadon nganggo kuping terwelu: kulit sawo mateng, kulit ireng',
    '👩🏿‍🐰‍👩🏻' => 'wong wadon nganggo kuping terwelu: kulit ireng, kulit putih',
    '👩🏿‍🐰‍👩🏼' => 'wong wadon nganggo kuping terwelu: kulit ireng, kulit putih langsep',
    '👩🏿‍🐰‍👩🏽' => 'wong wadon nganggo kuping terwelu: kulit ireng, kulit kuning',
    '👩🏿‍🐰‍👩🏾' => 'wong wadon nganggo kuping terwelu: kulit ireng, kulit sawo mateng',
    '🧑🏻‍🤝‍🧑🏻' => 'wong gandhengan tangan: kulit putih',
    '🧑🏻‍🤝‍🧑🏼' => 'wong gandhengan tangan: kulit putih, kulit putih langsep',
    '🧑🏻‍🤝‍🧑🏽' => 'wong gandhengan tangan: kulit putih, kulit kuning',
    '🧑🏻‍🤝‍🧑🏾' => 'wong gandhengan tangan: kulit putih, kulit sawo mateng',
    '🧑🏻‍🤝‍🧑🏿' => 'wong gandhengan tangan: kulit putih, kulit ireng',
    '🧑🏼‍🤝‍🧑🏻' => 'wong gandhengan tangan: kulit putih langsep, kulit putih',
    '🧑🏼‍🤝‍🧑🏼' => 'wong gandhengan tangan: kulit putih langsep',
    '🧑🏼‍🤝‍🧑🏽' => 'wong gandhengan tangan: kulit putih langsep, kulit kuning',
    '🧑🏼‍🤝‍🧑🏾' => 'wong gandhengan tangan: kulit putih langsep, kulit sawo mateng',
    '🧑🏼‍🤝‍🧑🏿' => 'wong gandhengan tangan: kulit putih langsep, kulit ireng',
    '🧑🏽‍🤝‍🧑🏻' => 'wong gandhengan tangan: kulit kuning, kulit putih',
    '🧑🏽‍🤝‍🧑🏼' => 'wong gandhengan tangan: kulit kuning, kulit putih langsep',
    '🧑🏽‍🤝‍🧑🏽' => 'wong gandhengan tangan: kulit kuning',
    '🧑🏽‍🤝‍🧑🏾' => 'wong gandhengan tangan: kulit kuning, kulit sawo mateng',
    '🧑🏽‍🤝‍🧑🏿' => 'wong gandhengan tangan: kulit kuning, kulit ireng',
    '🧑🏾‍🤝‍🧑🏻' => 'wong gandhengan tangan: kulit sawo mateng, kulit putih',
    '🧑🏾‍🤝‍🧑🏼' => 'wong gandhengan tangan: kulit sawo mateng, kulit putih langsep',
    '🧑🏾‍🤝‍🧑🏽' => 'wong gandhengan tangan: kulit sawo mateng, kulit kuning',
    '🧑🏾‍🤝‍🧑🏾' => 'wong gandhengan tangan: kulit sawo mateng',
    '🧑🏾‍🤝‍🧑🏿' => 'wong gandhengan tangan: kulit sawo mateng, kulit ireng',
    '🧑🏿‍🤝‍🧑🏻' => 'wong gandhengan tangan: kulit ireng, kulit putih',
    '🧑🏿‍🤝‍🧑🏼' => 'wong gandhengan tangan: kulit ireng, kulit putih langsep',
    '🧑🏿‍🤝‍🧑🏽' => 'wong gandhengan tangan: kulit ireng, kulit kuning',
    '🧑🏿‍🤝‍🧑🏾' => 'wong gandhengan tangan: kulit ireng, kulit sawo mateng',
    '🧑🏿‍🤝‍🧑🏿' => 'wong gandhengan tangan: kulit ireng',
    '👩🏻‍🤝‍👩🏼' => 'wong wadon loro gandhengan tangan: kulit putih, kulit putih langsep',
    '👩🏻‍🤝‍👩🏽' => 'wong wadon loro gandhengan tangan: kulit putih, kulit kuning',
    '👩🏻‍🤝‍👩🏾' => 'wong wadon loro gandhengan tangan: kulit putih, kulit sawo mateng',
    '👩🏻‍🤝‍👩🏿' => 'wong wadon loro gandhengan tangan: kulit putih, kulit ireng',
    '👩🏼‍🤝‍👩🏻' => 'wong wadon loro gandhengan tangan: kulit putih langsep, kulit putih',
    '👩🏼‍🤝‍👩🏽' => 'wong wadon loro gandhengan tangan: kulit putih langsep, kulit kuning',
    '👩🏼‍🤝‍👩🏾' => 'wong wadon loro gandhengan tangan: kulit putih langsep, kulit sawo mateng',
    '👩🏼‍🤝‍👩🏿' => 'wong wadon loro gandhengan tangan: kulit putih langsep, kulit ireng',
    '👩🏽‍🤝‍👩🏻' => 'wong wadon loro gandhengan tangan: kulit kuning, kulit putih',
    '👩🏽‍🤝‍👩🏼' => 'wong wadon loro gandhengan tangan: kulit kuning, kulit putih langsep',
    '👩🏽‍🤝‍👩🏾' => 'wong wadon loro gandhengan tangan: kulit kuning, kulit sawo mateng',
    '👩🏽‍🤝‍👩🏿' => 'wong wadon loro gandhengan tangan: kulit kuning, kulit ireng',
    '👩🏾‍🤝‍👩🏻' => 'wong wadon loro gandhengan tangan: kulit sawo mateng, kulit putih',
    '👩🏾‍🤝‍👩🏼' => 'wong wadon loro gandhengan tangan: kulit sawo mateng, kulit putih langsep',
    '👩🏾‍🤝‍👩🏽' => 'wong wadon loro gandhengan tangan: kulit sawo mateng, kulit kuning',
    '👩🏾‍🤝‍👩🏿' => 'wong wadon loro gandhengan tangan: kulit sawo mateng, kulit ireng',
    '👩🏿‍🤝‍👩🏻' => 'wong wadon loro gandhengan tangan: kulit ireng, kulit putih',
    '👩🏿‍🤝‍👩🏼' => 'wong wadon loro gandhengan tangan: kulit ireng, kulit putih langsep',
    '👩🏿‍🤝‍👩🏽' => 'wong wadon loro gandhengan tangan: kulit ireng, kulit kuning',
    '👩🏿‍🤝‍👩🏾' => 'wong wadon loro gandhengan tangan: kulit ireng, kulit sawo mateng',
    '👩🏻‍🤝‍👨🏼' => 'wong lanang lan wadon gandhengan: kulit putih, kulit putih langsep',
    '👩🏻‍🤝‍👨🏽' => 'wong lanang lan wadon gandhengan: kulit putih, kulit kuning',
    '👩🏻‍🤝‍👨🏾' => 'wong lanang lan wadon gandhengan: kulit putih, kulit sawo mateng',
    '👩🏻‍🤝‍👨🏿' => 'wong lanang lan wadon gandhengan: kulit putih, kulit ireng',
    '👩🏼‍🤝‍👨🏻' => 'wong lanang lan wadon gandhengan: kulit putih langsep, kulit putih',
    '👩🏼‍🤝‍👨🏽' => 'wong lanang lan wadon gandhengan: kulit putih langsep, kulit kuning',
    '👩🏼‍🤝‍👨🏾' => 'wong lanang lan wadon gandhengan: kulit putih langsep, kulit sawo mateng',
    '👩🏼‍🤝‍👨🏿' => 'wong lanang lan wadon gandhengan: kulit putih langsep, kulit ireng',
    '👩🏽‍🤝‍👨🏻' => 'wong lanang lan wadon gandhengan: kulit kuning, kulit putih',
    '👩🏽‍🤝‍👨🏼' => 'wong lanang lan wadon gandhengan: kulit kuning, kulit putih langsep',
    '👩🏽‍🤝‍👨🏾' => 'wong lanang lan wadon gandhengan: kulit kuning, kulit sawo mateng',
    '👩🏽‍🤝‍👨🏿' => 'wong lanang lan wadon gandhengan: kulit kuning, kulit ireng',
    '👩🏾‍🤝‍👨🏻' => 'wong lanang lan wadon gandhengan: kulit sawo mateng, kulit putih',
    '👩🏾‍🤝‍👨🏼' => 'wong lanang lan wadon gandhengan: kulit sawo mateng, kulit putih langsep',
    '👩🏾‍🤝‍👨🏽' => 'wong lanang lan wadon gandhengan: kulit sawo mateng, kulit kuning',
    '👩🏾‍🤝‍👨🏿' => 'wong lanang lan wadon gandhengan: kulit sawo mateng, kulit ireng',
    '👩🏿‍🤝‍👨🏻' => 'wong lanang lan wadon gandhengan: kulit ireng, kulit putih',
    '👩🏿‍🤝‍👨🏼' => 'wong lanang lan wadon gandhengan: kulit ireng, kulit putih langsep',
    '👩🏿‍🤝‍👨🏽' => 'wong lanang lan wadon gandhengan: kulit ireng, kulit kuning',
    '👩🏿‍🤝‍👨🏾' => 'wong lanang lan wadon gandhengan: kulit ireng, kulit sawo mateng',
    '👨🏻‍🤝‍👨🏼' => 'wong lanang loro gandhengan tangan: kulit putih, kulit putih langsep',
    '👨🏻‍🤝‍👨🏽' => 'wong lanang loro gandhengan tangan: kulit putih, kulit kuning',
    '👨🏻‍🤝‍👨🏾' => 'wong lanang loro gandhengan tangan: kulit putih, kulit sawo mateng',
    '👨🏻‍🤝‍👨🏿' => 'wong lanang loro gandhengan tangan: kulit putih, kulit ireng',
    '👨🏼‍🤝‍👨🏻' => 'wong lanang loro gandhengan tangan: kulit putih langsep, kulit putih',
    '👨🏼‍🤝‍👨🏽' => 'wong lanang loro gandhengan tangan: kulit putih langsep, kulit kuning',
    '👨🏼‍🤝‍👨🏾' => 'wong lanang loro gandhengan tangan: kulit putih langsep, kulit sawo mateng',
    '👨🏼‍🤝‍👨🏿' => 'wong lanang loro gandhengan tangan: kulit putih langsep, kulit ireng',
    '👨🏽‍🤝‍👨🏻' => 'wong lanang loro gandhengan tangan: kulit kuning, kulit putih',
    '👨🏽‍🤝‍👨🏼' => 'wong lanang loro gandhengan tangan: kulit kuning, kulit putih langsep',
    '👨🏽‍🤝‍👨🏾' => 'wong lanang loro gandhengan tangan: kulit kuning, kulit sawo mateng',
    '👨🏽‍🤝‍👨🏿' => 'wong lanang loro gandhengan tangan: kulit kuning, kulit ireng',
    '👨🏾‍🤝‍👨🏻' => 'wong lanang loro gandhengan tangan: kulit sawo mateng, kulit putih',
    '👨🏾‍🤝‍👨🏼' => 'wong lanang loro gandhengan tangan: kulit sawo mateng, kulit putih langsep',
    '👨🏾‍🤝‍👨🏽' => 'wong lanang loro gandhengan tangan: kulit sawo mateng, kulit kuning',
    '👨🏾‍🤝‍👨🏿' => 'wong lanang loro gandhengan tangan: kulit sawo mateng, kulit ireng',
    '👨🏿‍🤝‍👨🏻' => 'wong lanang loro gandhengan tangan: kulit ireng, kulit putih',
    '👨🏿‍🤝‍👨🏼' => 'wong lanang loro gandhengan tangan: kulit ireng, kulit putih langsep',
    '👨🏿‍🤝‍👨🏽' => 'wong lanang loro gandhengan tangan: kulit ireng, kulit kuning',
    '👨🏿‍🤝‍👨🏾' => 'wong lanang loro gandhengan tangan: kulit ireng, kulit sawo mateng',
    '👩‍❤‍💋‍👨' => 'ambung: wong wadon, wong lanang',
    '👨‍❤‍💋‍👨' => 'ambung: wong lanang, wong lanang',
    '👩‍❤‍💋‍👩' => 'ambung: wong wadon, wong wadon',
    '👨‍👩‍👧‍👦' => 'kluwarga: wong lanang, wong wadon, bocah wadon, bocah lanang',
    '👨‍👩‍👦‍👦' => 'kluwarga: wong lanang, wong wadon, bocah lanang, bocah lanang',
    '👨‍👩‍👧‍👧' => 'kluwarga: wong lanang, wong wadon, bocah wadon, bocah wadon',
    '👨‍👨‍👧‍👦' => 'kluwarga: wong lanang, wong lanang, bocah wadon, bocah lanang',
    '👨‍👨‍👦‍👦' => 'kluwarga: wong lanang, wong lanang, bocah lanang, bocah lanang',
    '👨‍👨‍👧‍👧' => 'kluwarga: wong lanang, wong lanang, bocah wadon, bocah wadon',
    '👩‍👩‍👧‍👦' => 'kluwarga: wong wadon, wong wadon, bocah wadon, bocah lanang',
    '👩‍👩‍👦‍👦' => 'kluwarga: wong wadon, wong wadon, bocah lanang, bocah lanang',
    '👩‍👩‍👧‍👧' => 'kluwarga: wong wadon, wong wadon, bocah wadon, bocah wadon',
    '🏴󠁧󠁢󠁥󠁮󠁧󠁿' => 'gendera: Inggris',
    '🏴󠁧󠁢󠁳󠁣󠁴󠁿' => 'gendera: Skotlandia',
    '🏴󠁧󠁢󠁷󠁬󠁳󠁿' => 'gendera: Wales',
    '🧑‍🧑‍🧒‍🧒' => 'kulawarga: diwasa, diwasa, anak, anak',
    '🚶🏻‍♀‍➡' => 'wong wadon mlaku: kulit putih, madhep tengen',
    '🚶🏼‍♀‍➡' => 'wong wadon mlaku: kulit putih langsep, madhep tengen',
    '🚶🏽‍♀‍➡' => 'wong wadon mlaku: kulit kuning, madhep tengen',
    '🚶🏾‍♀‍➡' => 'wong wadon mlaku: kulit sawo mateng, madhep tengen',
    '🚶🏿‍♀‍➡' => 'wong wadon mlaku: kulit ireng, madhep tengen',
    '🚶🏻‍♂‍➡' => 'wong lanang mlaku: kulit putih, madhep tengen',
    '🚶🏼‍♂‍➡' => 'wong lanang mlaku: kulit putih langsep, madhep tengen',
    '🚶🏽‍♂‍➡' => 'wong lanang mlaku: kulit kuning, madhep tengen',
    '🚶🏾‍♂‍➡' => 'wong lanang mlaku: kulit sawo mateng, madhep tengen',
    '🚶🏿‍♂‍➡' => 'wong lanang mlaku: kulit ireng, madhep tengen',
    '🧎🏻‍♀‍➡' => 'wong wadon timpuh: kulit putih, madhep tengen',
    '🧎🏼‍♀‍➡' => 'wong wadon timpuh: kulit putih langsep, madhep tengen',
    '🧎🏽‍♀‍➡' => 'wong wadon timpuh: kulit kuning, madhep tengen',
    '🧎🏾‍♀‍➡' => 'wong wadon timpuh: kulit sawo mateng, madhep tengen',
    '🧎🏿‍♀‍➡' => 'wong wadon timpuh: kulit ireng, madhep tengen',
    '🧎🏻‍♂‍➡' => 'wong lanang timpuh: kulit putih, madhep tengen',
    '🧎🏼‍♂‍➡' => 'wong lanang timpuh: kulit putih langsep, madhep tengen',
    '🧎🏽‍♂‍➡' => 'wong lanang timpuh: kulit kuning, madhep tengen',
    '🧎🏾‍♂‍➡' => 'wong lanang timpuh: kulit sawo mateng, madhep tengen',
    '🧎🏿‍♂‍➡' => 'wong lanang timpuh: kulit ireng, madhep tengen',
    '🧑🏻‍🦯‍➡' => 'wong nyekeli teken: kulit putih, madhep tengen',
    '🧑🏼‍🦯‍➡' => 'wong nyekeli teken: kulit putih langsep, madhep tengen',
    '🧑🏽‍🦯‍➡' => 'wong nyekeli teken: kulit kuning, madhep tengen',
    '🧑🏾‍🦯‍➡' => 'wong nyekeli teken: kulit sawo mateng, madhep tengen',
    '🧑🏿‍🦯‍➡' => 'wong nyekeli teken: kulit ireng, madhep tengen',
    '👨🏻‍🦯‍➡' => 'wong lanang nyekeli teken: kulit putih, madhep tengen',
    '👨🏼‍🦯‍➡' => 'wong lanang nyekeli teken: kulit putih langsep, madhep tengen',
    '👨🏽‍🦯‍➡' => 'wong lanang nyekeli teken: kulit kuning, madhep tengen',
    '👨🏾‍🦯‍➡' => 'wong lanang nyekeli teken: kulit sawo mateng, madhep tengen',
    '👨🏿‍🦯‍➡' => 'wong lanang nyekeli teken: kulit ireng, madhep tengen',
    '👩🏻‍🦯‍➡' => 'wong wadon nyekeli teken: kulit putih, madhep tengen',
    '👩🏼‍🦯‍➡' => 'wong wadon nyekeli teken: kulit putih langsep, madhep tengen',
    '👩🏽‍🦯‍➡' => 'wong wadon nyekeli teken: kulit kuning, madhep tengen',
    '👩🏾‍🦯‍➡' => 'wong wadon nyekeli teken: kulit sawo mateng, madhep tengen',
    '👩🏿‍🦯‍➡' => 'wong wadon nyekeli teken: kulit ireng, madhep tengen',
    '🧑🏻‍🦼‍➡' => 'wong numpak kursi rodha mesin: kulit putih, madhep tengen',
    '🧑🏼‍🦼‍➡' => 'wong numpak kursi rodha mesin: kulit putih langsep, madhep tengen',
    '🧑🏽‍🦼‍➡' => 'wong numpak kursi rodha mesin: kulit kuning, madhep tengen',
    '🧑🏾‍🦼‍➡' => 'wong numpak kursi rodha mesin: kulit sawo mateng, madhep tengen',
    '🧑🏿‍🦼‍➡' => 'wong numpak kursi rodha mesin: kulit ireng, madhep tengen',
    '👨🏻‍🦼‍➡' => 'wong lanang numpak kursi rodha mesin: kulit putih, madhep tengen',
    '👨🏼‍🦼‍➡' => 'wong lanang numpak kursi rodha mesin: kulit putih langsep, madhep tengen',
    '👨🏽‍🦼‍➡' => 'wong lanang numpak kursi rodha mesin: kulit kuning, madhep tengen',
    '👨🏾‍🦼‍➡' => 'wong lanang numpak kursi rodha mesin: kulit sawo mateng, madhep tengen',
    '👨🏿‍🦼‍➡' => 'wong lanang numpak kursi rodha mesin: kulit ireng, madhep tengen',
    '👩🏻‍🦼‍➡' => 'wong wadon numpak kursi rodha mesin: kulit putih, madhep tengen',
    '👩🏼‍🦼‍➡' => 'wong wadon numpak kursi rodha mesin: kulit putih langsep, madhep tengen',
    '👩🏽‍🦼‍➡' => 'wong wadon numpak kursi rodha mesin: kulit kuning, madhep tengen',
    '👩🏾‍🦼‍➡' => 'wong wadon numpak kursi rodha mesin: kulit sawo mateng, madhep tengen',
    '👩🏿‍🦼‍➡' => 'wong wadon numpak kursi rodha mesin: kulit ireng, madhep tengen',
    '🧑🏻‍🦽‍➡' => 'wong numpak kursi rodha manual: kulit putih, madhep tengen',
    '🧑🏼‍🦽‍➡' => 'wong numpak kursi rodha manual: kulit putih langsep, madhep tengen',
    '🧑🏽‍🦽‍➡' => 'wong numpak kursi rodha manual: kulit kuning, madhep tengen',
    '🧑🏾‍🦽‍➡' => 'wong numpak kursi rodha manual: kulit sawo mateng, madhep tengen',
    '🧑🏿‍🦽‍➡' => 'wong numpak kursi rodha manual: kulit ireng, madhep tengen',
    '👨🏻‍🦽‍➡' => 'wong lanang numpak kursi rodha manual: kulit putih, madhep tengen',
    '👨🏼‍🦽‍➡' => 'wong lanang numpak kursi rodha manual: kulit putih langsep, madhep tengen',
    '👨🏽‍🦽‍➡' => 'wong lanang numpak kursi rodha manual: kulit kuning, madhep tengen',
    '👨🏾‍🦽‍➡' => 'wong lanang numpak kursi rodha manual: kulit sawo mateng, madhep tengen',
    '👨🏿‍🦽‍➡' => 'wong lanang numpak kursi rodha manual: kulit ireng, madhep tengen',
    '👩🏻‍🦽‍➡' => 'wong wadon numpak kursi rodha manual: kulit putih, madhep tengen',
    '👩🏼‍🦽‍➡' => 'wong wadon numpak kursi rodha manual: kulit putih langsep, madhep tengen',
    '👩🏽‍🦽‍➡' => 'wong wadon numpak kursi rodha manual: kulit kuning, madhep tengen',
    '👩🏾‍🦽‍➡' => 'wong wadon numpak kursi rodha manual: kulit sawo mateng, madhep tengen',
    '👩🏿‍🦽‍➡' => 'wong wadon numpak kursi rodha manual: kulit ireng, madhep tengen',
    '🏃🏻‍♀‍➡' => 'wong wadon mlayu: kulit putih, madhep tengen',
    '🏃🏼‍♀‍➡' => 'wong wadon mlayu: kulit putih langsep, madhep tengen',
    '🏃🏽‍♀‍➡' => 'wong wadon mlayu: kulit kuning, madhep tengen',
    '🏃🏾‍♀‍➡' => 'wong wadon mlayu: kulit sawo mateng, madhep tengen',
    '🏃🏿‍♀‍➡' => 'wong wadon mlayu: kulit ireng, madhep tengen',
    '🏃🏻‍♂‍➡' => 'wong lanang mlayu: kulit putih, madhep tengen',
    '🏃🏼‍♂‍➡' => 'wong lanang mlayu: kulit putih langsep, madhep tengen',
    '🏃🏽‍♂‍➡' => 'wong lanang mlayu: kulit kuning, madhep tengen',
    '🏃🏾‍♂‍➡' => 'wong lanang mlayu: kulit sawo mateng, madhep tengen',
    '🏃🏿‍♂‍➡' => 'wong lanang mlayu: kulit ireng, madhep tengen',
    '🫱🏻‍🫲🏼' => 'salaman: kulit putih, kulit putih langsep',
    '🫱🏻‍🫲🏽' => 'salaman: kulit putih, kulit kuning',
    '🫱🏻‍🫲🏾' => 'salaman: kulit putih, kulit sawo mateng',
    '🫱🏻‍🫲🏿' => 'salaman: kulit putih, kulit ireng',
    '🫱🏼‍🫲🏻' => 'salaman: kulit putih langsep, kulit putih',
    '🫱🏼‍🫲🏽' => 'salaman: kulit putih langsep, kulit kuning',
    '🫱🏼‍🫲🏾' => 'salaman: kulit putih langsep, kulit sawo mateng',
    '🫱🏼‍🫲🏿' => 'salaman: kulit putih langsep, kulit ireng',
    '🫱🏽‍🫲🏻' => 'salaman: kulit kuning, kulit putih',
    '🫱🏽‍🫲🏼' => 'salaman: kulit kuning, kulit putih langsep',
    '🫱🏽‍🫲🏾' => 'salaman: kulit kuning, kulit sawo mateng',
    '🫱🏽‍🫲🏿' => 'salaman: kulit kuning, kulit ireng',
    '🫱🏾‍🫲🏻' => 'salaman: kulit sawo mateng, kulit putih',
    '🫱🏾‍🫲🏼' => 'salaman: kulit sawo mateng, kulit putih langsep',
    '🫱🏾‍🫲🏽' => 'salaman: kulit sawo mateng, kulit kuning',
    '🫱🏾‍🫲🏿' => 'salaman: kulit sawo mateng, kulit ireng',
    '🫱🏿‍🫲🏻' => 'salaman: kulit ireng, kulit putih',
    '🫱🏿‍🫲🏼' => 'salaman: kulit ireng, kulit putih langsep',
    '🫱🏿‍🫲🏽' => 'salaman: kulit ireng, kulit kuning',
    '🫱🏿‍🫲🏾' => 'salaman: kulit ireng, kulit sawo mateng',
    '🚶‍♀‍➡' => 'wong wadon mlaku: madhep tengen',
    '🚶‍♂‍➡' => 'wong lanang mlaku: madhep tengen',
    '🧎‍♀‍➡' => 'wong wadon timpuh: madhep tengen',
    '🧎‍♂‍➡' => 'wong lanang timpuh: madhep tengen',
    '🧑‍🦯‍➡' => 'wong nyekeli teken: madhep tengen',
    '👨‍🦯‍➡' => 'wong lanang nyekeli teken: madhep tengen',
    '👩‍🦯‍➡' => 'wong wadon nyekeli teken: madhep tengen',
    '🧑‍🦼‍➡' => 'wong numpak kursi rodha mesin: madhep tengen',
    '👨‍🦼‍➡' => 'wong lanang numpak kursi rodha mesin: madhep tengen',
    '👩‍🦼‍➡' => 'wong wadon numpak kursi rodha mesin: madhep tengen',
    '🧑‍🦽‍➡' => 'wong numpak kursi rodha manual: madhep tengen',
    '👨‍🦽‍➡' => 'wong lanang numpak kursi rodha manual: madhep tengen',
    '👩‍🦽‍➡' => 'wong wadon numpak kursi rodha manual: madhep tengen',
    '🏃‍♀‍➡' => 'wong wadon mlayu: madhep tengen',
    '🏃‍♂‍➡' => 'wong lanang mlayu: madhep tengen',
    '👩‍❤‍👨' => 'pasangan lan tandha ati: wong wadon, wong lanang',
    '👨‍❤‍👨' => 'pasangan lan tandha ati: wong lanang, wong lanang',
    '👩‍❤‍👩' => 'pasangan lan tandha ati: wong wadon, wong wadon',
    '👨‍👩‍👦' => 'kluwarga: wong lanang, wong wadon, bocah lanang',
    '👨‍👩‍👧' => 'kluwarga: wong lanang, wong wadon, bocah wadon',
    '👨‍👨‍👦' => 'kluwarga: wong lanang, wong lanang, bocah lanang',
    '👨‍👨‍👧' => 'kluwarga: wong lanang, wong lanang, bocah wadon',
    '👩‍👩‍👦' => 'kluwarga: wong wadon, wong wadon, bocah lanang',
    '👩‍👩‍👧' => 'kluwarga: wong wadon, wong wadon, bocah wadon',
    '👨‍👦‍👦' => 'kluwarga: wong lanang, bocah lanang, bocah lanang',
    '👨‍👧‍👦' => 'kluwarga: wong lanang, bocah wadon, bocah lanang',
    '👨‍👧‍👧' => 'kluwarga: wong lanang, bocah wadon, bocah wadon',
    '👩‍👦‍👦' => 'kluwarga: wong wadon, bocah lanang, bocah lanang',
    '👩‍👧‍👦' => 'kluwarga: wong wadon, bocah wadon, bocah lanang',
    '👩‍👧‍👧' => 'kluwarga: wong wadon, bocah wadon, bocah wadon',
    '🧑‍🤝‍🧑' => 'wong gandhengan tangan',
    '🧑‍🧑‍🧒' => 'kulawarga: diwasa, diwasa, anak',
    '🧑‍🧒‍🧒' => 'kulawarga: diwasa, anak, anak',
    '🧑🏻‍🦰' => 'wong: kulit putih, rambut abang',
    '🧑🏼‍🦰' => 'wong: kulit putih langsep, rambut abang',
    '🧑🏽‍🦰' => 'wong: kulit kuning, rambut abang',
    '🧑🏾‍🦰' => 'wong: kulit sawo mateng, rambut abang',
    '🧑🏿‍🦰' => 'wong: kulit ireng, rambut abang',
    '🧑🏻‍🦱' => 'wong: kulit putih, rambut brintik',
    '🧑🏼‍🦱' => 'wong: kulit putih langsep, rambut brintik',
    '🧑🏽‍🦱' => 'wong: kulit kuning, rambut brintik',
    '🧑🏾‍🦱' => 'wong: kulit sawo mateng, rambut brintik',
    '🧑🏿‍🦱' => 'wong: kulit ireng, rambut brintik',
    '🧑🏻‍🦳' => 'wong: kulit putih, rambut putih',
    '🧑🏼‍🦳' => 'wong: kulit putih langsep, rambut putih',
    '🧑🏽‍🦳' => 'wong: kulit kuning, rambut putih',
    '🧑🏾‍🦳' => 'wong: kulit sawo mateng, rambut putih',
    '🧑🏿‍🦳' => 'wong: kulit ireng, rambut putih',
    '🧑🏻‍🦲' => 'wong: kulit putih, buthak',
    '🧑🏼‍🦲' => 'wong: kulit putih langsep, buthak',
    '🧑🏽‍🦲' => 'wong: kulit kuning, buthak',
    '🧑🏾‍🦲' => 'wong: kulit sawo mateng, buthak',
    '🧑🏿‍🦲' => 'wong: kulit ireng, buthak',
    '🧑🏻‍🩰' => 'penari balet: kulit putih',
    '🧑🏼‍🩰' => 'penari balet: kulit putih langsep',
    '🧑🏽‍🩰' => 'penari balet: kulit kuning',
    '🧑🏾‍🩰' => 'penari balet: kulit sawo mateng',
    '🧑🏿‍🩰' => 'penari balet: kulit ireng',
    '🧔🏻‍♂' => 'wong lanang: kulit putih, jenggot',
    '🧔🏼‍♂' => 'wong lanang: kulit putih langsep, jenggot',
    '🧔🏽‍♂' => 'wong lanang: kulit kuning, jenggot',
    '🧔🏾‍♂' => 'wong lanang: kulit sawo mateng, jenggot',
    '🧔🏿‍♂' => 'wong lanang: kulit ireng, jenggot',
    '👱🏻‍♂' => 'wong lanang: kulit putih, rambut pirang',
    '👱🏼‍♂' => 'wong lanang: kulit putih langsep, rambut pirang',
    '👱🏽‍♂' => 'wong lanang: kulit kuning, rambut pirang',
    '👱🏾‍♂' => 'wong lanang: kulit sawo mateng, rambut pirang',
    '👱🏿‍♂' => 'wong lanang: kulit ireng, rambut pirang',
    '👨🏻‍🦰' => 'wong lanang: kulit putih, rambut abang',
    '👨🏼‍🦰' => 'wong lanang: kulit putih langsep, rambut abang',
    '👨🏽‍🦰' => 'wong lanang: kulit kuning, rambut abang',
    '👨🏾‍🦰' => 'wong lanang: kulit sawo mateng, rambut abang',
    '👨🏿‍🦰' => 'wong lanang: kulit ireng, rambut abang',
    '👨🏻‍🦱' => 'wong lanang: kulit putih, rambut brintik',
    '👨🏼‍🦱' => 'wong lanang: kulit putih langsep, rambut brintik',
    '👨🏽‍🦱' => 'wong lanang: kulit kuning, rambut brintik',
    '👨🏾‍🦱' => 'wong lanang: kulit sawo mateng, rambut brintik',
    '👨🏿‍🦱' => 'wong lanang: kulit ireng, rambut brintik',
    '👨🏻‍🦳' => 'wong lanang: kulit putih, rambut putih',
    '👨🏼‍🦳' => 'wong lanang: kulit putih langsep, rambut putih',
    '👨🏽‍🦳' => 'wong lanang: kulit kuning, rambut putih',
    '👨🏾‍🦳' => 'wong lanang: kulit sawo mateng, rambut putih',
    '👨🏿‍🦳' => 'wong lanang: kulit ireng, rambut putih',
    '👨🏻‍🦲' => 'wong lanang: kulit putih, buthak',
    '👨🏼‍🦲' => 'wong lanang: kulit putih langsep, buthak',
    '👨🏽‍🦲' => 'wong lanang: kulit kuning, buthak',
    '👨🏾‍🦲' => 'wong lanang: kulit sawo mateng, buthak',
    '👨🏿‍🦲' => 'wong lanang: kulit ireng, buthak',
    '🧔🏻‍♀' => 'wong wadon: kulit putih, jenggot',
    '🧔🏼‍♀' => 'wong wadon: kulit putih langsep, jenggot',
    '🧔🏽‍♀' => 'wong wadon: kulit kuning, jenggot',
    '🧔🏾‍♀' => 'wong wadon: kulit sawo mateng, jenggot',
    '🧔🏿‍♀' => 'wong wadon: kulit ireng, jenggot',
    '👱🏻‍♀' => 'wong wadon: kulit putih, rambut pirang',
    '👱🏼‍♀' => 'wong wadon: kulit putih langsep, rambut pirang',
    '👱🏽‍♀' => 'wong wadon: kulit kuning, rambut pirang',
    '👱🏾‍♀' => 'wong wadon: kulit sawo mateng, rambut pirang',
    '👱🏿‍♀' => 'wong wadon: kulit ireng, rambut pirang',
    '👩🏻‍🦰' => 'wong wadon: kulit putih, rambut abang',
    '👩🏼‍🦰' => 'wong wadon: kulit putih langsep, rambut abang',
    '👩🏽‍🦰' => 'wong wadon: kulit kuning, rambut abang',
    '👩🏾‍🦰' => 'wong wadon: kulit sawo mateng, rambut abang',
    '👩🏿‍🦰' => 'wong wadon: kulit ireng, rambut abang',
    '👩🏻‍🦱' => 'wong wadon: kulit putih, rambut brintik',
    '👩🏼‍🦱' => 'wong wadon: kulit putih langsep, rambut brintik',
    '👩🏽‍🦱' => 'wong wadon: kulit kuning, rambut brintik',
    '👩🏾‍🦱' => 'wong wadon: kulit sawo mateng, rambut brintik',
    '👩🏿‍🦱' => 'wong wadon: kulit ireng, rambut brintik',
    '👩🏻‍🦳' => 'wong wadon: kulit putih, rambut putih',
    '👩🏼‍🦳' => 'wong wadon: kulit putih langsep, rambut putih',
    '👩🏽‍🦳' => 'wong wadon: kulit kuning, rambut putih',
    '👩🏾‍🦳' => 'wong wadon: kulit sawo mateng, rambut putih',
    '👩🏿‍🦳' => 'wong wadon: kulit ireng, rambut putih',
    '👩🏻‍🦲' => 'wong wadon: kulit putih, buthak',
    '👩🏼‍🦲' => 'wong wadon: kulit putih langsep, buthak',
    '👩🏽‍🦲' => 'wong wadon: kulit kuning, buthak',
    '👩🏾‍🦲' => 'wong wadon: kulit sawo mateng, buthak',
    '👩🏿‍🦲' => 'wong wadon: kulit ireng, buthak',
    '🙍🏻‍♂' => 'wong lanang sedhih: kulit putih',
    '🙍🏼‍♂' => 'wong lanang sedhih: kulit putih langsep',
    '🙍🏽‍♂' => 'wong lanang sedhih: kulit kuning',
    '🙍🏾‍♂' => 'wong lanang sedhih: kulit sawo mateng',
    '🙍🏿‍♂' => 'wong lanang sedhih: kulit ireng',
    '🙍🏻‍♀' => 'wong wadon sedhih: kulit putih',
    '🙍🏼‍♀' => 'wong wadon sedhih: kulit putih langsep',
    '🙍🏽‍♀' => 'wong wadon sedhih: kulit kuning',
    '🙍🏾‍♀' => 'wong wadon sedhih: kulit sawo mateng',
    '🙍🏿‍♀' => 'wong wadon sedhih: kulit ireng',
    '🙎🏻‍♂' => 'wong lanang mbesengut: kulit putih',
    '🙎🏼‍♂' => 'wong lanang mbesengut: kulit putih langsep',
    '🙎🏽‍♂' => 'wong lanang mbesengut: kulit kuning',
    '🙎🏾‍♂' => 'wong lanang mbesengut: kulit sawo mateng',
    '🙎🏿‍♂' => 'wong lanang mbesengut: kulit ireng',
    '🙎🏻‍♀' => 'wong wadon mbesengut: kulit putih',
    '🙎🏼‍♀' => 'wong wadon mbesengut: kulit putih langsep',
    '🙎🏽‍♀' => 'wong wadon mbesengut: kulit kuning',
    '🙎🏾‍♀' => 'wong wadon mbesengut: kulit sawo mateng',
    '🙎🏿‍♀' => 'wong wadon mbesengut: kulit ireng',
    '🙅🏻‍♂' => 'wong lanang ngisaratake AJA: kulit putih',
    '🙅🏼‍♂' => 'wong lanang ngisaratake AJA: kulit putih langsep',
    '🙅🏽‍♂' => 'wong lanang ngisaratake AJA: kulit kuning',
    '🙅🏾‍♂' => 'wong lanang ngisaratake AJA: kulit sawo mateng',
    '🙅🏿‍♂' => 'wong lanang ngisaratake AJA: kulit ireng',
    '🙅🏻‍♀' => 'wong wadon menehi isarat AJA: kulit putih',
    '🙅🏼‍♀' => 'wong wadon menehi isarat AJA: kulit putih langsep',
    '🙅🏽‍♀' => 'wong wadon menehi isarat AJA: kulit kuning',
    '🙅🏾‍♀' => 'wong wadon menehi isarat AJA: kulit sawo mateng',
    '🙅🏿‍♀' => 'wong wadon menehi isarat AJA: kulit ireng',
    '🙆🏻‍♂' => 'wong lanang ngisaratake OK: kulit putih',
    '🙆🏼‍♂' => 'wong lanang ngisaratake OK: kulit putih langsep',
    '🙆🏽‍♂' => 'wong lanang ngisaratake OK: kulit kuning',
    '🙆🏾‍♂' => 'wong lanang ngisaratake OK: kulit sawo mateng',
    '🙆🏿‍♂' => 'wong lanang ngisaratake OK: kulit ireng',
    '🙆🏻‍♀' => 'wong wadon ngisaratake OK: kulit putih',
    '🙆🏼‍♀' => 'wong wadon ngisaratake OK: kulit putih langsep',
    '🙆🏽‍♀' => 'wong wadon ngisaratake OK: kulit kuning',
    '🙆🏾‍♀' => 'wong wadon ngisaratake OK: kulit sawo mateng',
    '🙆🏿‍♀' => 'wong wadon ngisaratake OK: kulit ireng',
    '💁🏻‍♂' => 'wong lanang tangane anyangga: kulit putih',
    '💁🏼‍♂' => 'wong lanang tangane anyangga: kulit putih langsep',
    '💁🏽‍♂' => 'wong lanang tangane anyangga: kulit kuning',
    '💁🏾‍♂' => 'wong lanang tangane anyangga: kulit sawo mateng',
    '💁🏿‍♂' => 'wong lanang tangane anyangga: kulit ireng',
    '💁🏻‍♀' => 'wong wadon tangane anyangga: kulit putih',
    '💁🏼‍♀' => 'wong wadon tangane anyangga: kulit putih langsep',
    '💁🏽‍♀' => 'wong wadon tangane anyangga: kulit kuning',
    '💁🏾‍♀' => 'wong wadon tangane anyangga: kulit sawo mateng',
    '💁🏿‍♀' => 'wong wadon tangane anyangga: kulit ireng',
    '🙋🏻‍♂' => 'wong lanang ngacungake tangan: kulit putih',
    '🙋🏼‍♂' => 'wong lanang ngacungake tangan: kulit putih langsep',
    '🙋🏽‍♂' => 'wong lanang ngacungake tangan: kulit kuning',
    '🙋🏾‍♂' => 'wong lanang ngacungake tangan: kulit sawo mateng',
    '🙋🏿‍♂' => 'wong lanang ngacungake tangan: kulit ireng',
    '🙋🏻‍♀' => 'wong wadon ngacungake tangan: kulit putih',
    '🙋🏼‍♀' => 'wong wadon ngacungake tangan: kulit putih langsep',
    '🙋🏽‍♀' => 'wong wadon ngacungake tangan: kulit kuning',
    '🙋🏾‍♀' => 'wong wadon ngacungake tangan: kulit sawo mateng',
    '🙋🏿‍♀' => 'wong wadon ngacungake tangan: kulit ireng',
    '🧏🏻‍♂' => 'wong lanang budheg: kulit putih',
    '🧏🏼‍♂' => 'wong lanang budheg: kulit putih langsep',
    '🧏🏽‍♂' => 'wong lanang budheg: kulit kuning',
    '🧏🏾‍♂' => 'wong lanang budheg: kulit sawo mateng',
    '🧏🏿‍♂' => 'wong lanang budheg: kulit ireng',
    '🧏🏻‍♀' => 'wong wadon budheg: kulit putih',
    '🧏🏼‍♀' => 'wong wadon budheg: kulit putih langsep',
    '🧏🏽‍♀' => 'wong wadon budheg: kulit kuning',
    '🧏🏾‍♀' => 'wong wadon budheg: kulit sawo mateng',
    '🧏🏿‍♀' => 'wong wadon budheg: kulit ireng',
    '🙇🏻‍♂' => 'wong lanang mbungkuk ngurmati: kulit putih',
    '🙇🏼‍♂' => 'wong lanang mbungkuk ngurmati: kulit putih langsep',
    '🙇🏽‍♂' => 'wong lanang mbungkuk ngurmati: kulit kuning',
    '🙇🏾‍♂' => 'wong lanang mbungkuk ngurmati: kulit sawo mateng',
    '🙇🏿‍♂' => 'wong lanang mbungkuk ngurmati: kulit ireng',
    '🙇🏻‍♀' => 'wong wadon mbungkuk ngurmati: kulit putih',
    '🙇🏼‍♀' => 'wong wadon mbungkuk ngurmati: kulit putih langsep',
    '🙇🏽‍♀' => 'wong wadon mbungkuk ngurmati: kulit kuning',
    '🙇🏾‍♀' => 'wong wadon mbungkuk ngurmati: kulit sawo mateng',
    '🙇🏿‍♀' => 'wong wadon mbungkuk ngurmati: kulit ireng',
    '🤦🏻‍♂' => 'wong lanang anutup raine mawa dlamakan: kulit putih',
    '🤦🏼‍♂' => 'wong lanang anutup raine mawa dlamakan: kulit putih langsep',
    '🤦🏽‍♂' => 'wong lanang anutup raine mawa dlamakan: kulit kuning',
    '🤦🏾‍♂' => 'wong lanang anutup raine mawa dlamakan: kulit sawo mateng',
    '🤦🏿‍♂' => 'wong lanang anutup raine mawa dlamakan: kulit ireng',
    '🤦🏻‍♀' => 'wong wadon anutup raine mawa dlamakan: kulit putih',
    '🤦🏼‍♀' => 'wong wadon anutup raine mawa dlamakan: kulit putih langsep',
    '🤦🏽‍♀' => 'wong wadon anutup raine mawa dlamakan: kulit kuning',
    '🤦🏾‍♀' => 'wong wadon anutup raine mawa dlamakan: kulit sawo mateng',
    '🤦🏿‍♀' => 'wong wadon anutup raine mawa dlamakan: kulit ireng',
    '🤷🏻‍♂' => 'wong lanang angangkat pundhak: kulit putih',
    '🤷🏼‍♂' => 'wong lanang angangkat pundhak: kulit putih langsep',
    '🤷🏽‍♂' => 'wong lanang angangkat pundhak: kulit kuning',
    '🤷🏾‍♂' => 'wong lanang angangkat pundhak: kulit sawo mateng',
    '🤷🏿‍♂' => 'wong lanang angangkat pundhak: kulit ireng',
    '🤷🏻‍♀' => 'wong wadon ngangkat pundhak: kulit putih',
    '🤷🏼‍♀' => 'wong wadon ngangkat pundhak: kulit putih langsep',
    '🤷🏽‍♀' => 'wong wadon ngangkat pundhak: kulit kuning',
    '🤷🏾‍♀' => 'wong wadon ngangkat pundhak: kulit sawo mateng',
    '🤷🏿‍♀' => 'wong wadon ngangkat pundhak: kulit ireng',
    '🧑🏻‍⚕' => 'mantri: kulit putih',
    '🧑🏼‍⚕' => 'mantri: kulit putih langsep',
    '🧑🏽‍⚕' => 'mantri: kulit kuning',
    '🧑🏾‍⚕' => 'mantri: kulit sawo mateng',
    '🧑🏿‍⚕' => 'mantri: kulit ireng',
    '👨🏻‍⚕' => 'mantri lanang: kulit putih',
    '👨🏼‍⚕' => 'mantri lanang: kulit putih langsep',
    '👨🏽‍⚕' => 'mantri lanang: kulit kuning',
    '👨🏾‍⚕' => 'mantri lanang: kulit sawo mateng',
    '👨🏿‍⚕' => 'mantri lanang: kulit ireng',
    '👩🏻‍⚕' => 'mantri wadon: kulit putih',
    '👩🏼‍⚕' => 'mantri wadon: kulit putih langsep',
    '👩🏽‍⚕' => 'mantri wadon: kulit kuning',
    '👩🏾‍⚕' => 'mantri wadon: kulit sawo mateng',
    '👩🏿‍⚕' => 'mantri wadon: kulit ireng',
    '🧑🏻‍🎓' => 'mahasiswa: kulit putih',
    '🧑🏼‍🎓' => 'mahasiswa: kulit putih langsep',
    '🧑🏽‍🎓' => 'mahasiswa: kulit kuning',
    '🧑🏾‍🎓' => 'mahasiswa: kulit sawo mateng',
    '🧑🏿‍🎓' => 'mahasiswa: kulit ireng',
    '👨🏻‍🎓' => 'mahasiswa lanang: kulit putih',
    '👨🏼‍🎓' => 'mahasiswa lanang: kulit putih langsep',
    '👨🏽‍🎓' => 'mahasiswa lanang: kulit kuning',
    '👨🏾‍🎓' => 'mahasiswa lanang: kulit sawo mateng',
    '👨🏿‍🎓' => 'mahasiswa lanang: kulit ireng',
    '👩🏻‍🎓' => 'mahasiswa wadon: kulit putih',
    '👩🏼‍🎓' => 'mahasiswa wadon: kulit putih langsep',
    '👩🏽‍🎓' => 'mahasiswa wadon: kulit kuning',
    '👩🏾‍🎓' => 'mahasiswa wadon: kulit sawo mateng',
    '👩🏿‍🎓' => 'mahasiswa wadon: kulit ireng',
    '🧑🏻‍🏫' => 'guru: kulit putih',
    '🧑🏼‍🏫' => 'guru: kulit putih langsep',
    '🧑🏽‍🏫' => 'guru: kulit kuning',
    '🧑🏾‍🏫' => 'guru: kulit sawo mateng',
    '🧑🏿‍🏫' => 'guru: kulit ireng',
    '👨🏻‍🏫' => 'guru lanang: kulit putih',
    '👨🏼‍🏫' => 'guru lanang: kulit putih langsep',
    '👨🏽‍🏫' => 'guru lanang: kulit kuning',
    '👨🏾‍🏫' => 'guru lanang: kulit sawo mateng',
    '👨🏿‍🏫' => 'guru lanang: kulit ireng',
    '👩🏻‍🏫' => 'guru wadon: kulit putih',
    '👩🏼‍🏫' => 'guru wadon: kulit putih langsep',
    '👩🏽‍🏫' => 'guru wadon: kulit kuning',
    '👩🏾‍🏫' => 'guru wadon: kulit sawo mateng',
    '👩🏿‍🏫' => 'guru wadon: kulit ireng',
    '🧑🏻‍⚖' => 'hakim: kulit putih',
    '🧑🏼‍⚖' => 'hakim: kulit putih langsep',
    '🧑🏽‍⚖' => 'hakim: kulit kuning',
    '🧑🏾‍⚖' => 'hakim: kulit sawo mateng',
    '🧑🏿‍⚖' => 'hakim: kulit ireng',
    '👨🏻‍⚖' => 'hakim lanang: kulit putih',
    '👨🏼‍⚖' => 'hakim lanang: kulit putih langsep',
    '👨🏽‍⚖' => 'hakim lanang: kulit kuning',
    '👨🏾‍⚖' => 'hakim lanang: kulit sawo mateng',
    '👨🏿‍⚖' => 'hakim lanang: kulit ireng',
    '👩🏻‍⚖' => 'hakim wadon: kulit putih',
    '👩🏼‍⚖' => 'hakim wadon: kulit putih langsep',
    '👩🏽‍⚖' => 'hakim wadon: kulit kuning',
    '👩🏾‍⚖' => 'hakim wadon: kulit sawo mateng',
    '👩🏿‍⚖' => 'hakim wadon: kulit ireng',
    '🧑🏻‍🌾' => 'tani: kulit putih',
    '🧑🏼‍🌾' => 'tani: kulit putih langsep',
    '🧑🏽‍🌾' => 'tani: kulit kuning',
    '🧑🏾‍🌾' => 'tani: kulit sawo mateng',
    '🧑🏿‍🌾' => 'tani: kulit ireng',
    '👨🏻‍🌾' => 'pak tani: kulit putih',
    '👨🏼‍🌾' => 'pak tani: kulit putih langsep',
    '👨🏽‍🌾' => 'pak tani: kulit kuning',
    '👨🏾‍🌾' => 'pak tani: kulit sawo mateng',
    '👨🏿‍🌾' => 'pak tani: kulit ireng',
    '👩🏻‍🌾' => 'bu tani: kulit putih',
    '👩🏼‍🌾' => 'bu tani: kulit putih langsep',
    '👩🏽‍🌾' => 'bu tani: kulit kuning',
    '👩🏾‍🌾' => 'bu tani: kulit sawo mateng',
    '👩🏿‍🌾' => 'bu tani: kulit ireng',
    '🧑🏻‍🍳' => 'mangsak: kulit putih',
    '🧑🏼‍🍳' => 'mangsak: kulit putih langsep',
    '🧑🏽‍🍳' => 'mangsak: kulit kuning',
    '🧑🏾‍🍳' => 'mangsak: kulit sawo mateng',
    '🧑🏿‍🍳' => 'mangsak: kulit ireng',
    '👨🏻‍🍳' => 'koki lanang: kulit putih',
    '👨🏼‍🍳' => 'koki lanang: kulit putih langsep',
    '👨🏽‍🍳' => 'koki lanang: kulit kuning',
    '👨🏾‍🍳' => 'koki lanang: kulit sawo mateng',
    '👨🏿‍🍳' => 'koki lanang: kulit ireng',
    '👩🏻‍🍳' => 'koki wadon: kulit putih',
    '👩🏼‍🍳' => 'koki wadon: kulit putih langsep',
    '👩🏽‍🍳' => 'koki wadon: kulit kuning',
    '👩🏾‍🍳' => 'koki wadon: kulit sawo mateng',
    '👩🏿‍🍳' => 'koki wadon: kulit ireng',
    '🧑🏻‍🔧' => 'montir: kulit putih',
    '🧑🏼‍🔧' => 'montir: kulit putih langsep',
    '🧑🏽‍🔧' => 'montir: kulit kuning',
    '🧑🏾‍🔧' => 'montir: kulit sawo mateng',
    '🧑🏿‍🔧' => 'montir: kulit ireng',
    '👨🏻‍🔧' => 'montir lanang: kulit putih',
    '👨🏼‍🔧' => 'montir lanang: kulit putih langsep',
    '👨🏽‍🔧' => 'montir lanang: kulit kuning',
    '👨🏾‍🔧' => 'montir lanang: kulit sawo mateng',
    '👨🏿‍🔧' => 'montir lanang: kulit ireng',
    '👩🏻‍🔧' => 'montir wadon: kulit putih',
    '👩🏼‍🔧' => 'montir wadon: kulit putih langsep',
    '👩🏽‍🔧' => 'montir wadon: kulit kuning',
    '👩🏾‍🔧' => 'montir wadon: kulit sawo mateng',
    '👩🏿‍🔧' => 'montir wadon: kulit ireng',
    '🧑🏻‍🏭' => 'buruh pabrik: kulit putih',
    '🧑🏼‍🏭' => 'buruh pabrik: kulit putih langsep',
    '🧑🏽‍🏭' => 'buruh pabrik: kulit kuning',
    '🧑🏾‍🏭' => 'buruh pabrik: kulit sawo mateng',
    '🧑🏿‍🏭' => 'buruh pabrik: kulit ireng',
    '👨🏻‍🏭' => 'buruh pabrik lanang: kulit putih',
    '👨🏼‍🏭' => 'buruh pabrik lanang: kulit putih langsep',
    '👨🏽‍🏭' => 'buruh pabrik lanang: kulit kuning',
    '👨🏾‍🏭' => 'buruh pabrik lanang: kulit sawo mateng',
    '👨🏿‍🏭' => 'buruh pabrik lanang: kulit ireng',
    '👩🏻‍🏭' => 'buruh pabrik wadon: kulit putih',
    '👩🏼‍🏭' => 'buruh pabrik wadon: kulit putih langsep',
    '👩🏽‍🏭' => 'buruh pabrik wadon: kulit kuning',
    '👩🏾‍🏭' => 'buruh pabrik wadon: kulit sawo mateng',
    '👩🏿‍🏭' => 'buruh pabrik wadon: kulit ireng',
    '🧑🏻‍💼' => 'pegawe: kulit putih',
    '🧑🏼‍💼' => 'pegawe: kulit putih langsep',
    '🧑🏽‍💼' => 'pegawe: kulit kuning',
    '🧑🏾‍💼' => 'pegawe: kulit sawo mateng',
    '🧑🏿‍💼' => 'pegawe: kulit ireng',
    '👨🏻‍💼' => 'pegawe kantor lanang: kulit putih',
    '👨🏼‍💼' => 'pegawe kantor lanang: kulit putih langsep',
    '👨🏽‍💼' => 'pegawe kantor lanang: kulit kuning',
    '👨🏾‍💼' => 'pegawe kantor lanang: kulit sawo mateng',
    '👨🏿‍💼' => 'pegawe kantor lanang: kulit ireng',
    '👩🏻‍💼' => 'pegawe kantor wadon: kulit putih',
    '👩🏼‍💼' => 'pegawe kantor wadon: kulit putih langsep',
    '👩🏽‍💼' => 'pegawe kantor wadon: kulit kuning',
    '👩🏾‍💼' => 'pegawe kantor wadon: kulit sawo mateng',
    '👩🏿‍💼' => 'pegawe kantor wadon: kulit ireng',
    '🧑🏻‍🔬' => 'ilmuwan: kulit putih',
    '🧑🏼‍🔬' => 'ilmuwan: kulit putih langsep',
    '🧑🏽‍🔬' => 'ilmuwan: kulit kuning',
    '🧑🏾‍🔬' => 'ilmuwan: kulit sawo mateng',
    '🧑🏿‍🔬' => 'ilmuwan: kulit ireng',
    '👨🏻‍🔬' => 'ilmuwan lanang: kulit putih',
    '👨🏼‍🔬' => 'ilmuwan lanang: kulit putih langsep',
    '👨🏽‍🔬' => 'ilmuwan lanang: kulit kuning',
    '👨🏾‍🔬' => 'ilmuwan lanang: kulit sawo mateng',
    '👨🏿‍🔬' => 'ilmuwan lanang: kulit ireng',
    '👩🏻‍🔬' => 'ilmuwan wadon: kulit putih',
    '👩🏼‍🔬' => 'ilmuwan wadon: kulit putih langsep',
    '👩🏽‍🔬' => 'ilmuwan wadon: kulit kuning',
    '👩🏾‍🔬' => 'ilmuwan wadon: kulit sawo mateng',
    '👩🏿‍🔬' => 'ilmuwan wadon: kulit ireng',
    '🧑🏻‍💻' => 'ahli teknologi: kulit putih',
    '🧑🏼‍💻' => 'ahli teknologi: kulit putih langsep',
    '🧑🏽‍💻' => 'ahli teknologi: kulit kuning',
    '🧑🏾‍💻' => 'ahli teknologi: kulit sawo mateng',
    '🧑🏿‍💻' => 'ahli teknologi: kulit ireng',
    '👨🏻‍💻' => 'ahli teknologi lanang: kulit putih',
    '👨🏼‍💻' => 'ahli teknologi lanang: kulit putih langsep',
    '👨🏽‍💻' => 'ahli teknologi lanang: kulit kuning',
    '👨🏾‍💻' => 'ahli teknologi lanang: kulit sawo mateng',
    '👨🏿‍💻' => 'ahli teknologi lanang: kulit ireng',
    '👩🏻‍💻' => 'ahli teknologi wadon: kulit putih',
    '👩🏼‍💻' => 'ahli teknologi wadon: kulit putih langsep',
    '👩🏽‍💻' => 'ahli teknologi wadon: kulit kuning',
    '👩🏾‍💻' => 'ahli teknologi wadon: kulit sawo mateng',
    '👩🏿‍💻' => 'ahli teknologi wadon: kulit ireng',
    '🧑🏻‍🎤' => 'biduan: kulit putih',
    '🧑🏼‍🎤' => 'biduan: kulit putih langsep',
    '🧑🏽‍🎤' => 'biduan: kulit kuning',
    '🧑🏾‍🎤' => 'biduan: kulit sawo mateng',
    '🧑🏿‍🎤' => 'biduan: kulit ireng',
    '👨🏻‍🎤' => 'biduan lanang: kulit putih',
    '👨🏼‍🎤' => 'biduan lanang: kulit putih langsep',
    '👨🏽‍🎤' => 'biduan lanang: kulit kuning',
    '👨🏾‍🎤' => 'biduan lanang: kulit sawo mateng',
    '👨🏿‍🎤' => 'biduan lanang: kulit ireng',
    '👩🏻‍🎤' => 'biduan wadon: kulit putih',
    '👩🏼‍🎤' => 'biduan wadon: kulit putih langsep',
    '👩🏽‍🎤' => 'biduan wadon: kulit kuning',
    '👩🏾‍🎤' => 'biduan wadon: kulit sawo mateng',
    '👩🏿‍🎤' => 'biduan wadon: kulit ireng',
    '🧑🏻‍🎨' => 'artis: kulit putih',
    '🧑🏼‍🎨' => 'artis: kulit putih langsep',
    '🧑🏽‍🎨' => 'artis: kulit kuning',
    '🧑🏾‍🎨' => 'artis: kulit sawo mateng',
    '🧑🏿‍🎨' => 'artis: kulit ireng',
    '👨🏻‍🎨' => 'seniman: kulit putih',
    '👨🏼‍🎨' => 'seniman: kulit putih langsep',
    '👨🏽‍🎨' => 'seniman: kulit kuning',
    '👨🏾‍🎨' => 'seniman: kulit sawo mateng',
    '👨🏿‍🎨' => 'seniman: kulit ireng',
    '👩🏻‍🎨' => 'artis wadon: kulit putih',
    '👩🏼‍🎨' => 'artis wadon: kulit putih langsep',
    '👩🏽‍🎨' => 'artis wadon: kulit kuning',
    '👩🏾‍🎨' => 'artis wadon: kulit sawo mateng',
    '👩🏿‍🎨' => 'artis wadon: kulit ireng',
    '🧑🏻‍✈' => 'pilot: kulit putih',
    '🧑🏼‍✈' => 'pilot: kulit putih langsep',
    '🧑🏽‍✈' => 'pilot: kulit kuning',
    '🧑🏾‍✈' => 'pilot: kulit sawo mateng',
    '🧑🏿‍✈' => 'pilot: kulit ireng',
    '👨🏻‍✈' => 'pilot lanang: kulit putih',
    '👨🏼‍✈' => 'pilot lanang: kulit putih langsep',
    '👨🏽‍✈' => 'pilot lanang: kulit kuning',
    '👨🏾‍✈' => 'pilot lanang: kulit sawo mateng',
    '👨🏿‍✈' => 'pilot lanang: kulit ireng',
    '👩🏻‍✈' => 'pilot wadon: kulit putih',
    '👩🏼‍✈' => 'pilot wadon: kulit putih langsep',
    '👩🏽‍✈' => 'pilot wadon: kulit kuning',
    '👩🏾‍✈' => 'pilot wadon: kulit sawo mateng',
    '👩🏿‍✈' => 'pilot wadon: kulit ireng',
    '🧑🏻‍🚀' => 'astronot: kulit putih',
    '🧑🏼‍🚀' => 'astronot: kulit putih langsep',
    '🧑🏽‍🚀' => 'astronot: kulit kuning',
    '🧑🏾‍🚀' => 'astronot: kulit sawo mateng',
    '🧑🏿‍🚀' => 'astronot: kulit ireng',
    '👨🏻‍🚀' => 'astronot lanang: kulit putih',
    '👨🏼‍🚀' => 'astronot lanang: kulit putih langsep',
    '👨🏽‍🚀' => 'astronot lanang: kulit kuning',
    '👨🏾‍🚀' => 'astronot lanang: kulit sawo mateng',
    '👨🏿‍🚀' => 'astronot lanang: kulit ireng',
    '👩🏻‍🚀' => 'astronot wadon: kulit putih',
    '👩🏼‍🚀' => 'astronot wadon: kulit putih langsep',
    '👩🏽‍🚀' => 'astronot wadon: kulit kuning',
    '👩🏾‍🚀' => 'astronot wadon: kulit sawo mateng',
    '👩🏿‍🚀' => 'astronot wadon: kulit ireng',
    '🧑🏻‍🚒' => 'damkar: kulit putih',
    '🧑🏼‍🚒' => 'damkar: kulit putih langsep',
    '🧑🏽‍🚒' => 'damkar: kulit kuning',
    '🧑🏾‍🚒' => 'damkar: kulit sawo mateng',
    '🧑🏿‍🚒' => 'damkar: kulit ireng',
    '👨🏻‍🚒' => 'damkar lanang: kulit putih',
    '👨🏼‍🚒' => 'damkar lanang: kulit putih langsep',
    '👨🏽‍🚒' => 'damkar lanang: kulit kuning',
    '👨🏾‍🚒' => 'damkar lanang: kulit sawo mateng',
    '👨🏿‍🚒' => 'damkar lanang: kulit ireng',
    '👩🏻‍🚒' => 'damkar wadon: kulit putih',
    '👩🏼‍🚒' => 'damkar wadon: kulit putih langsep',
    '👩🏽‍🚒' => 'damkar wadon: kulit kuning',
    '👩🏾‍🚒' => 'damkar wadon: kulit sawo mateng',
    '👩🏿‍🚒' => 'damkar wadon: kulit ireng',
    '👮🏻‍♂' => 'pulisi lanang: kulit putih',
    '👮🏼‍♂' => 'pulisi lanang: kulit putih langsep',
    '👮🏽‍♂' => 'pulisi lanang: kulit kuning',
    '👮🏾‍♂' => 'pulisi lanang: kulit sawo mateng',
    '👮🏿‍♂' => 'pulisi lanang: kulit ireng',
    '👮🏻‍♀' => 'pulisi wadon: kulit putih',
    '👮🏼‍♀' => 'pulisi wadon: kulit putih langsep',
    '👮🏽‍♀' => 'pulisi wadon: kulit kuning',
    '👮🏾‍♀' => 'pulisi wadon: kulit sawo mateng',
    '👮🏿‍♀' => 'pulisi wadon: kulit ireng',
    '🕵🏻‍♂' => 'dhetektif lanang: kulit putih',
    '🕵🏼‍♂' => 'dhetektif lanang: kulit putih langsep',
    '🕵🏽‍♂' => 'dhetektif lanang: kulit kuning',
    '🕵🏾‍♂' => 'dhetektif lanang: kulit sawo mateng',
    '🕵🏿‍♂' => 'dhetektif lanang: kulit ireng',
    '🕵🏻‍♀' => 'dhetektif wadon: kulit putih',
    '🕵🏼‍♀' => 'dhetektif wadon: kulit putih langsep',
    '🕵🏽‍♀' => 'dhetektif wadon: kulit kuning',
    '🕵🏾‍♀' => 'dhetektif wadon: kulit sawo mateng',
    '🕵🏿‍♀' => 'dhetektif wadon: kulit ireng',
    '💂🏻‍♂' => 'panjaga lanang: kulit putih',
    '💂🏼‍♂' => 'panjaga lanang: kulit putih langsep',
    '💂🏽‍♂' => 'panjaga lanang: kulit kuning',
    '💂🏾‍♂' => 'panjaga lanang: kulit sawo mateng',
    '💂🏿‍♂' => 'panjaga lanang: kulit ireng',
    '💂🏻‍♀' => 'prejurit wadon: kulit putih',
    '💂🏼‍♀' => 'prejurit wadon: kulit putih langsep',
    '💂🏽‍♀' => 'prejurit wadon: kulit kuning',
    '💂🏾‍♀' => 'prejurit wadon: kulit sawo mateng',
    '💂🏿‍♀' => 'prejurit wadon: kulit ireng',
    '👷🏻‍♂' => 'buruh bangunan lanang: kulit putih',
    '👷🏼‍♂' => 'buruh bangunan lanang: kulit putih langsep',
    '👷🏽‍♂' => 'buruh bangunan lanang: kulit kuning',
    '👷🏾‍♂' => 'buruh bangunan lanang: kulit sawo mateng',
    '👷🏿‍♂' => 'buruh bangunan lanang: kulit ireng',
    '👷🏻‍♀' => 'buruh bangunan wadon: kulit putih',
    '👷🏼‍♀' => 'buruh bangunan wadon: kulit putih langsep',
    '👷🏽‍♀' => 'buruh bangunan wadon: kulit kuning',
    '👷🏾‍♀' => 'buruh bangunan wadon: kulit sawo mateng',
    '👷🏿‍♀' => 'buruh bangunan wadon: kulit ireng',
    '👳🏻‍♂' => 'wong lanang serbanan: kulit putih',
    '👳🏼‍♂' => 'wong lanang serbanan: kulit putih langsep',
    '👳🏽‍♂' => 'wong lanang serbanan: kulit kuning',
    '👳🏾‍♂' => 'wong lanang serbanan: kulit sawo mateng',
    '👳🏿‍♂' => 'wong lanang serbanan: kulit ireng',
    '👳🏻‍♀' => 'wong wadon serbanan: kulit putih',
    '👳🏼‍♀' => 'wong wadon serbanan: kulit putih langsep',
    '👳🏽‍♀' => 'wong wadon serbanan: kulit kuning',
    '👳🏾‍♀' => 'wong wadon serbanan: kulit sawo mateng',
    '👳🏿‍♀' => 'wong wadon serbanan: kulit ireng',
    '🤵🏻‍♂' => 'wong lanang anganggo jas tuksedo: kulit putih',
    '🤵🏼‍♂' => 'wong lanang anganggo jas tuksedo: kulit putih langsep',
    '🤵🏽‍♂' => 'wong lanang anganggo jas tuksedo: kulit kuning',
    '🤵🏾‍♂' => 'wong lanang anganggo jas tuksedo: kulit sawo mateng',
    '🤵🏿‍♂' => 'wong lanang anganggo jas tuksedo: kulit ireng',
    '🤵🏻‍♀' => 'wong wadon anganggo tuksedo: kulit putih',
    '🤵🏼‍♀' => 'wong wadon anganggo tuksedo: kulit putih langsep',
    '🤵🏽‍♀' => 'wong wadon anganggo tuksedo: kulit kuning',
    '🤵🏾‍♀' => 'wong wadon anganggo tuksedo: kulit sawo mateng',
    '🤵🏿‍♀' => 'wong wadon anganggo tuksedo: kulit ireng',
    '👰🏻‍♂' => 'wong lanang nganggo kudhung manten: kulit putih',
    '👰🏼‍♂' => 'wong lanang nganggo kudhung manten: kulit putih langsep',
    '👰🏽‍♂' => 'wong lanang nganggo kudhung manten: kulit kuning',
    '👰🏾‍♂' => 'wong lanang nganggo kudhung manten: kulit sawo mateng',
    '👰🏿‍♂' => 'wong lanang nganggo kudhung manten: kulit ireng',
    '👰🏻‍♀' => 'wong wadon nganggo kudhung manten: kulit putih',
    '👰🏼‍♀' => 'wong wadon nganggo kudhung manten: kulit putih langsep',
    '👰🏽‍♀' => 'wong wadon nganggo kudhung manten: kulit kuning',
    '👰🏾‍♀' => 'wong wadon nganggo kudhung manten: kulit sawo mateng',
    '👰🏿‍♀' => 'wong wadon nganggo kudhung manten: kulit ireng',
    '👩🏻‍🍼' => 'wong wadon nyusoni bayi: kulit putih',
    '👩🏼‍🍼' => 'wong wadon nyusoni bayi: kulit putih langsep',
    '👩🏽‍🍼' => 'wong wadon nyusoni bayi: kulit kuning',
    '👩🏾‍🍼' => 'wong wadon nyusoni bayi: kulit sawo mateng',
    '👩🏿‍🍼' => 'wong wadon nyusoni bayi: kulit ireng',
    '👨🏻‍🍼' => 'wong lanang nyusoni bayi: kulit putih',
    '👨🏼‍🍼' => 'wong lanang nyusoni bayi: kulit putih langsep',
    '👨🏽‍🍼' => 'wong lanang nyusoni bayi: kulit kuning',
    '👨🏾‍🍼' => 'wong lanang nyusoni bayi: kulit sawo mateng',
    '👨🏿‍🍼' => 'wong lanang nyusoni bayi: kulit ireng',
    '🧑🏻‍🍼' => 'wong nyusoni bayi: kulit putih',
    '🧑🏼‍🍼' => 'wong nyusoni bayi: kulit putih langsep',
    '🧑🏽‍🍼' => 'wong nyusoni bayi: kulit kuning',
    '🧑🏾‍🍼' => 'wong nyusoni bayi: kulit sawo mateng',
    '🧑🏿‍🍼' => 'wong nyusoni bayi: kulit ireng',
    '🧑🏻‍🎄' => 'bapa/ibu klas: kulit putih',
    '🧑🏼‍🎄' => 'bapa/ibu klas: kulit putih langsep',
    '🧑🏽‍🎄' => 'bapa/ibu klas: kulit kuning',
    '🧑🏾‍🎄' => 'bapa/ibu klas: kulit sawo mateng',
    '🧑🏿‍🎄' => 'bapa/ibu klas: kulit ireng',
    '🦸🏻‍♂' => 'satriya mandraguna lanang: kulit putih',
    '🦸🏼‍♂' => 'satriya mandraguna lanang: kulit putih langsep',
    '🦸🏽‍♂' => 'satriya mandraguna lanang: kulit kuning',
    '🦸🏾‍♂' => 'satriya mandraguna lanang: kulit sawo mateng',
    '🦸🏿‍♂' => 'satriya mandraguna lanang: kulit ireng',
    '🦸🏻‍♀' => 'srikandhi: kulit putih',
    '🦸🏼‍♀' => 'srikandhi: kulit putih langsep',
    '🦸🏽‍♀' => 'srikandhi: kulit kuning',
    '🦸🏾‍♀' => 'srikandhi: kulit sawo mateng',
    '🦸🏿‍♀' => 'srikandhi: kulit ireng',
    '🦹🏻‍♂' => 'mungsuh digdaya lanang: kulit putih',
    '🦹🏼‍♂' => 'mungsuh digdaya lanang: kulit putih langsep',
    '🦹🏽‍♂' => 'mungsuh digdaya lanang: kulit kuning',
    '🦹🏾‍♂' => 'mungsuh digdaya lanang: kulit sawo mateng',
    '🦹🏿‍♂' => 'mungsuh digdaya lanang: kulit ireng',
    '🦹🏻‍♀' => 'mungsuh digdaya wadon: kulit putih',
    '🦹🏼‍♀' => 'mungsuh digdaya wadon: kulit putih langsep',
    '🦹🏽‍♀' => 'mungsuh digdaya wadon: kulit kuning',
    '🦹🏾‍♀' => 'mungsuh digdaya wadon: kulit sawo mateng',
    '🦹🏿‍♀' => 'mungsuh digdaya wadon: kulit ireng',
    '🧙🏻‍♂' => 'wong winasis lanang: kulit putih',
    '🧙🏼‍♂' => 'wong winasis lanang: kulit putih langsep',
    '🧙🏽‍♂' => 'wong winasis lanang: kulit kuning',
    '🧙🏾‍♂' => 'wong winasis lanang: kulit sawo mateng',
    '🧙🏿‍♂' => 'wong winasis lanang: kulit ireng',
    '🧙🏻‍♀' => 'wong winasis wadon: kulit putih',
    '🧙🏼‍♀' => 'wong winasis wadon: kulit putih langsep',
    '🧙🏽‍♀' => 'wong winasis wadon: kulit kuning',
    '🧙🏾‍♀' => 'wong winasis wadon: kulit sawo mateng',
    '🧙🏿‍♀' => 'wong winasis wadon: kulit ireng',
    '🧚🏻‍♂' => 'dewa: kulit putih',
    '🧚🏼‍♂' => 'dewa: kulit putih langsep',
    '🧚🏽‍♂' => 'dewa: kulit kuning',
    '🧚🏾‍♂' => 'dewa: kulit sawo mateng',
    '🧚🏿‍♂' => 'dewa: kulit ireng',
    '🧚🏻‍♀' => 'dewi: kulit putih',
    '🧚🏼‍♀' => 'dewi: kulit putih langsep',
    '🧚🏽‍♀' => 'dewi: kulit kuning',
    '🧚🏾‍♀' => 'dewi: kulit sawo mateng',
    '🧚🏿‍♀' => 'dewi: kulit ireng',
    '🧛🏻‍♂' => 'vampir lanang: kulit putih',
    '🧛🏼‍♂' => 'vampir lanang: kulit putih langsep',
    '🧛🏽‍♂' => 'vampir lanang: kulit kuning',
    '🧛🏾‍♂' => 'vampir lanang: kulit sawo mateng',
    '🧛🏿‍♂' => 'vampir lanang: kulit ireng',
    '🧛🏻‍♀' => 'vampir wadon: kulit putih',
    '🧛🏼‍♀' => 'vampir wadon: kulit putih langsep',
    '🧛🏽‍♀' => 'vampir wadon: kulit kuning',
    '🧛🏾‍♀' => 'vampir wadon: kulit sawo mateng',
    '🧛🏿‍♀' => 'vampir wadon: kulit ireng',
    '🧜🏻‍♂' => 'duyung lanang: kulit putih',
    '🧜🏼‍♂' => 'duyung lanang: kulit putih langsep',
    '🧜🏽‍♂' => 'duyung lanang: kulit kuning',
    '🧜🏾‍♂' => 'duyung lanang: kulit sawo mateng',
    '🧜🏿‍♂' => 'duyung lanang: kulit ireng',
    '🧜🏻‍♀' => 'duyung wadon: kulit putih',
    '🧜🏼‍♀' => 'duyung wadon: kulit putih langsep',
    '🧜🏽‍♀' => 'duyung wadon: kulit kuning',
    '🧜🏾‍♀' => 'duyung wadon: kulit sawo mateng',
    '🧜🏿‍♀' => 'duyung wadon: kulit ireng',
    '🧝🏻‍♂' => 'peri lanang: kulit putih',
    '🧝🏼‍♂' => 'peri lanang: kulit putih langsep',
    '🧝🏽‍♂' => 'peri lanang: kulit kuning',
    '🧝🏾‍♂' => 'peri lanang: kulit sawo mateng',
    '🧝🏿‍♂' => 'peri lanang: kulit ireng',
    '🧝🏻‍♀' => 'peri wadon: kulit putih',
    '🧝🏼‍♀' => 'peri wadon: kulit putih langsep',
    '🧝🏽‍♀' => 'peri wadon: kulit kuning',
    '🧝🏾‍♀' => 'peri wadon: kulit sawo mateng',
    '🧝🏿‍♀' => 'peri wadon: kulit ireng',
    '💆🏻‍♂' => 'wong lanang dipijeti: kulit putih',
    '💆🏼‍♂' => 'wong lanang dipijeti: kulit putih langsep',
    '💆🏽‍♂' => 'wong lanang dipijeti: kulit kuning',
    '💆🏾‍♂' => 'wong lanang dipijeti: kulit sawo mateng',
    '💆🏿‍♂' => 'wong lanang dipijeti: kulit ireng',
    '💆🏻‍♀' => 'wong wadon dipijeti: kulit putih',
    '💆🏼‍♀' => 'wong wadon dipijeti: kulit putih langsep',
    '💆🏽‍♀' => 'wong wadon dipijeti: kulit kuning',
    '💆🏾‍♀' => 'wong wadon dipijeti: kulit sawo mateng',
    '💆🏿‍♀' => 'wong wadon dipijeti: kulit ireng',
    '💇🏻‍♂' => 'wong lanang lagi dikethok rambute: kulit putih',
    '💇🏼‍♂' => 'wong lanang lagi dikethok rambute: kulit putih langsep',
    '💇🏽‍♂' => 'wong lanang lagi dikethok rambute: kulit kuning',
    '💇🏾‍♂' => 'wong lanang lagi dikethok rambute: kulit sawo mateng',
    '💇🏿‍♂' => 'wong lanang lagi dikethok rambute: kulit ireng',
    '💇🏻‍♀' => 'wong wadon lagi dikethok rambute: kulit putih',
    '💇🏼‍♀' => 'wong wadon lagi dikethok rambute: kulit putih langsep',
    '💇🏽‍♀' => 'wong wadon lagi dikethok rambute: kulit kuning',
    '💇🏾‍♀' => 'wong wadon lagi dikethok rambute: kulit sawo mateng',
    '💇🏿‍♀' => 'wong wadon lagi dikethok rambute: kulit ireng',
    '🚶🏻‍♂' => 'wong lanang mlaku: kulit putih',
    '🚶🏼‍♂' => 'wong lanang mlaku: kulit putih langsep',
    '🚶🏽‍♂' => 'wong lanang mlaku: kulit kuning',
    '🚶🏾‍♂' => 'wong lanang mlaku: kulit sawo mateng',
    '🚶🏿‍♂' => 'wong lanang mlaku: kulit ireng',
    '🚶🏻‍♀' => 'wong wadon mlaku: kulit putih',
    '🚶🏼‍♀' => 'wong wadon mlaku: kulit putih langsep',
    '🚶🏽‍♀' => 'wong wadon mlaku: kulit kuning',
    '🚶🏾‍♀' => 'wong wadon mlaku: kulit sawo mateng',
    '🚶🏿‍♀' => 'wong wadon mlaku: kulit ireng',
    '🚶🏻‍➡' => 'wong mlaku: kulit putih, madhep tengen',
    '🚶🏼‍➡' => 'wong mlaku: kulit putih langsep, madhep tengen',
    '🚶🏽‍➡' => 'wong mlaku: kulit kuning, madhep tengen',
    '🚶🏾‍➡' => 'wong mlaku: kulit sawo mateng, madhep tengen',
    '🚶🏿‍➡' => 'wong mlaku: kulit ireng, madhep tengen',
    '🧍🏻‍♂' => 'wong lanang ngadeg: kulit putih',
    '🧍🏼‍♂' => 'wong lanang ngadeg: kulit putih langsep',
    '🧍🏽‍♂' => 'wong lanang ngadeg: kulit kuning',
    '🧍🏾‍♂' => 'wong lanang ngadeg: kulit sawo mateng',
    '🧍🏿‍♂' => 'wong lanang ngadeg: kulit ireng',
    '🧍🏻‍♀' => 'wong wadon ngadeg: kulit putih',
    '🧍🏼‍♀' => 'wong wadon ngadeg: kulit putih langsep',
    '🧍🏽‍♀' => 'wong wadon ngadeg: kulit kuning',
    '🧍🏾‍♀' => 'wong wadon ngadeg: kulit sawo mateng',
    '🧍🏿‍♀' => 'wong wadon ngadeg: kulit ireng',
    '🧎🏻‍♂' => 'wong lanang timpuh: kulit putih',
    '🧎🏼‍♂' => 'wong lanang timpuh: kulit putih langsep',
    '🧎🏽‍♂' => 'wong lanang timpuh: kulit kuning',
    '🧎🏾‍♂' => 'wong lanang timpuh: kulit sawo mateng',
    '🧎🏿‍♂' => 'wong lanang timpuh: kulit ireng',
    '🧎🏻‍♀' => 'wong wadon timpuh: kulit putih',
    '🧎🏼‍♀' => 'wong wadon timpuh: kulit putih langsep',
    '🧎🏽‍♀' => 'wong wadon timpuh: kulit kuning',
    '🧎🏾‍♀' => 'wong wadon timpuh: kulit sawo mateng',
    '🧎🏿‍♀' => 'wong wadon timpuh: kulit ireng',
    '🧎🏻‍➡' => 'wong timpuh: kulit putih, madhep tengen',
    '🧎🏼‍➡' => 'wong timpuh: kulit putih langsep, madhep tengen',
    '🧎🏽‍➡' => 'wong timpuh: kulit kuning, madhep tengen',
    '🧎🏾‍➡' => 'wong timpuh: kulit sawo mateng, madhep tengen',
    '🧎🏿‍➡' => 'wong timpuh: kulit ireng, madhep tengen',
    '🧑🏻‍🦯' => 'wong nyekeli teken: kulit putih',
    '🧑🏼‍🦯' => 'wong nyekeli teken: kulit putih langsep',
    '🧑🏽‍🦯' => 'wong nyekeli teken: kulit kuning',
    '🧑🏾‍🦯' => 'wong nyekeli teken: kulit sawo mateng',
    '🧑🏿‍🦯' => 'wong nyekeli teken: kulit ireng',
    '👨🏻‍🦯' => 'wong lanang nyekeli teken: kulit putih',
    '👨🏼‍🦯' => 'wong lanang nyekeli teken: kulit putih langsep',
    '👨🏽‍🦯' => 'wong lanang nyekeli teken: kulit kuning',
    '👨🏾‍🦯' => 'wong lanang nyekeli teken: kulit sawo mateng',
    '👨🏿‍🦯' => 'wong lanang nyekeli teken: kulit ireng',
    '👩🏻‍🦯' => 'wong wadon nyekeli teken: kulit putih',
    '👩🏼‍🦯' => 'wong wadon nyekeli teken: kulit putih langsep',
    '👩🏽‍🦯' => 'wong wadon nyekeli teken: kulit kuning',
    '👩🏾‍🦯' => 'wong wadon nyekeli teken: kulit sawo mateng',
    '👩🏿‍🦯' => 'wong wadon nyekeli teken: kulit ireng',
    '🧑🏻‍🦼' => 'wong numpak kursi rodha mesin: kulit putih',
    '🧑🏼‍🦼' => 'wong numpak kursi rodha mesin: kulit putih langsep',
    '🧑🏽‍🦼' => 'wong numpak kursi rodha mesin: kulit kuning',
    '🧑🏾‍🦼' => 'wong numpak kursi rodha mesin: kulit sawo mateng',
    '🧑🏿‍🦼' => 'wong numpak kursi rodha mesin: kulit ireng',
    '👨🏻‍🦼' => 'wong lanang numpak kursi rodha mesin: kulit putih',
    '👨🏼‍🦼' => 'wong lanang numpak kursi rodha mesin: kulit putih langsep',
    '👨🏽‍🦼' => 'wong lanang numpak kursi rodha mesin: kulit kuning',
    '👨🏾‍🦼' => 'wong lanang numpak kursi rodha mesin: kulit sawo mateng',
    '👨🏿‍🦼' => 'wong lanang numpak kursi rodha mesin: kulit ireng',
    '👩🏻‍🦼' => 'wong wadon numpak kursi rodha mesin: kulit putih',
    '👩🏼‍🦼' => 'wong wadon numpak kursi rodha mesin: kulit putih langsep',
    '👩🏽‍🦼' => 'wong wadon numpak kursi rodha mesin: kulit kuning',
    '👩🏾‍🦼' => 'wong wadon numpak kursi rodha mesin: kulit sawo mateng',
    '👩🏿‍🦼' => 'wong wadon numpak kursi rodha mesin: kulit ireng',
    '🧑🏻‍🦽' => 'wong numpak kursi rodha manual: kulit putih',
    '🧑🏼‍🦽' => 'wong numpak kursi rodha manual: kulit putih langsep',
    '🧑🏽‍🦽' => 'wong numpak kursi rodha manual: kulit kuning',
    '🧑🏾‍🦽' => 'wong numpak kursi rodha manual: kulit sawo mateng',
    '🧑🏿‍🦽' => 'wong numpak kursi rodha manual: kulit ireng',
    '👨🏻‍🦽' => 'wong lanang numpak kursi rodha manual: kulit putih',
    '👨🏼‍🦽' => 'wong lanang numpak kursi rodha manual: kulit putih langsep',
    '👨🏽‍🦽' => 'wong lanang numpak kursi rodha manual: kulit kuning',
    '👨🏾‍🦽' => 'wong lanang numpak kursi rodha manual: kulit sawo mateng',
    '👨🏿‍🦽' => 'wong lanang numpak kursi rodha manual: kulit ireng',
    '👩🏻‍🦽' => 'wong wadon numpak kursi rodha manual: kulit putih',
    '👩🏼‍🦽' => 'wong wadon numpak kursi rodha manual: kulit putih langsep',
    '👩🏽‍🦽' => 'wong wadon numpak kursi rodha manual: kulit kuning',
    '👩🏾‍🦽' => 'wong wadon numpak kursi rodha manual: kulit sawo mateng',
    '👩🏿‍🦽' => 'wong wadon numpak kursi rodha manual: kulit ireng',
    '🏃🏻‍♂' => 'wong lanang mlayu: kulit putih',
    '🏃🏼‍♂' => 'wong lanang mlayu: kulit putih langsep',
    '🏃🏽‍♂' => 'wong lanang mlayu: kulit kuning',
    '🏃🏾‍♂' => 'wong lanang mlayu: kulit sawo mateng',
    '🏃🏿‍♂' => 'wong lanang mlayu: kulit ireng',
    '🏃🏻‍♀' => 'wong wadon mlayu: kulit putih',
    '🏃🏼‍♀' => 'wong wadon mlayu: kulit putih langsep',
    '🏃🏽‍♀' => 'wong wadon mlayu: kulit kuning',
    '🏃🏾‍♀' => 'wong wadon mlayu: kulit sawo mateng',
    '🏃🏿‍♀' => 'wong wadon mlayu: kulit ireng',
    '🏃🏻‍➡' => 'wong mlayu: kulit putih, madhep tengen',
    '🏃🏼‍➡' => 'wong mlayu: kulit putih langsep, madhep tengen',
    '🏃🏽‍➡' => 'wong mlayu: kulit kuning, madhep tengen',
    '🏃🏾‍➡' => 'wong mlayu: kulit sawo mateng, madhep tengen',
    '🏃🏿‍➡' => 'wong mlayu: kulit ireng, madhep tengen',
    '👯🏻‍♀' => 'wong wadon nganggo kuping terwelu: kulit putih',
    '👯🏼‍♀' => 'wong wadon nganggo kuping terwelu: kulit putih langsep',
    '👯🏽‍♀' => 'wong wadon nganggo kuping terwelu: kulit kuning',
    '👯🏾‍♀' => 'wong wadon nganggo kuping terwelu: kulit sawo mateng',
    '👯🏿‍♀' => 'wong wadon nganggo kuping terwelu: kulit ireng',
    '👯🏻‍♂' => 'wong lanang nganggo kuping terwelu: kulit putih',
    '👯🏼‍♂' => 'wong lanang nganggo kuping terwelu: kulit putih langsep',
    '👯🏽‍♂' => 'wong lanang nganggo kuping terwelu: kulit kuning',
    '👯🏾‍♂' => 'wong lanang nganggo kuping terwelu: kulit sawo mateng',
    '👯🏿‍♂' => 'wong lanang nganggo kuping terwelu: kulit ireng',
    '🧖🏻‍♂' => 'wong lanang ing kamar kebak sumub: kulit putih',
    '🧖🏼‍♂' => 'wong lanang ing kamar kebak sumub: kulit putih langsep',
    '🧖🏽‍♂' => 'wong lanang ing kamar kebak sumub: kulit kuning',
    '🧖🏾‍♂' => 'wong lanang ing kamar kebak sumub: kulit sawo mateng',
    '🧖🏿‍♂' => 'wong lanang ing kamar kebak sumub: kulit ireng',
    '🧖🏻‍♀' => 'wong wadon ing kamar kebak sumub: kulit putih',
    '🧖🏼‍♀' => 'wong wadon ing kamar kebak sumub: kulit putih langsep',
    '🧖🏽‍♀' => 'wong wadon ing kamar kebak sumub: kulit kuning',
    '🧖🏾‍♀' => 'wong wadon ing kamar kebak sumub: kulit sawo mateng',
    '🧖🏿‍♀' => 'wong wadon ing kamar kebak sumub: kulit ireng',
    '🧗🏻‍♂' => 'wong lanang manjad: kulit putih',
    '🧗🏼‍♂' => 'wong lanang manjad: kulit putih langsep',
    '🧗🏽‍♂' => 'wong lanang manjad: kulit kuning',
    '🧗🏾‍♂' => 'wong lanang manjad: kulit sawo mateng',
    '🧗🏿‍♂' => 'wong lanang manjad: kulit ireng',
    '🧗🏻‍♀' => 'wong wadon manjad: kulit putih',
    '🧗🏼‍♀' => 'wong wadon manjad: kulit putih langsep',
    '🧗🏽‍♀' => 'wong wadon manjad: kulit kuning',
    '🧗🏾‍♀' => 'wong wadon manjad: kulit sawo mateng',
    '🧗🏿‍♀' => 'wong wadon manjad: kulit ireng',
    '🏌🏻‍♂' => 'wong lanang main golf: kulit putih',
    '🏌🏼‍♂' => 'wong lanang main golf: kulit putih langsep',
    '🏌🏽‍♂' => 'wong lanang main golf: kulit kuning',
    '🏌🏾‍♂' => 'wong lanang main golf: kulit sawo mateng',
    '🏌🏿‍♂' => 'wong lanang main golf: kulit ireng',
    '🏌🏻‍♀' => 'wong wadon main golf: kulit putih',
    '🏌🏼‍♀' => 'wong wadon main golf: kulit putih langsep',
    '🏌🏽‍♀' => 'wong wadon main golf: kulit kuning',
    '🏌🏾‍♀' => 'wong wadon main golf: kulit sawo mateng',
    '🏌🏿‍♀' => 'wong wadon main golf: kulit ireng',
    '🏄🏻‍♂' => 'wong lanang slancar: kulit putih',
    '🏄🏼‍♂' => 'wong lanang slancar: kulit putih langsep',
    '🏄🏽‍♂' => 'wong lanang slancar: kulit kuning',
    '🏄🏾‍♂' => 'wong lanang slancar: kulit sawo mateng',
    '🏄🏿‍♂' => 'wong lanang slancar: kulit ireng',
    '🏄🏻‍♀' => 'wong wadon slancar: kulit putih',
    '🏄🏼‍♀' => 'wong wadon slancar: kulit putih langsep',
    '🏄🏽‍♀' => 'wong wadon slancar: kulit kuning',
    '🏄🏾‍♀' => 'wong wadon slancar: kulit sawo mateng',
    '🏄🏿‍♀' => 'wong wadon slancar: kulit ireng',
    '🚣🏻‍♂' => 'wong lanang ndhayung: kulit putih',
    '🚣🏼‍♂' => 'wong lanang ndhayung: kulit putih langsep',
    '🚣🏽‍♂' => 'wong lanang ndhayung: kulit kuning',
    '🚣🏾‍♂' => 'wong lanang ndhayung: kulit sawo mateng',
    '🚣🏿‍♂' => 'wong lanang ndhayung: kulit ireng',
    '🚣🏻‍♀' => 'wong wadon ndhayung: kulit putih',
    '🚣🏼‍♀' => 'wong wadon ndhayung: kulit putih langsep',
    '🚣🏽‍♀' => 'wong wadon ndhayung: kulit kuning',
    '🚣🏾‍♀' => 'wong wadon ndhayung: kulit sawo mateng',
    '🚣🏿‍♀' => 'wong wadon ndhayung: kulit ireng',
    '🏊🏻‍♂' => 'wong lanang nglangi: kulit putih',
    '🏊🏼‍♂' => 'wong lanang nglangi: kulit putih langsep',
    '🏊🏽‍♂' => 'wong lanang nglangi: kulit kuning',
    '🏊🏾‍♂' => 'wong lanang nglangi: kulit sawo mateng',
    '🏊🏿‍♂' => 'wong lanang nglangi: kulit ireng',
    '🏊🏻‍♀' => 'wong wadon nglangi: kulit putih',
    '🏊🏼‍♀' => 'wong wadon nglangi: kulit putih langsep',
    '🏊🏽‍♀' => 'wong wadon nglangi: kulit kuning',
    '🏊🏾‍♀' => 'wong wadon nglangi: kulit sawo mateng',
    '🏊🏿‍♀' => 'wong wadon nglangi: kulit ireng',
    '⛹🏻‍♂' => 'wong lanang mentulake bal: kulit putih',
    '⛹🏼‍♂' => 'wong lanang mentulake bal: kulit putih langsep',
    '⛹🏽‍♂' => 'wong lanang mentulake bal: kulit kuning',
    '⛹🏾‍♂' => 'wong lanang mentulake bal: kulit sawo mateng',
    '⛹🏿‍♂' => 'wong lanang mentulake bal: kulit ireng',
    '⛹🏻‍♀' => 'wong wadon mentulake bal: kulit putih',
    '⛹🏼‍♀' => 'wong wadon mentulake bal: kulit putih langsep',
    '⛹🏽‍♀' => 'wong wadon mentulake bal: kulit kuning',
    '⛹🏾‍♀' => 'wong wadon mentulake bal: kulit sawo mateng',
    '⛹🏿‍♀' => 'wong wadon mentulake bal: kulit ireng',
    '🏋🏻‍♂' => 'wong lanang ngangkat barbel: kulit putih',
    '🏋🏼‍♂' => 'wong lanang ngangkat barbel: kulit putih langsep',
    '🏋🏽‍♂' => 'wong lanang ngangkat barbel: kulit kuning',
    '🏋🏾‍♂' => 'wong lanang ngangkat barbel: kulit sawo mateng',
    '🏋🏿‍♂' => 'wong lanang ngangkat barbel: kulit ireng',
    '🏋🏻‍♀' => 'wong wadon ngangkat barbel: kulit putih',
    '🏋🏼‍♀' => 'wong wadon ngangkat barbel: kulit putih langsep',
    '🏋🏽‍♀' => 'wong wadon ngangkat barbel: kulit kuning',
    '🏋🏾‍♀' => 'wong wadon ngangkat barbel: kulit sawo mateng',
    '🏋🏿‍♀' => 'wong wadon ngangkat barbel: kulit ireng',
    '🚴🏻‍♂' => 'wong lanang numpak pit: kulit putih',
    '🚴🏼‍♂' => 'wong lanang numpak pit: kulit putih langsep',
    '🚴🏽‍♂' => 'wong lanang numpak pit: kulit kuning',
    '🚴🏾‍♂' => 'wong lanang numpak pit: kulit sawo mateng',
    '🚴🏿‍♂' => 'wong lanang numpak pit: kulit ireng',
    '🚴🏻‍♀' => 'wong wadon numpak pit: kulit putih',
    '🚴🏼‍♀' => 'wong wadon numpak pit: kulit putih langsep',
    '🚴🏽‍♀' => 'wong wadon numpak pit: kulit kuning',
    '🚴🏾‍♀' => 'wong wadon numpak pit: kulit sawo mateng',
    '🚴🏿‍♀' => 'wong wadon numpak pit: kulit ireng',
    '🚵🏻‍♂' => 'wong lanang numpak sepedha gunung: kulit putih',
    '🚵🏼‍♂' => 'wong lanang numpak sepedha gunung: kulit putih langsep',
    '🚵🏽‍♂' => 'wong lanang numpak sepedha gunung: kulit kuning',
    '🚵🏾‍♂' => 'wong lanang numpak sepedha gunung: kulit sawo mateng',
    '🚵🏿‍♂' => 'wong lanang numpak sepedha gunung: kulit ireng',
    '🚵🏻‍♀' => 'wong wadon numpak sepedha gunung: kulit putih',
    '🚵🏼‍♀' => 'wong wadon numpak sepedha gunung: kulit putih langsep',
    '🚵🏽‍♀' => 'wong wadon numpak sepedha gunung: kulit kuning',
    '🚵🏾‍♀' => 'wong wadon numpak sepedha gunung: kulit sawo mateng',
    '🚵🏿‍♀' => 'wong wadon numpak sepedha gunung: kulit ireng',
    '🤸🏻‍♂' => 'wong lanang engkang: kulit putih',
    '🤸🏼‍♂' => 'wong lanang engkang: kulit putih langsep',
    '🤸🏽‍♂' => 'wong lanang engkang: kulit kuning',
    '🤸🏾‍♂' => 'wong lanang engkang: kulit sawo mateng',
    '🤸🏿‍♂' => 'wong lanang engkang: kulit ireng',
    '🤸🏻‍♀' => 'wong wadon engkang: kulit putih',
    '🤸🏼‍♀' => 'wong wadon engkang: kulit putih langsep',
    '🤸🏽‍♀' => 'wong wadon engkang: kulit kuning',
    '🤸🏾‍♀' => 'wong wadon engkang: kulit sawo mateng',
    '🤸🏿‍♀' => 'wong wadon engkang: kulit ireng',
    '🤼🏻‍♀' => 'wong wadon gulat: kulit putih',
    '🤼🏼‍♀' => 'wong wadon gulat: kulit putih langsep',
    '🤼🏽‍♀' => 'wong wadon gulat: kulit kuning',
    '🤼🏾‍♀' => 'wong wadon gulat: kulit sawo mateng',
    '🤼🏿‍♀' => 'wong wadon gulat: kulit ireng',
    '🤼🏻‍♂' => 'wong lanang gulat: kulit putih',
    '🤼🏼‍♂' => 'wong lanang gulat: kulit putih langsep',
    '🤼🏽‍♂' => 'wong lanang gulat: kulit kuning',
    '🤼🏾‍♂' => 'wong lanang gulat: kulit sawo mateng',
    '🤼🏿‍♂' => 'wong lanang gulat: kulit ireng',
    '🤽🏻‍♂' => 'wong lanang main polo banyu: kulit putih',
    '🤽🏼‍♂' => 'wong lanang main polo banyu: kulit putih langsep',
    '🤽🏽‍♂' => 'wong lanang main polo banyu: kulit kuning',
    '🤽🏾‍♂' => 'wong lanang main polo banyu: kulit sawo mateng',
    '🤽🏿‍♂' => 'wong lanang main polo banyu: kulit ireng',
    '🤽🏻‍♀' => 'wong wadon main polo banyu: kulit putih',
    '🤽🏼‍♀' => 'wong wadon main polo banyu: kulit putih langsep',
    '🤽🏽‍♀' => 'wong wadon main polo banyu: kulit kuning',
    '🤽🏾‍♀' => 'wong wadon main polo banyu: kulit sawo mateng',
    '🤽🏿‍♀' => 'wong wadon main polo banyu: kulit ireng',
    '🤾🏻‍♂' => 'wong lanang main bal tangan: kulit putih',
    '🤾🏼‍♂' => 'wong lanang main bal tangan: kulit putih langsep',
    '🤾🏽‍♂' => 'wong lanang main bal tangan: kulit kuning',
    '🤾🏾‍♂' => 'wong lanang main bal tangan: kulit sawo mateng',
    '🤾🏿‍♂' => 'wong lanang main bal tangan: kulit ireng',
    '🤾🏻‍♀' => 'wong wadon main bal tangan: kulit putih',
    '🤾🏼‍♀' => 'wong wadon main bal tangan: kulit putih langsep',
    '🤾🏽‍♀' => 'wong wadon main bal tangan: kulit kuning',
    '🤾🏾‍♀' => 'wong wadon main bal tangan: kulit sawo mateng',
    '🤾🏿‍♀' => 'wong wadon main bal tangan: kulit ireng',
    '🤹🏻‍♂' => 'wong lanang main akrobat bal: kulit putih',
    '🤹🏼‍♂' => 'wong lanang main akrobat bal: kulit putih langsep',
    '🤹🏽‍♂' => 'wong lanang main akrobat bal: kulit kuning',
    '🤹🏾‍♂' => 'wong lanang main akrobat bal: kulit sawo mateng',
    '🤹🏿‍♂' => 'wong lanang main akrobat bal: kulit ireng',
    '🤹🏻‍♀' => 'wong wadon main akrobat bal: kulit putih',
    '🤹🏼‍♀' => 'wong wadon main akrobat bal: kulit putih langsep',
    '🤹🏽‍♀' => 'wong wadon main akrobat bal: kulit kuning',
    '🤹🏾‍♀' => 'wong wadon main akrobat bal: kulit sawo mateng',
    '🤹🏿‍♀' => 'wong wadon main akrobat bal: kulit ireng',
    '🧘🏻‍♂' => 'wong lanang njagong sila: kulit putih',
    '🧘🏼‍♂' => 'wong lanang njagong sila: kulit putih langsep',
    '🧘🏽‍♂' => 'wong lanang njagong sila: kulit kuning',
    '🧘🏾‍♂' => 'wong lanang njagong sila: kulit sawo mateng',
    '🧘🏿‍♂' => 'wong lanang njagong sila: kulit ireng',
    '🧘🏻‍♀' => 'wong wadon njagong sila: kulit putih',
    '🧘🏼‍♀' => 'wong wadon njagong sila: kulit putih langsep',
    '🧘🏽‍♀' => 'wong wadon njagong sila: kulit kuning',
    '🧘🏾‍♀' => 'wong wadon njagong sila: kulit sawo mateng',
    '🧘🏿‍♀' => 'wong wadon njagong sila: kulit ireng',
    '🧑‍🦰' => 'wong: rambut abang',
    '🧑‍🦱' => 'wong: rambut brintik',
    '🧑‍🦳' => 'wong: rambut putih',
    '🧑‍🦲' => 'wong: buthak',
    '👨‍🦰' => 'wong lanang: rambut abang',
    '👨‍🦱' => 'wong lanang: rambut brintik',
    '👨‍🦳' => 'wong lanang: rambut putih',
    '👨‍🦲' => 'wong lanang: buthak',
    '👩‍🦰' => 'wong wadon: rambut abang',
    '👩‍🦱' => 'wong wadon: rambut brintik',
    '👩‍🦳' => 'wong wadon: rambut putih',
    '👩‍🦲' => 'wong wadon: buthak',
    '🚶‍➡' => 'wong mlaku: madhep tengen',
    '🧎‍➡' => 'wong timpuh: madhep tengen',
    '🏃‍➡' => 'wong mlayu: madhep tengen',
    '👨‍👦' => 'kluwarga: wong lanang, bocah lanang',
    '👨‍👧' => 'kluwarga: wong lanang, bocah wadon',
    '👩‍👦' => 'kluwarga: wong wadon, bocah lanang',
    '👩‍👧' => 'kluwarga: wong wadon, bocah wadon',
    '😶‍🌫' => 'rai ora dong',
    '😮‍💨' => 'rai ambegan lego',
    '🙂‍↕' => 'manthuk',
    '😵‍💫' => 'rai ngelu',
    '❤‍🔥' => 'ati kasmaran',
    '❤‍🩹' => 'ndandani ati',
    '👁‍🗨' => 'mata ing njero balon omongan',
    '🧔‍♂' => 'wong lanang: jenggot',
    '👱‍♂' => 'wong lanang: rambut pirang',
    '🧔‍♀' => 'wong wadon: jenggot',
    '👱‍♀' => 'wong wadon: rambut pirang',
    '🙍‍♂' => 'wong lanang sedhih',
    '🙍‍♀' => 'wong wadon sedhih',
    '🙎‍♂' => 'wong lanang mbesengut',
    '🙎‍♀' => 'wong wadon mbesengut',
    '🙅‍♂' => 'wong lanang ngisaratake AJA',
    '🙅‍♀' => 'wong wadon menehi isarat AJA',
    '🙆‍♂' => 'wong lanang ngisaratake OK',
    '🙆‍♀' => 'wong wadon ngisaratake OK',
    '💁‍♂' => 'wong lanang tangane anyangga',
    '💁‍♀' => 'wong wadon tangane anyangga',
    '🙋‍♂' => 'wong lanang ngacungake tangan',
    '🙋‍♀' => 'wong wadon ngacungake tangan',
    '🧏‍♂' => 'wong lanang budheg',
    '🧏‍♀' => 'wong wadon budheg',
    '🙇‍♂' => 'wong lanang mbungkuk ngurmati',
    '🙇‍♀' => 'wong wadon mbungkuk ngurmati',
    '🤦‍♂' => 'wong lanang anutup raine mawa dlamakan',
    '🤦‍♀' => 'wong wadon anutup raine mawa dlamakan',
    '🤷‍♂' => 'wong lanang angangkat pundhak',
    '🤷‍♀' => 'wong wadon ngangkat pundhak',
    '🧑‍⚕' => 'mantri',
    '👨‍⚕' => 'mantri lanang',
    '👩‍⚕' => 'mantri wadon',
    '🧑‍🎓' => 'mahasiswa',
    '👨‍🎓' => 'mahasiswa lanang',
    '👩‍🎓' => 'mahasiswa wadon',
    '🧑‍🏫' => 'guru',
    '👨‍🏫' => 'guru lanang',
    '👩‍🏫' => 'guru wadon',
    '🧑‍⚖' => 'hakim',
    '👨‍⚖' => 'hakim lanang',
    '👩‍⚖' => 'hakim wadon',
    '🧑‍🌾' => 'tani',
    '👨‍🌾' => 'pak tani',
    '👩‍🌾' => 'bu tani',
    '🧑‍🍳' => 'mangsak',
    '👨‍🍳' => 'koki lanang',
    '👩‍🍳' => 'koki wadon',
    '🧑‍🔧' => 'montir',
    '👨‍🔧' => 'montir lanang',
    '👩‍🔧' => 'montir wadon',
    '🧑‍🏭' => 'buruh pabrik',
    '👨‍🏭' => 'buruh pabrik lanang',
    '👩‍🏭' => 'buruh pabrik wadon',
    '🧑‍💼' => 'pegawe',
    '👨‍💼' => 'pegawe kantor lanang',
    '👩‍💼' => 'pegawe kantor wadon',
    '🧑‍🔬' => 'ilmuwan',
    '👨‍🔬' => 'ilmuwan lanang',
    '👩‍🔬' => 'ilmuwan wadon',
    '🧑‍💻' => 'ahli teknologi',
    '👨‍💻' => 'ahli teknologi lanang',
    '👩‍💻' => 'ahli teknologi wadon',
    '🧑‍🎤' => 'biduan',
    '👨‍🎤' => 'biduan lanang',
    '👩‍🎤' => 'biduan wadon',
    '🧑‍🎨' => 'artis',
    '👨‍🎨' => 'seniman',
    '👩‍🎨' => 'artis wadon',
    '🧑‍✈' => 'pilot',
    '👨‍✈' => 'pilot lanang',
    '👩‍✈' => 'pilot wadon',
    '🧑‍🚀' => 'astronot',
    '👨‍🚀' => 'astronot lanang',
    '👩‍🚀' => 'astronot wadon',
    '🧑‍🚒' => 'damkar',
    '👨‍🚒' => 'damkar lanang',
    '👩‍🚒' => 'damkar wadon',
    '👮‍♂' => 'pulisi lanang',
    '👮‍♀' => 'pulisi wadon',
    '🕵‍♂' => 'dhetektif lanang',
    '🕵‍♀' => 'dhetektif wadon',
    '💂‍♂' => 'panjaga lanang',
    '💂‍♀' => 'prejurit wadon',
    '👷‍♂' => 'buruh bangunan lanang',
    '👷‍♀' => 'buruh bangunan wadon',
    '👳‍♂' => 'wong lanang serbanan',
    '👳‍♀' => 'wong wadon serbanan',
    '🤵‍♂' => 'wong lanang anganggo jas tuksedo',
    '🤵‍♀' => 'wong wadon anganggo tuksedo',
    '👰‍♂' => 'wong lanang nganggo kudhung manten',
    '👰‍♀' => 'wong wadon nganggo kudhung manten',
    '👩‍🍼' => 'wong wadon nyusoni bayi',
    '👨‍🍼' => 'wong lanang nyusoni bayi',
    '🧑‍🍼' => 'wong nyusoni bayi',
    '🧑‍🎄' => 'bapa/ibu klas',
    '🦸‍♂' => 'satriya mandraguna lanang',
    '🦸‍♀' => 'srikandhi',
    '🦹‍♂' => 'mungsuh digdaya lanang',
    '🦹‍♀' => 'mungsuh digdaya wadon',
    '🧙‍♂' => 'wong winasis lanang',
    '🧙‍♀' => 'wong winasis wadon',
    '🧚‍♂' => 'dewa',
    '🧚‍♀' => 'dewi',
    '🧛‍♂' => 'vampir lanang',
    '🧛‍♀' => 'vampir wadon',
    '🧜‍♂' => 'duyung lanang',
    '🧜‍♀' => 'duyung wadon',
    '🧝‍♂' => 'peri lanang',
    '🧝‍♀' => 'peri wadon',
    '🧞‍♂' => 'jim lanang',
    '🧞‍♀' => 'jim wadon',
    '🧟‍♂' => 'zombi lanang',
    '🧟‍♀' => 'zombi wadon',
    '💆‍♂' => 'wong lanang dipijeti',
    '💆‍♀' => 'wong wadon dipijeti',
    '💇‍♂' => 'wong lanang lagi dikethok rambute',
    '💇‍♀' => 'wong wadon lagi dikethok rambute',
    '🚶‍♂' => 'wong lanang mlaku',
    '🚶‍♀' => 'wong wadon mlaku',
    '🧍‍♂' => 'wong lanang ngadeg',
    '🧍‍♀' => 'wong wadon ngadeg',
    '🧎‍♂' => 'wong lanang timpuh',
    '🧎‍♀' => 'wong wadon timpuh',
    '🧑‍🦯' => 'wong nyekeli teken',
    '👨‍🦯' => 'wong lanang nyekeli teken',
    '👩‍🦯' => 'wong wadon nyekeli teken',
    '🧑‍🦼' => 'wong numpak kursi rodha mesin',
    '👨‍🦼' => 'wong lanang numpak kursi rodha mesin',
    '👩‍🦼' => 'wong wadon numpak kursi rodha mesin',
    '🧑‍🦽' => 'wong numpak kursi rodha manual',
    '👨‍🦽' => 'wong lanang numpak kursi rodha manual',
    '👩‍🦽' => 'wong wadon numpak kursi rodha manual',
    '🏃‍♂' => 'wong lanang mlayu',
    '🏃‍♀' => 'wong wadon mlayu',
    '🧑‍🩰' => 'penari balet',
    '👯‍♂' => 'wong lanang nganggo kuping terwelu',
    '👯‍♀' => 'wong wadon nganggo kuping terwelu',
    '🧖‍♂' => 'wong lanang ing kamar kebak sumub',
    '🧖‍♀' => 'wong wadon ing kamar kebak sumub',
    '🧗‍♂' => 'wong lanang manjad',
    '🧗‍♀' => 'wong wadon manjad',
    '🏌‍♂' => 'wong lanang main golf',
    '🏌‍♀' => 'wong wadon main golf',
    '🏄‍♂' => 'wong lanang slancar',
    '🏄‍♀' => 'wong wadon slancar',
    '🚣‍♂' => 'wong lanang ndhayung',
    '🚣‍♀' => 'wong wadon ndhayung',
    '🏊‍♂' => 'wong lanang nglangi',
    '🏊‍♀' => 'wong wadon nglangi',
    '⛹‍♂' => 'wong lanang mentulake bal',
    '⛹‍♀' => 'wong wadon mentulake bal',
    '🏋‍♂' => 'wong lanang ngangkat barbel',
    '🏋‍♀' => 'wong wadon ngangkat barbel',
    '🚴‍♂' => 'wong lanang numpak pit',
    '🚴‍♀' => 'wong wadon numpak pit',
    '🚵‍♂' => 'wong lanang numpak sepedha gunung',
    '🚵‍♀' => 'wong wadon numpak sepedha gunung',
    '🤸‍♂' => 'wong lanang engkang',
    '🤸‍♀' => 'wong wadon engkang',
    '🤼‍♂' => 'wong lanang gulat',
    '🤼‍♀' => 'wong wadon gulat',
    '🤽‍♂' => 'wong lanang main polo banyu',
    '🤽‍♀' => 'wong wadon main polo banyu',
    '🤾‍♂' => 'wong lanang main bal tangan',
    '🤾‍♀' => 'wong wadon main bal tangan',
    '🤹‍♂' => 'wong lanang main akrobat bal',
    '🤹‍♀' => 'wong wadon main akrobat bal',
    '🧘‍♂' => 'wong lanang njagong sila',
    '🧘‍♀' => 'wong wadon njagong sila',
    '🧑‍🧒' => 'kulawarga: diwasa, anak',
    '🐕‍🦺' => 'asu layanan',
    '🐈‍⬛' => 'kucing ireng',
    '🐻‍❄' => 'beruang kutub',
    '🐦‍⬛' => 'manuk ireng',
    '🐦‍🔥' => 'foniks',
    '🍋‍🟩' => 'jeruk nipis',
    '🍄‍🟫' => 'jamur soklat',
    '⛓‍💥' => 'rante pedhot',
    '🏳‍🌈' => 'gendera plangi',
    '🏳‍⚧' => 'gendera wariya',
    '🏴‍☠' => 'gendera begal segara',
    '👋🏻' => 'tangan ngawe-awe: kulit putih',
    '👋🏼' => 'tangan ngawe-awe: kulit putih langsep',
    '👋🏽' => 'tangan ngawe-awe: kulit kuning',
    '👋🏾' => 'tangan ngawe-awe: kulit sawo mateng',
    '👋🏿' => 'tangan ngawe-awe: kulit ireng',
    '🤚🏻' => 'tangan diangkat nuduhake gegere bae: kulit putih',
    '🤚🏼' => 'tangan diangkat nuduhake gegere bae: kulit putih langsep',
    '🤚🏽' => 'tangan diangkat nuduhake gegere bae: kulit kuning',
    '🤚🏾' => 'tangan diangkat nuduhake gegere bae: kulit sawo mateng',
    '🤚🏿' => 'tangan diangkat nuduhake gegere bae: kulit ireng',
    '🖐🏻' => 'tangan sing driji-drijine megar: kulit putih',
    '🖐🏼' => 'tangan sing driji-drijine megar: kulit putih langsep',
    '🖐🏽' => 'tangan sing driji-drijine megar: kulit kuning',
    '🖐🏾' => 'tangan sing driji-drijine megar: kulit sawo mateng',
    '🖐🏿' => 'tangan sing driji-drijine megar: kulit ireng',
    '✋🏻' => 'tangan diangkat: kulit putih',
    '✋🏼' => 'tangan diangkat: kulit putih langsep',
    '✋🏽' => 'tangan diangkat: kulit kuning',
    '✋🏾' => 'tangan diangkat: kulit sawo mateng',
    '✋🏿' => 'tangan diangkat: kulit ireng',
    '🖖🏻' => 'ngurmat cara bangsa vulcan: kulit putih',
    '🖖🏼' => 'ngurmat cara bangsa vulcan: kulit putih langsep',
    '🖖🏽' => 'ngurmat cara bangsa vulcan: kulit kuning',
    '🖖🏾' => 'ngurmat cara bangsa vulcan: kulit sawo mateng',
    '🖖🏿' => 'ngurmat cara bangsa vulcan: kulit ireng',
    '🫱🏻' => 'tangan tengen: kulit putih',
    '🫱🏼' => 'tangan tengen: kulit putih langsep',
    '🫱🏽' => 'tangan tengen: kulit kuning',
    '🫱🏾' => 'tangan tengen: kulit sawo mateng',
    '🫱🏿' => 'tangan tengen: kulit ireng',
    '🫲🏻' => 'tangan kiwo: kulit putih',
    '🫲🏼' => 'tangan kiwo: kulit putih langsep',
    '🫲🏽' => 'tangan kiwo: kulit kuning',
    '🫲🏾' => 'tangan kiwo: kulit sawo mateng',
    '🫲🏿' => 'tangan kiwo: kulit ireng',
    '🫳🏻' => 'tangan madep ngisor: kulit putih',
    '🫳🏼' => 'tangan madep ngisor: kulit putih langsep',
    '🫳🏽' => 'tangan madep ngisor: kulit kuning',
    '🫳🏾' => 'tangan madep ngisor: kulit sawo mateng',
    '🫳🏿' => 'tangan madep ngisor: kulit ireng',
    '🫴🏻' => 'tangan madep nduwur: kulit putih',
    '🫴🏼' => 'tangan madep nduwur: kulit putih langsep',
    '🫴🏽' => 'tangan madep nduwur: kulit kuning',
    '🫴🏾' => 'tangan madep nduwur: kulit sawo mateng',
    '🫴🏿' => 'tangan madep nduwur: kulit ireng',
    '🫷🏻' => 'tangan sisih kiwa nyurung: kulit putih',
    '🫷🏼' => 'tangan sisih kiwa nyurung: kulit putih langsep',
    '🫷🏽' => 'tangan sisih kiwa nyurung: kulit kuning',
    '🫷🏾' => 'tangan sisih kiwa nyurung: kulit sawo mateng',
    '🫷🏿' => 'tangan sisih kiwa nyurung: kulit ireng',
    '🫸🏻' => 'tangan sisih tengen nyurung: kulit putih',
    '🫸🏼' => 'tangan sisih tengen nyurung: kulit putih langsep',
    '🫸🏽' => 'tangan sisih tengen nyurung: kulit kuning',
    '🫸🏾' => 'tangan sisih tengen nyurung: kulit sawo mateng',
    '🫸🏿' => 'tangan sisih tengen nyurung: kulit ireng',
    '👌🏻' => 'tangan nuduhake tandha OK: kulit putih',
    '👌🏼' => 'tangan nuduhake tandha OK: kulit putih langsep',
    '👌🏽' => 'tangan nuduhake tandha OK: kulit kuning',
    '👌🏾' => 'tangan nuduhake tandha OK: kulit sawo mateng',
    '👌🏿' => 'tangan nuduhake tandha OK: kulit ireng',
    '🤌🏻' => 'driji digatukake: kulit putih',
    '🤌🏼' => 'driji digatukake: kulit putih langsep',
    '🤌🏽' => 'driji digatukake: kulit kuning',
    '🤌🏾' => 'driji digatukake: kulit sawo mateng',
    '🤌🏿' => 'driji digatukake: kulit ireng',
    '🤏🏻' => 'tangan njiwit: kulit putih',
    '🤏🏼' => 'tangan njiwit: kulit putih langsep',
    '🤏🏽' => 'tangan njiwit: kulit kuning',
    '🤏🏾' => 'tangan njiwit: kulit sawo mateng',
    '🤏🏿' => 'tangan njiwit: kulit ireng',
    '✌🏻' => 'tangan nuduhake tandha kamenangan: kulit putih',
    '✌🏼' => 'tangan nuduhake tandha kamenangan: kulit putih langsep',
    '✌🏽' => 'tangan nuduhake tandha kamenangan: kulit kuning',
    '✌🏾' => 'tangan nuduhake tandha kamenangan: kulit sawo mateng',
    '✌🏿' => 'tangan nuduhake tandha kamenangan: kulit ireng',
    '🤞🏻' => 'driji loro tetalenan: kulit putih',
    '🤞🏼' => 'driji loro tetalenan: kulit putih langsep',
    '🤞🏽' => 'driji loro tetalenan: kulit kuning',
    '🤞🏾' => 'driji loro tetalenan: kulit sawo mateng',
    '🤞🏿' => 'driji loro tetalenan: kulit ireng',
    '🫰🏻' => 'jempol karo driji panuduh tetalenan: kulit putih',
    '🫰🏼' => 'jempol karo driji panuduh tetalenan: kulit putih langsep',
    '🫰🏽' => 'jempol karo driji panuduh tetalenan: kulit kuning',
    '🫰🏾' => 'jempol karo driji panuduh tetalenan: kulit sawo mateng',
    '🫰🏿' => 'jempol karo driji panuduh tetalenan: kulit ireng',
    '🤟🏻' => 'tangan nuduhake tandha tresna sliramu: kulit putih',
    '🤟🏼' => 'tangan nuduhake tandha tresna sliramu: kulit putih langsep',
    '🤟🏽' => 'tangan nuduhake tandha tresna sliramu: kulit kuning',
    '🤟🏾' => 'tangan nuduhake tandha tresna sliramu: kulit sawo mateng',
    '🤟🏿' => 'tangan nuduhake tandha tresna sliramu: kulit ireng',
    '🤘🏻' => 'tandha sungu: kulit putih',
    '🤘🏼' => 'tandha sungu: kulit putih langsep',
    '🤘🏽' => 'tandha sungu: kulit kuning',
    '🤘🏾' => 'tandha sungu: kulit sawo mateng',
    '🤘🏿' => 'tandha sungu: kulit ireng',
    '🤙🏻' => 'tangan nuduhake tandha telpuna aku: kulit putih',
    '🤙🏼' => 'tangan nuduhake tandha telpuna aku: kulit putih langsep',
    '🤙🏽' => 'tangan nuduhake tandha telpuna aku: kulit kuning',
    '🤙🏾' => 'tangan nuduhake tandha telpuna aku: kulit sawo mateng',
    '🤙🏿' => 'tangan nuduhake tandha telpuna aku: kulit ireng',
    '👈🏻' => 'geger tangan nuding ngiwa: kulit putih',
    '👈🏼' => 'geger tangan nuding ngiwa: kulit putih langsep',
    '👈🏽' => 'geger tangan nuding ngiwa: kulit kuning',
    '👈🏾' => 'geger tangan nuding ngiwa: kulit sawo mateng',
    '👈🏿' => 'geger tangan nuding ngiwa: kulit ireng',
    '👉🏻' => 'geger tangan nuding nengen: kulit putih',
    '👉🏼' => 'geger tangan nuding nengen: kulit putih langsep',
    '👉🏽' => 'geger tangan nuding nengen: kulit kuning',
    '👉🏾' => 'geger tangan nuding nengen: kulit sawo mateng',
    '👉🏿' => 'geger tangan nuding nengen: kulit ireng',
    '👆🏻' => 'geger tangan nuding ndhuwur: kulit putih',
    '👆🏼' => 'geger tangan nuding ndhuwur: kulit putih langsep',
    '👆🏽' => 'geger tangan nuding ndhuwur: kulit kuning',
    '👆🏾' => 'geger tangan nuding ndhuwur: kulit sawo mateng',
    '👆🏿' => 'geger tangan nuding ndhuwur: kulit ireng',
    '🖕🏻' => 'driji tengah: kulit putih',
    '🖕🏼' => 'driji tengah: kulit putih langsep',
    '🖕🏽' => 'driji tengah: kulit kuning',
    '🖕🏾' => 'driji tengah: kulit sawo mateng',
    '🖕🏿' => 'driji tengah: kulit ireng',
    '👇🏻' => 'geger tangan nuding ngisor: kulit putih',
    '👇🏼' => 'geger tangan nuding ngisor: kulit putih langsep',
    '👇🏽' => 'geger tangan nuding ngisor: kulit kuning',
    '👇🏾' => 'geger tangan nuding ngisor: kulit sawo mateng',
    '👇🏿' => 'geger tangan nuding ngisor: kulit ireng',
    '☝🏻' => 'driji panuduh ngacung: kulit putih',
    '☝🏼' => 'driji panuduh ngacung: kulit putih langsep',
    '☝🏽' => 'driji panuduh ngacung: kulit kuning',
    '☝🏾' => 'driji panuduh ngacung: kulit sawo mateng',
    '☝🏿' => 'driji panuduh ngacung: kulit ireng',
    '🫵🏻' => 'driji panuduh seng ngewasi: kulit putih',
    '🫵🏼' => 'driji panuduh seng ngewasi: kulit putih langsep',
    '🫵🏽' => 'driji panuduh seng ngewasi: kulit kuning',
    '🫵🏾' => 'driji panuduh seng ngewasi: kulit sawo mateng',
    '🫵🏿' => 'driji panuduh seng ngewasi: kulit ireng',
    '👍🏻' => 'jempol ngacung: kulit putih',
    '👍🏼' => 'jempol ngacung: kulit putih langsep',
    '👍🏽' => 'jempol ngacung: kulit kuning',
    '👍🏾' => 'jempol ngacung: kulit sawo mateng',
    '👍🏿' => 'jempol ngacung: kulit ireng',
    '👎🏻' => 'jempol ngacung mudhun: kulit putih',
    '👎🏼' => 'jempol ngacung mudhun: kulit putih langsep',
    '👎🏽' => 'jempol ngacung mudhun: kulit kuning',
    '👎🏾' => 'jempol ngacung mudhun: kulit sawo mateng',
    '👎🏿' => 'jempol ngacung mudhun: kulit ireng',
    '✊🏻' => 'ngacungake kepel: kulit putih',
    '✊🏼' => 'ngacungake kepel: kulit putih langsep',
    '✊🏽' => 'ngacungake kepel: kulit kuning',
    '✊🏾' => 'ngacungake kepel: kulit sawo mateng',
    '✊🏿' => 'ngacungake kepel: kulit ireng',
    '👊🏻' => 'kepel mara: kulit putih',
    '👊🏼' => 'kepel mara: kulit putih langsep',
    '👊🏽' => 'kepel mara: kulit kuning',
    '👊🏾' => 'kepel mara: kulit sawo mateng',
    '👊🏿' => 'kepel mara: kulit ireng',
    '🤛🏻' => 'kepel katon saka sisih kiwa: kulit putih',
    '🤛🏼' => 'kepel katon saka sisih kiwa: kulit putih langsep',
    '🤛🏽' => 'kepel katon saka sisih kiwa: kulit kuning',
    '🤛🏾' => 'kepel katon saka sisih kiwa: kulit sawo mateng',
    '🤛🏿' => 'kepel katon saka sisih kiwa: kulit ireng',
    '🤜🏻' => 'kepel katon saka sisih tengen: kulit putih',
    '🤜🏼' => 'kepel katon saka sisih tengen: kulit putih langsep',
    '🤜🏽' => 'kepel katon saka sisih tengen: kulit kuning',
    '🤜🏾' => 'kepel katon saka sisih tengen: kulit sawo mateng',
    '🤜🏿' => 'kepel katon saka sisih tengen: kulit ireng',
    '👏🏻' => 'tangan keplok-keplok: kulit putih',
    '👏🏼' => 'tangan keplok-keplok: kulit putih langsep',
    '👏🏽' => 'tangan keplok-keplok: kulit kuning',
    '👏🏾' => 'tangan keplok-keplok: kulit sawo mateng',
    '👏🏿' => 'tangan keplok-keplok: kulit ireng',
    '🙌🏻' => 'tangan loro diangkat: kulit putih',
    '🙌🏼' => 'tangan loro diangkat: kulit putih langsep',
    '🙌🏽' => 'tangan loro diangkat: kulit kuning',
    '🙌🏾' => 'tangan loro diangkat: kulit sawo mateng',
    '🙌🏿' => 'tangan loro diangkat: kulit ireng',
    '🫶🏻' => 'tangan loro mbentuk ati: kulit putih',
    '🫶🏼' => 'tangan loro mbentuk ati: kulit putih langsep',
    '🫶🏽' => 'tangan loro mbentuk ati: kulit kuning',
    '🫶🏾' => 'tangan loro mbentuk ati: kulit sawo mateng',
    '🫶🏿' => 'tangan loro mbentuk ati: kulit ireng',
    '👐🏻' => 'tangan loro mlumah: kulit putih',
    '👐🏼' => 'tangan loro mlumah: kulit putih langsep',
    '👐🏽' => 'tangan loro mlumah: kulit kuning',
    '👐🏾' => 'tangan loro mlumah: kulit sawo mateng',
    '👐🏿' => 'tangan loro mlumah: kulit ireng',
    '🤲🏻' => 'tangan loro mandho nadhah amin: kulit putih',
    '🤲🏼' => 'tangan loro mandho nadhah amin: kulit putih langsep',
    '🤲🏽' => 'tangan loro mandho nadhah amin: kulit kuning',
    '🤲🏾' => 'tangan loro mandho nadhah amin: kulit sawo mateng',
    '🤲🏿' => 'tangan loro mandho nadhah amin: kulit ireng',
    '🤝🏻' => 'salaman: kulit putih',
    '🤝🏼' => 'salaman: kulit putih langsep',
    '🤝🏽' => 'salaman: kulit kuning',
    '🤝🏾' => 'salaman: kulit sawo mateng',
    '🤝🏿' => 'salaman: kulit ireng',
    '🙏🏻' => 'tangan nyembah: kulit putih',
    '🙏🏼' => 'tangan nyembah: kulit putih langsep',
    '🙏🏽' => 'tangan nyembah: kulit kuning',
    '🙏🏾' => 'tangan nyembah: kulit sawo mateng',
    '🙏🏿' => 'tangan nyembah: kulit ireng',
    '✍🏻' => 'tangan nulis: kulit putih',
    '✍🏼' => 'tangan nulis: kulit putih langsep',
    '✍🏽' => 'tangan nulis: kulit kuning',
    '✍🏾' => 'tangan nulis: kulit sawo mateng',
    '✍🏿' => 'tangan nulis: kulit ireng',
    '💅🏻' => 'cet kuku: kulit putih',
    '💅🏼' => 'cet kuku: kulit putih langsep',
    '💅🏽' => 'cet kuku: kulit kuning',
    '💅🏾' => 'cet kuku: kulit sawo mateng',
    '💅🏿' => 'cet kuku: kulit ireng',
    '🤳🏻' => 'foto selfi: kulit putih',
    '🤳🏼' => 'foto selfi: kulit putih langsep',
    '🤳🏽' => 'foto selfi: kulit kuning',
    '🤳🏾' => 'foto selfi: kulit sawo mateng',
    '🤳🏿' => 'foto selfi: kulit ireng',
    '💪🏻' => 'otot lengen mlenthung: kulit putih',
    '💪🏼' => 'otot lengen mlenthung: kulit putih langsep',
    '💪🏽' => 'otot lengen mlenthung: kulit kuning',
    '💪🏾' => 'otot lengen mlenthung: kulit sawo mateng',
    '💪🏿' => 'otot lengen mlenthung: kulit ireng',
    '🦵🏻' => 'sikil: kulit putih',
    '🦵🏼' => 'sikil: kulit putih langsep',
    '🦵🏽' => 'sikil: kulit kuning',
    '🦵🏾' => 'sikil: kulit sawo mateng',
    '🦵🏿' => 'sikil: kulit ireng',
    '🦶🏻' => 'tlapakan sikil: kulit putih',
    '🦶🏼' => 'tlapakan sikil: kulit putih langsep',
    '🦶🏽' => 'tlapakan sikil: kulit kuning',
    '🦶🏾' => 'tlapakan sikil: kulit sawo mateng',
    '🦶🏿' => 'tlapakan sikil: kulit ireng',
    '👂🏻' => 'kuping: kulit putih',
    '👂🏼' => 'kuping: kulit putih langsep',
    '👂🏽' => 'kuping: kulit kuning',
    '👂🏾' => 'kuping: kulit sawo mateng',
    '👂🏿' => 'kuping: kulit ireng',
    '🦻🏻' => 'kuping sarwa piranti pangrungon: kulit putih',
    '🦻🏼' => 'kuping sarwa piranti pangrungon: kulit putih langsep',
    '🦻🏽' => 'kuping sarwa piranti pangrungon: kulit kuning',
    '🦻🏾' => 'kuping sarwa piranti pangrungon: kulit sawo mateng',
    '🦻🏿' => 'kuping sarwa piranti pangrungon: kulit ireng',
    '👃🏻' => 'irung: kulit putih',
    '👃🏼' => 'irung: kulit putih langsep',
    '👃🏽' => 'irung: kulit kuning',
    '👃🏾' => 'irung: kulit sawo mateng',
    '👃🏿' => 'irung: kulit ireng',
    '👶🏻' => 'bayi: kulit putih',
    '👶🏼' => 'bayi: kulit putih langsep',
    '👶🏽' => 'bayi: kulit kuning',
    '👶🏾' => 'bayi: kulit sawo mateng',
    '👶🏿' => 'bayi: kulit ireng',
    '🧒🏻' => 'bocah: kulit putih',
    '🧒🏼' => 'bocah: kulit putih langsep',
    '🧒🏽' => 'bocah: kulit kuning',
    '🧒🏾' => 'bocah: kulit sawo mateng',
    '🧒🏿' => 'bocah: kulit ireng',
    '👦🏻' => 'bocah lanang: kulit putih',
    '👦🏼' => 'bocah lanang: kulit putih langsep',
    '👦🏽' => 'bocah lanang: kulit kuning',
    '👦🏾' => 'bocah lanang: kulit sawo mateng',
    '👦🏿' => 'bocah lanang: kulit ireng',
    '👧🏻' => 'bocah wadon: kulit putih',
    '👧🏼' => 'bocah wadon: kulit putih langsep',
    '👧🏽' => 'bocah wadon: kulit kuning',
    '👧🏾' => 'bocah wadon: kulit sawo mateng',
    '👧🏿' => 'bocah wadon: kulit ireng',
    '🧑🏻' => 'wong: kulit putih',
    '🧑🏼' => 'wong: kulit putih langsep',
    '🧑🏽' => 'wong: kulit kuning',
    '🧑🏾' => 'wong: kulit sawo mateng',
    '🧑🏿' => 'wong: kulit ireng',
    '👱🏻' => 'wong: kulit putih, rambute pirang',
    '👱🏼' => 'wong: kulit putih langsep, rambute pirang',
    '👱🏽' => 'wong: kulit kuning, rambute pirang',
    '👱🏾' => 'wong: kulit sawo mateng, rambute pirang',
    '👱🏿' => 'wong: kulit ireng, rambute pirang',
    '👨🏻' => 'wong lanang: kulit putih',
    '👨🏼' => 'wong lanang: kulit putih langsep',
    '👨🏽' => 'wong lanang: kulit kuning',
    '👨🏾' => 'wong lanang: kulit sawo mateng',
    '👨🏿' => 'wong lanang: kulit ireng',
    '🧔🏻' => 'wong: kulit putih, jenggot',
    '🧔🏼' => 'wong: kulit putih langsep, jenggot',
    '🧔🏽' => 'wong: kulit kuning, jenggot',
    '🧔🏾' => 'wong: kulit sawo mateng, jenggot',
    '🧔🏿' => 'wong: kulit ireng, jenggot',
    '👩🏻' => 'wong wadon: kulit putih',
    '👩🏼' => 'wong wadon: kulit putih langsep',
    '👩🏽' => 'wong wadon: kulit kuning',
    '👩🏾' => 'wong wadon: kulit sawo mateng',
    '👩🏿' => 'wong wadon: kulit ireng',
    '🧓🏻' => 'wong tuwa: kulit putih',
    '🧓🏼' => 'wong tuwa: kulit putih langsep',
    '🧓🏽' => 'wong tuwa: kulit kuning',
    '🧓🏾' => 'wong tuwa: kulit sawo mateng',
    '🧓🏿' => 'wong tuwa: kulit ireng',
    '👴🏻' => 'wong tuwa lanang: kulit putih',
    '👴🏼' => 'wong tuwa lanang: kulit putih langsep',
    '👴🏽' => 'wong tuwa lanang: kulit kuning',
    '👴🏾' => 'wong tuwa lanang: kulit sawo mateng',
    '👴🏿' => 'wong tuwa lanang: kulit ireng',
    '👵🏻' => 'wong wadon tuwa: kulit putih',
    '👵🏼' => 'wong wadon tuwa: kulit putih langsep',
    '👵🏽' => 'wong wadon tuwa: kulit kuning',
    '👵🏾' => 'wong wadon tuwa: kulit sawo mateng',
    '👵🏿' => 'wong wadon tuwa: kulit ireng',
    '🙍🏻' => 'wong sedhih: kulit putih',
    '🙍🏼' => 'wong sedhih: kulit putih langsep',
    '🙍🏽' => 'wong sedhih: kulit kuning',
    '🙍🏾' => 'wong sedhih: kulit sawo mateng',
    '🙍🏿' => 'wong sedhih: kulit ireng',
    '🙎🏻' => 'wong mbesengut: kulit putih',
    '🙎🏼' => 'wong mbesengut: kulit putih langsep',
    '🙎🏽' => 'wong mbesengut: kulit kuning',
    '🙎🏾' => 'wong mbesengut: kulit sawo mateng',
    '🙎🏿' => 'wong mbesengut: kulit ireng',
    '🙅🏻' => 'wong ngisaratake AJA: kulit putih',
    '🙅🏼' => 'wong ngisaratake AJA: kulit putih langsep',
    '🙅🏽' => 'wong ngisaratake AJA: kulit kuning',
    '🙅🏾' => 'wong ngisaratake AJA: kulit sawo mateng',
    '🙅🏿' => 'wong ngisaratake AJA: kulit ireng',
    '🙆🏻' => 'wong ngisaratake OK: kulit putih',
    '🙆🏼' => 'wong ngisaratake OK: kulit putih langsep',
    '🙆🏽' => 'wong ngisaratake OK: kulit kuning',
    '🙆🏾' => 'wong ngisaratake OK: kulit sawo mateng',
    '🙆🏿' => 'wong ngisaratake OK: kulit ireng',
    '💁🏻' => 'wong tangane anyangga: kulit putih',
    '💁🏼' => 'wong tangane anyangga: kulit putih langsep',
    '💁🏽' => 'wong tangane anyangga: kulit kuning',
    '💁🏾' => 'wong tangane anyangga: kulit sawo mateng',
    '💁🏿' => 'wong tangane anyangga: kulit ireng',
    '🙋🏻' => 'wong ngacungake tangan: kulit putih',
    '🙋🏼' => 'wong ngacungake tangan: kulit putih langsep',
    '🙋🏽' => 'wong ngacungake tangan: kulit kuning',
    '🙋🏾' => 'wong ngacungake tangan: kulit sawo mateng',
    '🙋🏿' => 'wong ngacungake tangan: kulit ireng',
    '🧏🏻' => 'wong budheg: kulit putih',
    '🧏🏼' => 'wong budheg: kulit putih langsep',
    '🧏🏽' => 'wong budheg: kulit kuning',
    '🧏🏾' => 'wong budheg: kulit sawo mateng',
    '🧏🏿' => 'wong budheg: kulit ireng',
    '🙇🏻' => 'wong mbungkuk ngurmati: kulit putih',
    '🙇🏼' => 'wong mbungkuk ngurmati: kulit putih langsep',
    '🙇🏽' => 'wong mbungkuk ngurmati: kulit kuning',
    '🙇🏾' => 'wong mbungkuk ngurmati: kulit sawo mateng',
    '🙇🏿' => 'wong mbungkuk ngurmati: kulit ireng',
    '🤦🏻' => 'wong anutup raine mawa dlamakan: kulit putih',
    '🤦🏼' => 'wong anutup raine mawa dlamakan: kulit putih langsep',
    '🤦🏽' => 'wong anutup raine mawa dlamakan: kulit kuning',
    '🤦🏾' => 'wong anutup raine mawa dlamakan: kulit sawo mateng',
    '🤦🏿' => 'wong anutup raine mawa dlamakan: kulit ireng',
    '🤷🏻' => 'wong angangkat pundhak: kulit putih',
    '🤷🏼' => 'wong angangkat pundhak: kulit putih langsep',
    '🤷🏽' => 'wong angangkat pundhak: kulit kuning',
    '🤷🏾' => 'wong angangkat pundhak: kulit sawo mateng',
    '🤷🏿' => 'wong angangkat pundhak: kulit ireng',
    '👮🏻' => 'pulisi: kulit putih',
    '👮🏼' => 'pulisi: kulit putih langsep',
    '👮🏽' => 'pulisi: kulit kuning',
    '👮🏾' => 'pulisi: kulit sawo mateng',
    '👮🏿' => 'pulisi: kulit ireng',
    '🕵🏻' => 'dhetektif: kulit putih',
    '🕵🏼' => 'dhetektif: kulit putih langsep',
    '🕵🏽' => 'dhetektif: kulit kuning',
    '🕵🏾' => 'dhetektif: kulit sawo mateng',
    '🕵🏿' => 'dhetektif: kulit ireng',
    '💂🏻' => 'panjaga: kulit putih',
    '💂🏼' => 'panjaga: kulit putih langsep',
    '💂🏽' => 'panjaga: kulit kuning',
    '💂🏾' => 'panjaga: kulit sawo mateng',
    '💂🏿' => 'panjaga: kulit ireng',
    '🥷🏻' => 'ninja: kulit putih',
    '🥷🏼' => 'ninja: kulit putih langsep',
    '🥷🏽' => 'ninja: kulit kuning',
    '🥷🏾' => 'ninja: kulit sawo mateng',
    '🥷🏿' => 'ninja: kulit ireng',
    '👷🏻' => 'buruh bangunan: kulit putih',
    '👷🏼' => 'buruh bangunan: kulit putih langsep',
    '👷🏽' => 'buruh bangunan: kulit kuning',
    '👷🏾' => 'buruh bangunan: kulit sawo mateng',
    '👷🏿' => 'buruh bangunan: kulit ireng',
    '🫅🏻' => 'wong nganggo makutha: kulit putih',
    '🫅🏼' => 'wong nganggo makutha: kulit putih langsep',
    '🫅🏽' => 'wong nganggo makutha: kulit kuning',
    '🫅🏾' => 'wong nganggo makutha: kulit sawo mateng',
    '🫅🏿' => 'wong nganggo makutha: kulit ireng',
    '🤴🏻' => 'pangeran: kulit putih',
    '🤴🏼' => 'pangeran: kulit putih langsep',
    '🤴🏽' => 'pangeran: kulit kuning',
    '🤴🏾' => 'pangeran: kulit sawo mateng',
    '🤴🏿' => 'pangeran: kulit ireng',
    '👸🏻' => 'putri: kulit putih',
    '👸🏼' => 'putri: kulit putih langsep',
    '👸🏽' => 'putri: kulit kuning',
    '👸🏾' => 'putri: kulit sawo mateng',
    '👸🏿' => 'putri: kulit ireng',
    '👳🏻' => 'wong serbanan: kulit putih',
    '👳🏼' => 'wong serbanan: kulit putih langsep',
    '👳🏽' => 'wong serbanan: kulit kuning',
    '👳🏾' => 'wong serbanan: kulit sawo mateng',
    '👳🏿' => 'wong serbanan: kulit ireng',
    '👲🏻' => 'wong lanang nganggo kethu Cina: kulit putih',
    '👲🏼' => 'wong lanang nganggo kethu Cina: kulit putih langsep',
    '👲🏽' => 'wong lanang nganggo kethu Cina: kulit kuning',
    '👲🏾' => 'wong lanang nganggo kethu Cina: kulit sawo mateng',
    '👲🏿' => 'wong lanang nganggo kethu Cina: kulit ireng',
    '🧕🏻' => 'wong wadon jilbaban: kulit putih',
    '🧕🏼' => 'wong wadon jilbaban: kulit putih langsep',
    '🧕🏽' => 'wong wadon jilbaban: kulit kuning',
    '🧕🏾' => 'wong wadon jilbaban: kulit sawo mateng',
    '🧕🏿' => 'wong wadon jilbaban: kulit ireng',
    '🤵🏻' => 'wong anganggo jas tuksedo: kulit putih',
    '🤵🏼' => 'wong anganggo jas tuksedo: kulit putih langsep',
    '🤵🏽' => 'wong anganggo jas tuksedo: kulit kuning',
    '🤵🏾' => 'wong anganggo jas tuksedo: kulit sawo mateng',
    '🤵🏿' => 'wong anganggo jas tuksedo: kulit ireng',
    '👰🏻' => 'wong nganggo kudhung manten: kulit putih',
    '👰🏼' => 'wong nganggo kudhung manten: kulit putih langsep',
    '👰🏽' => 'wong nganggo kudhung manten: kulit kuning',
    '👰🏾' => 'wong nganggo kudhung manten: kulit sawo mateng',
    '👰🏿' => 'wong nganggo kudhung manten: kulit ireng',
    '🤰🏻' => 'wong wadon ngandhut: kulit putih',
    '🤰🏼' => 'wong wadon ngandhut: kulit putih langsep',
    '🤰🏽' => 'wong wadon ngandhut: kulit kuning',
    '🤰🏾' => 'wong wadon ngandhut: kulit sawo mateng',
    '🤰🏿' => 'wong wadon ngandhut: kulit ireng',
    '🫃🏻' => 'wong lanang meteng: kulit putih',
    '🫃🏼' => 'wong lanang meteng: kulit putih langsep',
    '🫃🏽' => 'wong lanang meteng: kulit kuning',
    '🫃🏾' => 'wong lanang meteng: kulit sawo mateng',
    '🫃🏿' => 'wong lanang meteng: kulit ireng',
    '🫄🏻' => 'wong meteng: kulit putih',
    '🫄🏼' => 'wong meteng: kulit putih langsep',
    '🫄🏽' => 'wong meteng: kulit kuning',
    '🫄🏾' => 'wong meteng: kulit sawo mateng',
    '🫄🏿' => 'wong meteng: kulit ireng',
    '🤱🏻' => 'menthili: kulit putih',
    '🤱🏼' => 'menthili: kulit putih langsep',
    '🤱🏽' => 'menthili: kulit kuning',
    '🤱🏾' => 'menthili: kulit sawo mateng',
    '🤱🏿' => 'menthili: kulit ireng',
    '👼🏻' => 'malaékat bayi: kulit putih',
    '👼🏼' => 'malaékat bayi: kulit putih langsep',
    '👼🏽' => 'malaékat bayi: kulit kuning',
    '👼🏾' => 'malaékat bayi: kulit sawo mateng',
    '👼🏿' => 'malaékat bayi: kulit ireng',
    '🎅🏻' => 'Sinter Klas: kulit putih',
    '🎅🏼' => 'Sinter Klas: kulit putih langsep',
    '🎅🏽' => 'Sinter Klas: kulit kuning',
    '🎅🏾' => 'Sinter Klas: kulit sawo mateng',
    '🎅🏿' => 'Sinter Klas: kulit ireng',
    '🤶🏻' => 'Ibu Klas: kulit putih',
    '🤶🏼' => 'Ibu Klas: kulit putih langsep',
    '🤶🏽' => 'Ibu Klas: kulit kuning',
    '🤶🏾' => 'Ibu Klas: kulit sawo mateng',
    '🤶🏿' => 'Ibu Klas: kulit ireng',
    '🦸🏻' => 'satriya mandraguna: kulit putih',
    '🦸🏼' => 'satriya mandraguna: kulit putih langsep',
    '🦸🏽' => 'satriya mandraguna: kulit kuning',
    '🦸🏾' => 'satriya mandraguna: kulit sawo mateng',
    '🦸🏿' => 'satriya mandraguna: kulit ireng',
    '🦹🏻' => 'mungsuh digdaya: kulit putih',
    '🦹🏼' => 'mungsuh digdaya: kulit putih langsep',
    '🦹🏽' => 'mungsuh digdaya: kulit kuning',
    '🦹🏾' => 'mungsuh digdaya: kulit sawo mateng',
    '🦹🏿' => 'mungsuh digdaya: kulit ireng',
    '🧙🏻' => 'wong winasis: kulit putih',
    '🧙🏼' => 'wong winasis: kulit putih langsep',
    '🧙🏽' => 'wong winasis: kulit kuning',
    '🧙🏾' => 'wong winasis: kulit sawo mateng',
    '🧙🏿' => 'wong winasis: kulit ireng',
    '🧚🏻' => 'bangsa dewi: kulit putih',
    '🧚🏼' => 'bangsa dewi: kulit putih langsep',
    '🧚🏽' => 'bangsa dewi: kulit kuning',
    '🧚🏾' => 'bangsa dewi: kulit sawo mateng',
    '🧚🏿' => 'bangsa dewi: kulit ireng',
    '🧛🏻' => 'vampir: kulit putih',
    '🧛🏼' => 'vampir: kulit putih langsep',
    '🧛🏽' => 'vampir: kulit kuning',
    '🧛🏾' => 'vampir: kulit sawo mateng',
    '🧛🏿' => 'vampir: kulit ireng',
    '🧜🏻' => 'duyung: kulit putih',
    '🧜🏼' => 'duyung: kulit putih langsep',
    '🧜🏽' => 'duyung: kulit kuning',
    '🧜🏾' => 'duyung: kulit sawo mateng',
    '🧜🏿' => 'duyung: kulit ireng',
    '🧝🏻' => 'peri: kulit putih',
    '🧝🏼' => 'peri: kulit putih langsep',
    '🧝🏽' => 'peri: kulit kuning',
    '🧝🏾' => 'peri: kulit sawo mateng',
    '🧝🏿' => 'peri: kulit ireng',
    '💆🏻' => 'wong dipijeti: kulit putih',
    '💆🏼' => 'wong dipijeti: kulit putih langsep',
    '💆🏽' => 'wong dipijeti: kulit kuning',
    '💆🏾' => 'wong dipijeti: kulit sawo mateng',
    '💆🏿' => 'wong dipijeti: kulit ireng',
    '💇🏻' => 'wong lagi dikethok rambute: kulit putih',
    '💇🏼' => 'wong lagi dikethok rambute: kulit putih langsep',
    '💇🏽' => 'wong lagi dikethok rambute: kulit kuning',
    '💇🏾' => 'wong lagi dikethok rambute: kulit sawo mateng',
    '💇🏿' => 'wong lagi dikethok rambute: kulit ireng',
    '🚶🏻' => 'wong mlaku: kulit putih',
    '🚶🏼' => 'wong mlaku: kulit putih langsep',
    '🚶🏽' => 'wong mlaku: kulit kuning',
    '🚶🏾' => 'wong mlaku: kulit sawo mateng',
    '🚶🏿' => 'wong mlaku: kulit ireng',
    '🧍🏻' => 'wong ngadeg: kulit putih',
    '🧍🏼' => 'wong ngadeg: kulit putih langsep',
    '🧍🏽' => 'wong ngadeg: kulit kuning',
    '🧍🏾' => 'wong ngadeg: kulit sawo mateng',
    '🧍🏿' => 'wong ngadeg: kulit ireng',
    '🧎🏻' => 'wong timpuh: kulit putih',
    '🧎🏼' => 'wong timpuh: kulit putih langsep',
    '🧎🏽' => 'wong timpuh: kulit kuning',
    '🧎🏾' => 'wong timpuh: kulit sawo mateng',
    '🧎🏿' => 'wong timpuh: kulit ireng',
    '🏃🏻' => 'wong mlayu: kulit putih',
    '🏃🏼' => 'wong mlayu: kulit putih langsep',
    '🏃🏽' => 'wong mlayu: kulit kuning',
    '🏃🏾' => 'wong mlayu: kulit sawo mateng',
    '🏃🏿' => 'wong mlayu: kulit ireng',
    '💃🏻' => 'wong wadon njoget: kulit putih',
    '💃🏼' => 'wong wadon njoget: kulit putih langsep',
    '💃🏽' => 'wong wadon njoget: kulit kuning',
    '💃🏾' => 'wong wadon njoget: kulit sawo mateng',
    '💃🏿' => 'wong wadon njoget: kulit ireng',
    '🕺🏻' => 'wong lanang njoget: kulit putih',
    '🕺🏼' => 'wong lanang njoget: kulit putih langsep',
    '🕺🏽' => 'wong lanang njoget: kulit kuning',
    '🕺🏾' => 'wong lanang njoget: kulit sawo mateng',
    '🕺🏿' => 'wong lanang njoget: kulit ireng',
    '🕴🏻' => 'wong lanang jas-jasan ora napak: kulit putih',
    '🕴🏼' => 'wong lanang jas-jasan ora napak: kulit putih langsep',
    '🕴🏽' => 'wong lanang jas-jasan ora napak: kulit kuning',
    '🕴🏾' => 'wong lanang jas-jasan ora napak: kulit sawo mateng',
    '🕴🏿' => 'wong lanang jas-jasan ora napak: kulit ireng',
    '👯🏻' => 'wong nganggo kuping terwelu: kulit putih',
    '👯🏼' => 'wong nganggo kuping terwelu: kulit putih langsep',
    '👯🏽' => 'wong nganggo kuping terwelu: kulit kuning',
    '👯🏾' => 'wong nganggo kuping terwelu: kulit sawo mateng',
    '👯🏿' => 'wong nganggo kuping terwelu: kulit ireng',
    '🧖🏻' => 'wong ing kamar kebak sumub: kulit putih',
    '🧖🏼' => 'wong ing kamar kebak sumub: kulit putih langsep',
    '🧖🏽' => 'wong ing kamar kebak sumub: kulit kuning',
    '🧖🏾' => 'wong ing kamar kebak sumub: kulit sawo mateng',
    '🧖🏿' => 'wong ing kamar kebak sumub: kulit ireng',
    '🧗🏻' => 'wong manjad: kulit putih',
    '🧗🏼' => 'wong manjad: kulit putih langsep',
    '🧗🏽' => 'wong manjad: kulit kuning',
    '🧗🏾' => 'wong manjad: kulit sawo mateng',
    '🧗🏿' => 'wong manjad: kulit ireng',
    '🏇🏻' => 'balapan jaran: kulit putih',
    '🏇🏼' => 'balapan jaran: kulit putih langsep',
    '🏇🏽' => 'balapan jaran: kulit kuning',
    '🏇🏾' => 'balapan jaran: kulit sawo mateng',
    '🏇🏿' => 'balapan jaran: kulit ireng',
    '🏂🏻' => 'pemain slancar salju: kulit putih',
    '🏂🏼' => 'pemain slancar salju: kulit putih langsep',
    '🏂🏽' => 'pemain slancar salju: kulit kuning',
    '🏂🏾' => 'pemain slancar salju: kulit sawo mateng',
    '🏂🏿' => 'pemain slancar salju: kulit ireng',
    '🏌🏻' => 'wong main golf: kulit putih',
    '🏌🏼' => 'wong main golf: kulit putih langsep',
    '🏌🏽' => 'wong main golf: kulit kuning',
    '🏌🏾' => 'wong main golf: kulit sawo mateng',
    '🏌🏿' => 'wong main golf: kulit ireng',
    '🏄🏻' => 'wong slancar: kulit putih',
    '🏄🏼' => 'wong slancar: kulit putih langsep',
    '🏄🏽' => 'wong slancar: kulit kuning',
    '🏄🏾' => 'wong slancar: kulit sawo mateng',
    '🏄🏿' => 'wong slancar: kulit ireng',
    '🚣🏻' => 'wong ndhayung: kulit putih',
    '🚣🏼' => 'wong ndhayung: kulit putih langsep',
    '🚣🏽' => 'wong ndhayung: kulit kuning',
    '🚣🏾' => 'wong ndhayung: kulit sawo mateng',
    '🚣🏿' => 'wong ndhayung: kulit ireng',
    '🏊🏻' => 'wong nglangi: kulit putih',
    '🏊🏼' => 'wong nglangi: kulit putih langsep',
    '🏊🏽' => 'wong nglangi: kulit kuning',
    '🏊🏾' => 'wong nglangi: kulit sawo mateng',
    '🏊🏿' => 'wong nglangi: kulit ireng',
    '⛹🏻' => 'wong mentulake bal: kulit putih',
    '⛹🏼' => 'wong mentulake bal: kulit putih langsep',
    '⛹🏽' => 'wong mentulake bal: kulit kuning',
    '⛹🏾' => 'wong mentulake bal: kulit sawo mateng',
    '⛹🏿' => 'wong mentulake bal: kulit ireng',
    '🏋🏻' => 'wong ngangkat barbel: kulit putih',
    '🏋🏼' => 'wong ngangkat barbel: kulit putih langsep',
    '🏋🏽' => 'wong ngangkat barbel: kulit kuning',
    '🏋🏾' => 'wong ngangkat barbel: kulit sawo mateng',
    '🏋🏿' => 'wong ngangkat barbel: kulit ireng',
    '🚴🏻' => 'wong numpak pit: kulit putih',
    '🚴🏼' => 'wong numpak pit: kulit putih langsep',
    '🚴🏽' => 'wong numpak pit: kulit kuning',
    '🚴🏾' => 'wong numpak pit: kulit sawo mateng',
    '🚴🏿' => 'wong numpak pit: kulit ireng',
    '🚵🏻' => 'wong numpak sepedha gunung: kulit putih',
    '🚵🏼' => 'wong numpak sepedha gunung: kulit putih langsep',
    '🚵🏽' => 'wong numpak sepedha gunung: kulit kuning',
    '🚵🏾' => 'wong numpak sepedha gunung: kulit sawo mateng',
    '🚵🏿' => 'wong numpak sepedha gunung: kulit ireng',
    '🤸🏻' => 'wong engkang: kulit putih',
    '🤸🏼' => 'wong engkang: kulit putih langsep',
    '🤸🏽' => 'wong engkang: kulit kuning',
    '🤸🏾' => 'wong engkang: kulit sawo mateng',
    '🤸🏿' => 'wong engkang: kulit ireng',
    '🤼🏻' => 'wong gulat: kulit putih',
    '🤼🏼' => 'wong gulat: kulit putih langsep',
    '🤼🏽' => 'wong gulat: kulit kuning',
    '🤼🏾' => 'wong gulat: kulit sawo mateng',
    '🤼🏿' => 'wong gulat: kulit ireng',
    '🤽🏻' => 'wong main polo banyu: kulit putih',
    '🤽🏼' => 'wong main polo banyu: kulit putih langsep',
    '🤽🏽' => 'wong main polo banyu: kulit kuning',
    '🤽🏾' => 'wong main polo banyu: kulit sawo mateng',
    '🤽🏿' => 'wong main polo banyu: kulit ireng',
    '🤾🏻' => 'wong main bal tangan: kulit putih',
    '🤾🏼' => 'wong main bal tangan: kulit putih langsep',
    '🤾🏽' => 'wong main bal tangan: kulit kuning',
    '🤾🏾' => 'wong main bal tangan: kulit sawo mateng',
    '🤾🏿' => 'wong main bal tangan: kulit ireng',
    '🤹🏻' => 'wong main akrobat bal: kulit putih',
    '🤹🏼' => 'wong main akrobat bal: kulit putih langsep',
    '🤹🏽' => 'wong main akrobat bal: kulit kuning',
    '🤹🏾' => 'wong main akrobat bal: kulit sawo mateng',
    '🤹🏿' => 'wong main akrobat bal: kulit ireng',
    '🧘🏻' => 'wong njagong sila: kulit putih',
    '🧘🏼' => 'wong njagong sila: kulit putih langsep',
    '🧘🏽' => 'wong njagong sila: kulit kuning',
    '🧘🏾' => 'wong njagong sila: kulit sawo mateng',
    '🧘🏿' => 'wong njagong sila: kulit ireng',
    '🛀🏻' => 'wong adus kungkum: kulit putih',
    '🛀🏼' => 'wong adus kungkum: kulit putih langsep',
    '🛀🏽' => 'wong adus kungkum: kulit kuning',
    '🛀🏾' => 'wong adus kungkum: kulit sawo mateng',
    '🛀🏿' => 'wong adus kungkum: kulit ireng',
    '🛌🏻' => 'wong turu: kulit putih',
    '🛌🏼' => 'wong turu: kulit putih langsep',
    '🛌🏽' => 'wong turu: kulit kuning',
    '🛌🏾' => 'wong turu: kulit sawo mateng',
    '🛌🏿' => 'wong turu: kulit ireng',
    '👭🏻' => 'wong wadon loro gandhengan tangan: kulit putih',
    '👭🏼' => 'wong wadon loro gandhengan tangan: kulit putih langsep',
    '👭🏽' => 'wong wadon loro gandhengan tangan: kulit kuning',
    '👭🏾' => 'wong wadon loro gandhengan tangan: kulit sawo mateng',
    '👭🏿' => 'wong wadon loro gandhengan tangan: kulit ireng',
    '👫🏻' => 'wong lanang lan wadon gandhengan: kulit putih',
    '👫🏼' => 'wong lanang lan wadon gandhengan: kulit putih langsep',
    '👫🏽' => 'wong lanang lan wadon gandhengan: kulit kuning',
    '👫🏾' => 'wong lanang lan wadon gandhengan: kulit sawo mateng',
    '👫🏿' => 'wong lanang lan wadon gandhengan: kulit ireng',
    '👬🏻' => 'wong lanang loro gandhengan tangan: kulit putih',
    '👬🏼' => 'wong lanang loro gandhengan tangan: kulit putih langsep',
    '👬🏽' => 'wong lanang loro gandhengan tangan: kulit kuning',
    '👬🏾' => 'wong lanang loro gandhengan tangan: kulit sawo mateng',
    '👬🏿' => 'wong lanang loro gandhengan tangan: kulit ireng',
    '💏🏻' => 'ambung: kulit putih',
    '💏🏼' => 'ambung: kulit putih langsep',
    '💏🏽' => 'ambung: kulit kuning',
    '💏🏾' => 'ambung: kulit sawo mateng',
    '💏🏿' => 'ambung: kulit ireng',
    '💑🏻' => 'pasangan lan tandha ati: kulit putih',
    '💑🏼' => 'pasangan lan tandha ati: kulit putih langsep',
    '💑🏽' => 'pasangan lan tandha ati: kulit kuning',
    '💑🏾' => 'pasangan lan tandha ati: kulit sawo mateng',
    '💑🏿' => 'pasangan lan tandha ati: kulit ireng',
    '🇦🇨' => 'gendera: Pulo Ascension',
    '🇦🇩' => 'gendera: Andora',
    '🇦🇪' => 'gendera: Uni Émirat Arab',
    '🇦🇫' => 'gendera: Afganistan',
    '🇦🇬' => 'gendera: Antigua lan Barbuda',
    '🇦🇮' => 'gendera: Anguilla',
    '🇦🇱' => 'gendera: Albani',
    '🇦🇲' => 'gendera: Arménia',
    '🇦🇴' => 'gendera: Angola',
    '🇦🇶' => 'gendera: Antartika',
    '🇦🇷' => 'gendera: Argèntina',
    '🇦🇸' => 'gendera: Samoa Amerika',
    '🇦🇹' => 'gendera: Ostenrik',
    '🇦🇺' => 'gendera: Ostrali',
    '🇦🇼' => 'gendera: Aruba',
    '🇦🇽' => 'gendera: Kapuloan Alan',
    '🇦🇿' => 'gendera: Azerbaijan',
    '🇧🇦' => 'gendera: Bosnia lan Hèrségovina',
    '🇧🇧' => 'gendera: Barbadhos',
    '🇧🇩' => 'gendera: Banggaladésa',
    '🇧🇪' => 'gendera: Bèlgi',
    '🇧🇫' => 'gendera: Burkina Faso',
    '🇧🇬' => 'gendera: Bulgari',
    '🇧🇭' => 'gendera: Bahrain',
    '🇧🇮' => 'gendera: Burundi',
    '🇧🇯' => 'gendera: Bénin',
    '🇧🇱' => 'gendera: Saint Barthélémi',
    '🇧🇲' => 'gendera: Bermuda',
    '🇧🇳' => 'gendera: Brunéi',
    '🇧🇴' => 'gendera: Bolivia',
    '🇧🇶' => 'gendera: Karibia Walanda',
    '🇧🇷' => 'gendera: Brasil',
    '🇧🇸' => 'gendera: Bahama',
    '🇧🇹' => 'gendera: Bhutan',
    '🇧🇻' => 'gendera: Pulo Bovèt',
    '🇧🇼' => 'gendera: Botswana',
    '🇧🇾' => 'gendera: Bélarus',
    '🇧🇿' => 'gendera: Bélisé',
    '🇨🇦' => 'gendera: Kanada',
    '🇨🇨' => 'gendera: Kapuloan Cocos (Keeling)',
    '🇨🇩' => 'gendera: Kongo - Kinshasa',
    '🇨🇫' => 'gendera: Républik Afrika Tengah',
    '🇨🇬' => 'gendera: Kongo - Brassaville',
    '🇨🇭' => 'gendera: Switserlan',
    '🇨🇮' => 'gendera: Pasisir Gadhing',
    '🇨🇰' => 'gendera: Kapuloan Cook',
    '🇨🇱' => 'gendera: Cilé',
    '🇨🇲' => 'gendera: Kamerun',
    '🇨🇳' => 'gendera: Tyongkok',
    '🇨🇴' => 'gendera: Kolombia',
    '🇨🇵' => 'gendera: Pulo Clipperton',
    '🇨🇶' => 'gendera: Sark',
    '🇨🇷' => 'gendera: Kosta Rika',
    '🇨🇺' => 'gendera: Kuba',
    '🇨🇻' => 'gendera: Pongol Verdé',
    '🇨🇼' => 'gendera: Kurasao',
    '🇨🇽' => 'gendera: Pulo Natal',
    '🇨🇾' => 'gendera: Siprus',
    '🇨🇿' => 'gendera: Céko',
    '🇩🇪' => 'gendera: Jérman',
    '🇩🇬' => 'gendera: Diego Garcia',
    '🇩🇯' => 'gendera: Jibuti',
    '🇩🇰' => 'gendera: Dhènemarken',
    '🇩🇲' => 'gendera: Dominika',
    '🇩🇴' => 'gendera: Républik Dominika',
    '🇩🇿' => 'gendera: Aljasair',
    '🇪🇦' => 'gendera: Séuta lan Melila',
    '🇪🇨' => 'gendera: Ékuadhor',
    '🇪🇪' => 'gendera: Éstonia',
    '🇪🇬' => 'gendera: Mesir',
    '🇪🇭' => 'gendera: Sahara Kulon',
    '🇪🇷' => 'gendera: Éritréa',
    '🇪🇸' => 'gendera: Sepanyol',
    '🇪🇹' => 'gendera: Étiopia',
    '🇪🇺' => 'gendera: Uni Éropah',
    '🇫🇮' => 'gendera: Finlan',
    '🇫🇯' => 'gendera: Fiji',
    '🇫🇰' => 'gendera: Kapuloan Falkland',
    '🇫🇲' => 'gendera: Féderasi Mikronésia',
    '🇫🇴' => 'gendera: Kapuloan Faro',
    '🇫🇷' => 'gendera: Prancis',
    '🇬🇦' => 'gendera: Gabon',
    '🇬🇧' => 'gendera: Karajan Manunggal',
    '🇬🇩' => 'gendera: Grénada',
    '🇬🇪' => 'gendera: Géorgia',
    '🇬🇫' => 'gendera: Guyana Prancis',
    '🇬🇬' => 'gendera: Guernsei',
    '🇬🇭' => 'gendera: Ghana',
    '🇬🇮' => 'gendera: Gibraltar',
    '🇬🇱' => 'gendera: Greenland',
    '🇬🇲' => 'gendera: Gambia',
    '🇬🇳' => 'gendera: Guinea',
    '🇬🇵' => 'gendera: Guadélup',
    '🇬🇶' => 'gendera: Guinéa Katulistiwa',
    '🇬🇷' => 'gendera: Grikenlan',
    '🇬🇸' => 'gendera: Georgia Kidul lan Kapuloan Sandwich Kidul',
    '🇬🇹' => 'gendera: Guatémala',
    '🇬🇺' => 'gendera: Guam',
    '🇬🇼' => 'gendera: Guinea-Bissau',
    '🇬🇾' => 'gendera: Guyana',
    '🇭🇰' => 'gendera: Laladan Administratif Astamiwa Hong Kong',
    '🇭🇲' => 'gendera: Kapuloan Heard lan McDonald',
    '🇭🇳' => 'gendera: Honduras',
    '🇭🇷' => 'gendera: Kroasia',
    '🇭🇹' => 'gendera: Haiti',
    '🇭🇺' => 'gendera: Honggari',
    '🇮🇨' => 'gendera: Kapuloan Kanari',
    '🇮🇩' => 'gendera: Indonésia',
    '🇮🇪' => 'gendera: Républik Irlan',
    '🇮🇱' => 'gendera: Israèl',
    '🇮🇲' => 'gendera: Pulo Man',
    '🇮🇳' => 'gendera: Indhia',
    '🇮🇴' => 'gendera: Wilayah Inggris ing Segara Hindia',
    '🇮🇶' => 'gendera: Irak',
    '🇮🇷' => 'gendera: Iran',
    '🇮🇸' => 'gendera: Èslan',
    '🇮🇹' => 'gendera: Itali',
    '🇯🇪' => 'gendera: Jersey',
    '🇯🇲' => 'gendera: Jamaika',
    '🇯🇴' => 'gendera: Yordania',
    '🇯🇵' => 'gendera: Jepang',
    '🇰🇪' => 'gendera: Kénya',
    '🇰🇬' => 'gendera: Kirgistan',
    '🇰🇭' => 'gendera: Kamboja',
    '🇰🇮' => 'gendera: Kiribati',
    '🇰🇲' => 'gendera: Komoro',
    '🇰🇳' => 'gendera: Saint Kits lan Nèvis',
    '🇰🇵' => 'gendera: Korea Lor',
    '🇰🇷' => 'gendera: Koréa Kidul',
    '🇰🇼' => 'gendera: Kuwait',
    '🇰🇾' => 'gendera: Kapuloan Kéman',
    '🇰🇿' => 'gendera: Kasakstan',
    '🇱🇦' => 'gendera: Laos',
    '🇱🇧' => 'gendera: Libanon',
    '🇱🇨' => 'gendera: Santa Lusia',
    '🇱🇮' => 'gendera: Liktenstén',
    '🇱🇰' => 'gendera: Sri Lanka',
    '🇱🇷' => 'gendera: Libèria',
    '🇱🇸' => 'gendera: Lésotho',
    '🇱🇹' => 'gendera: Litowen',
    '🇱🇺' => 'gendera: Luksemburg',
    '🇱🇻' => 'gendera: Latvia',
    '🇱🇾' => 'gendera: Libya',
    '🇲🇦' => 'gendera: Maroko',
    '🇲🇨' => 'gendera: Monako',
    '🇲🇩' => 'gendera: Moldova',
    '🇲🇪' => 'gendera: Montenégro',
    '🇲🇫' => 'gendera: Santa Martin',
    '🇲🇬' => 'gendera: Madagaskar',
    '🇲🇭' => 'gendera: Kapuloan Marshall',
    '🇲🇰' => 'gendera: Républik Makédonia Lor',
    '🇲🇱' => 'gendera: Mali',
    '🇲🇲' => 'gendera: Myanmar (Burma)',
    '🇲🇳' => 'gendera: Mongolia',
    '🇲🇴' => 'gendera: Laladan Administratif Astamiwa Makau',
    '🇲🇵' => 'gendera: Kapuloan Mariana Lor',
    '🇲🇶' => 'gendera: Martinik',
    '🇲🇷' => 'gendera: Mauritania',
    '🇲🇸' => 'gendera: Monsérat',
    '🇲🇹' => 'gendera: Malta',
    '🇲🇺' => 'gendera: Mauritius',
    '🇲🇻' => 'gendera: Maladéwa',
    '🇲🇼' => 'gendera: Malawi',
    '🇲🇽' => 'gendera: Mèksiko',
    '🇲🇾' => 'gendera: Malaysia',
    '🇲🇿' => 'gendera: Mosambik',
    '🇳🇦' => 'gendera: Namibia',
    '🇳🇨' => 'gendera: Kalédonia Anyar',
    '🇳🇪' => 'gendera: Nigér',
    '🇳🇫' => 'gendera: Pulo Norfolk',
    '🇳🇬' => 'gendera: Nigéria',
    '🇳🇮' => 'gendera: Nikaragua',
    '🇳🇱' => 'gendera: Walanda',
    '🇳🇴' => 'gendera: Nurwègen',
    '🇳🇵' => 'gendera: Népal',
    '🇳🇷' => 'gendera: Nauru',
    '🇳🇺' => 'gendera: Niue',
    '🇳🇿' => 'gendera: Selandia Anyar',
    '🇴🇲' => 'gendera: Oman',
    '🇵🇦' => 'gendera: Panama',
    '🇵🇪' => 'gendera: Peru',
    '🇵🇫' => 'gendera: Polinesia Prancis',
    '🇵🇬' => 'gendera: Papua Nugini',
    '🇵🇭' => 'gendera: Pilipina',
    '🇵🇰' => 'gendera: Pakistan',
    '🇵🇱' => 'gendera: Polen',
    '🇵🇲' => 'gendera: Saint Pièr lan Mikuélon',
    '🇵🇳' => 'gendera: Kapuloan Pitcairn',
    '🇵🇷' => 'gendera: Puèrto Riko',
    '🇵🇸' => 'gendera: Tlatah Palèstina',
    '🇵🇹' => 'gendera: Portugal',
    '🇵🇼' => 'gendera: Palau',
    '🇵🇾' => 'gendera: Paraguay',
    '🇶🇦' => 'gendera: Katar',
    '🇷🇪' => 'gendera: Réunion',
    '🇷🇴' => 'gendera: Ruméni',
    '🇷🇸' => 'gendera: Sèrbi',
    '🇷🇺' => 'gendera: Rusia',
    '🇷🇼' => 'gendera: Rwanda',
    '🇸🇦' => 'gendera: Arab Saudi',
    '🇸🇧' => 'gendera: Kapuloan Suleman',
    '🇸🇨' => 'gendera: Sésèl',
    '🇸🇩' => 'gendera: Sudan',
    '🇸🇪' => 'gendera: Swèdhen',
    '🇸🇬' => 'gendera: Singapura',
    '🇸🇭' => 'gendera: Saint Héléna',
    '🇸🇮' => 'gendera: Slovénia',
    '🇸🇯' => 'gendera: Svalbard lan Jan Mayen',
    '🇸🇰' => 'gendera: Slowak',
    '🇸🇱' => 'gendera: Siéra Léoné',
    '🇸🇲' => 'gendera: San Marino',
    '🇸🇳' => 'gendera: Sénégal',
    '🇸🇴' => 'gendera: Somalia',
    '🇸🇷' => 'gendera: Suriname',
    '🇸🇸' => 'gendera: Sudan Kidul',
    '🇸🇹' => 'gendera: Sao Tomé lan Principé',
    '🇸🇻' => 'gendera: Èl Salvador',
    '🇸🇽' => 'gendera: Sint Martén',
    '🇸🇾' => 'gendera: Suriah',
    '🇸🇿' => 'gendera: Swasiland',
    '🇹🇦' => 'gendera: Tristan da Cunha',
    '🇹🇨' => 'gendera: Turks lan Kapuloan Kaikos',
    '🇹🇩' => 'gendera: Chad',
    '🇹🇫' => 'gendera: Wilayah Prancis nang Kutub Kidul',
    '🇹🇬' => 'gendera: Togo',
    '🇹🇭' => 'gendera: Tanah Thai',
    '🇹🇯' => 'gendera: Tajikistan',
    '🇹🇰' => 'gendera: Tokelau',
    '🇹🇱' => 'gendera: Timor Leste',
    '🇹🇲' => 'gendera: Turkménistan',
    '🇹🇳' => 'gendera: Tunisia',
    '🇹🇴' => 'gendera: Tonga',
    '🇹🇷' => 'gendera: Turki',
    '🇹🇹' => 'gendera: Trinidad lan Tobago',
    '🇹🇻' => 'gendera: Tuvalu',
    '🇹🇼' => 'gendera: Taiwan',
    '🇹🇿' => 'gendera: Tansania',
    '🇺🇦' => 'gendera: Ukrania',
    '🇺🇬' => 'gendera: Uganda',
    '🇺🇲' => 'gendera: Kapuloan AS Paling Njaba',
    '🇺🇳' => 'gendera: Pasarékatan Bangsa-Bangsa',
    '🇺🇸' => 'gendera: Amérika Sarékat',
    '🇺🇾' => 'gendera: Uruguay',
    '🇺🇿' => 'gendera: Usbèkistan',
    '🇻🇦' => 'gendera: Kutha Vatikan',
    '🇻🇨' => 'gendera: Saint Vinsen lan Grénadin',
    '🇻🇪' => 'gendera: Vénésuéla',
    '🇻🇬' => 'gendera: Kapuloan Virgin Britania',
    '🇻🇮' => 'gendera: Kapuloan Virgin Amérika',
    '🇻🇳' => 'gendera: Viètnam',
    '🇻🇺' => 'gendera: Vanuatu',
    '🇼🇫' => 'gendera: Wallis lan Futuna',
    '🇼🇸' => 'gendera: Samoa',
    '🇽🇰' => 'gendera: Kosovo',
    '🇾🇪' => 'gendera: Yaman',
    '🇾🇹' => 'gendera: Mayotte',
    '🇿🇦' => 'gendera: Afrika Kidul',
    '🇿🇲' => 'gendera: Sambia',
    '🇿🇼' => 'gendera: Simbabwe',
    '🏻' => 'kulit putih',
    '🏼' => 'kulit putih langsep',
    '🏽' => 'kulit kuning',
    '🏾' => 'kulit sawo mateng',
    '🏿' => 'kulit ireng',
    '😀' => 'rai ngguyu',
    '😃' => 'rai ngguyu matane mblalak',
    '😄' => 'rai ngguyu nganti merem-merem',
    '😁' => 'rai ngguyu mecengis nganti merem',
    '😆' => 'rai ngguyu nganti matane dhipet',
    '😅' => 'rai ngguyu nganti kringet tumetes',
    '🤣' => 'ngguyu ngakak nganti glintingan ing jogan',
    '😂' => 'rai ngguyu nganti luhen saking bungahe',
    '🙂' => 'rai mesem',
    '🙃' => 'rai kuwalik',
    '🫠' => 'rai lebur',
    '😉' => 'rai ngedhèpi',
    '😊' => 'rai mesem matane merem',
    '😇' => 'rai mesem mawa tandha santo ing sirahe',
    '🥰' => 'rai mesem mawa ati-ati manguncup',
    '😍' => 'rai mesem matane metu atine',
    '🤩' => 'ketiban lintang',
    '😘' => 'rai nyebul sun',
    '😗' => 'rai ngambung',
    '☺' => 'rai lagi mesem',
    '😚' => 'rai ngambung karo matane merem',
    '😙' => 'rai ngambung matane merem bungah',
    '🥲' => 'rai mesem nanging mripat luhen',
    '😋' => 'rai themal-themel mangan',
    '😛' => 'rai melet',
    '😜' => 'rai kedhep karo melet',
    '🤪' => 'rai merat-merot',
    '😝' => 'rai melet matane ndhipet',
    '🤑' => 'rai mata dhuwiten',
    '🤗' => 'rai nyikep',
    '🤭' => 'rai mawa tangan nutupi cangkem',
    '🫢' => 'rai matane melek lan tangan nutupi cangkem',
    '🫣' => 'rai mawa mripat ngintip',
    '🤫' => 'rai ngaba-aba akon meneng',
    '🤔' => 'rai mikir',
    '🫡' => 'rai hormat',
    '🤐' => 'rai sing leregan lambene ditutup',
    '🤨' => 'rai alise siji kaangkat',
    '😐' => 'rai anteng',
    '😑' => 'rai tanpa ekspresi',
    '😶' => 'rai tanpa cangkem',
    '🫥' => 'rai garis strip',
    '😏' => 'rai mesem ngenyek',
    '😒' => 'rai wegah ngguyu',
    '🙄' => 'rai matane mlerok',
    '😬' => 'rai mringis mbatek',
    '🤥' => 'rai ngapusi',
    '🫨' => 'rai goyang-goyang',
    '😌' => 'rai lega',
    '😔' => 'rai sedhih anggone mikir',
    '😪' => 'rai ngantuk',
    '🤤' => 'rai ileren',
    '😴' => 'rai turu',
    '🫩' => 'mata pendul',
    '😷' => 'rai nganggo masker dhokter',
    '🤒' => 'rai ngemut termometer',
    '🤕' => 'rai sirahe dibebet',
    '🤢' => 'rai ngrasa muleg-muleg',
    '🤮' => 'rai mutah-mutah',
    '🤧' => 'rai wahing',
    '🥵' => 'rai panas',
    '🥶' => 'rai katisen',
    '🥴' => 'rai mendem',
    '😵' => 'rai mumet',
    '🤯' => 'rai ndhase njeblug',
    '🤠' => 'rai nganggo topi koboi',
    '🥳' => 'rai pista',
    '🥸' => 'rai disamarno',
    '😎' => 'rai mesem nganggo kacamata ireng',
    '🤓' => 'rai kutu buku',
    '🧐' => 'rai nganggo kacamata lensa tunggal',
    '😕' => 'rai bingung',
    '🫤' => 'rai lambene menjeb',
    '😟' => 'rai kuwatir',
    '🙁' => 'rai susah',
    '☹' => 'rai nelangsa',
    '😮' => 'rai mlongo',
    '😯' => 'rai dumadakan meneng',
    '😲' => 'rai gumun',
    '😳' => 'rai isin',
    '🫪' => 'rai semrawut',
    '🥺' => 'rai ngarep-arep welas',
    '🥹' => 'rai mbrambangi',
    '😦' => 'rai sedhih karo mlongo',
    '😧' => 'rai kaget lan kuciwa',
    '😨' => 'rai keweden',
    '😰' => 'rai kuwatir nganti kringet tumetes',
    '😥' => 'rai sedhih nanging lega',
    '😢' => 'rai nangis',
    '😭' => 'rai nangis kejer',
    '😱' => 'rai mbengok keweden',
    '😖' => 'rai prasa bingung ora karuan',
    '😣' => 'rai prasa wis ora kuat maneh',
    '😞' => 'rai kuciwa',
    '😓' => 'rai prasa wis kesel nganti kringet tumetes',
    '😩' => 'rai sayah',
    '😫' => 'rai kesel',
    '🥱' => 'rai angop',
    '😤' => 'rai sing irunge ngebul',
    '😡' => 'rai mbesengut',
    '😠' => 'rai nesu',
    '🤬' => 'rai mawa simbol pisuhan ing cangkeme',
    '😈' => 'rai mesem karo metu sungune',
    '👿' => 'rai nesu karo metu sungune',
    '💀' => 'jrangkong',
    '☠' => 'jrangkong karo balung timpuk',
    '💩' => 'tai seunthuk',
    '🤡' => 'rai badhut',
    '👹' => 'buta ogre',
    '👺' => 'buta goblin',
    '👻' => 'pocongan',
    '👽' => 'wujud alien',
    '👾' => 'monster alien',
    '🤖' => 'wujud robot',
    '😺' => 'kucing ngguyu',
    '😸' => 'kucing ngguyu nganti merem-merem',
    '😹' => 'kucing ngguyu nganti luhen',
    '😻' => 'kucing mesem matane metu atine',
    '😼' => 'kucing mesem ngece',
    '😽' => 'kucing ngambung',
    '🙀' => 'kucing sayah',
    '😿' => 'kucing nangis',
    '😾' => 'kucing mbesengut',
    '🙈' => 'munyuk aja ndelengake sing ala',
    '🙉' => 'munyuk aja ngrungokake sing ala',
    '🙊' => 'munyuk aja omong sing ala',
    '💌' => 'layang katresnan',
    '💘' => 'ati katuncep panah',
    '💝' => 'ati ditaleni pita',
    '💖' => 'ati kinclong-kinclong',
    '💗' => 'ati nggembung',
    '💓' => 'ati dheg-dhegan',
    '💞' => 'ati mubeng-mubeng',
    '💕' => 'ati loro',
    '💟' => 'dhekorasi ati',
    '❣' => 'tandha penthung wujude ati',
    '💔' => 'lara ati',
    '❤' => 'ati abang',
    '🩷' => 'ati jambon',
    '🧡' => 'ati kunir',
    '💛' => 'ati kuning',
    '💚' => 'ati ijo',
    '💙' => 'ati biru',
    '🩵' => 'ati biru enom',
    '💜' => 'ati wungu',
    '🤎' => 'ati soklat',
    '🖤' => 'ati ireng',
    '🩶' => 'ati awu-awu',
    '🤍' => 'ati putih',
    '💋' => 'tandha ambung',
    '💯' => 'biji satus',
    '💢' => 'simbol nesu',
    '🫯' => 'gelut muntel',
    '💥' => 'tabrakan',
    '💫' => 'ngelu',
    '💦' => 'tesing kringet',
    '💨' => 'nggeblas',
    '🕳' => 'bolongan',
    '💬' => 'balon omongan',
    '🗨' => 'balon omongan sisih kiwa',
    '🗯' => 'balon nesu sisih tengen',
    '💭' => 'balon pikiran',
    '💤' => 'zzzz',
    '👋' => 'tangan ngawe-awe',
    '🤚' => 'tangan diangkat nuduhake gegere bae',
    '🖐' => 'tangan sing driji-drijine megar',
    '✋' => 'tangan diangkat',
    '🖖' => 'ngurmat cara bangsa vulcan',
    '🫱' => 'tangan tengen',
    '🫲' => 'tangan kiwo',
    '🫳' => 'tangan madep ngisor',
    '🫴' => 'tangan madep nduwur',
    '🫷' => 'tangan sisih kiwa nyurung',
    '🫸' => 'tangan sisih tengen nyurung',
    '👌' => 'tangan nuduhake tandha OK',
    '🤌' => 'driji digatukake',
    '🤏' => 'tangan njiwit',
    '✌' => 'tangan nuduhake tandha kamenangan',
    '🤞' => 'driji loro tetalenan',
    '🫰' => 'jempol karo driji panuduh tetalenan',
    '🤟' => 'tangan nuduhake tandha tresna sliramu',
    '🤘' => 'tandha sungu',
    '🤙' => 'tangan nuduhake tandha telpuna aku',
    '👈' => 'geger tangan nuding ngiwa',
    '👉' => 'geger tangan nuding nengen',
    '👆' => 'geger tangan nuding ndhuwur',
    '🖕' => 'driji tengah',
    '👇' => 'geger tangan nuding ngisor',
    '☝' => 'driji panuduh ngacung',
    '🫵' => 'driji panuduh seng ngewasi',
    '👍' => 'jempol ngacung',
    '👎' => 'jempol ngacung mudhun',
    '✊' => 'ngacungake kepel',
    '👊' => 'kepel mara',
    '🤛' => 'kepel katon saka sisih kiwa',
    '🤜' => 'kepel katon saka sisih tengen',
    '👏' => 'tangan keplok-keplok',
    '🙌' => 'tangan loro diangkat',
    '🫶' => 'tangan loro mbentuk ati',
    '👐' => 'tangan loro mlumah',
    '🤲' => 'tangan loro mandho nadhah amin',
    '🤝' => 'salaman',
    '🙏' => 'tangan nyembah',
    '✍' => 'tangan nulis',
    '💅' => 'cet kuku',
    '🤳' => 'foto selfi',
    '💪' => 'otot lengen mlenthung',
    '🦾' => 'lengen mekanis',
    '🦿' => 'sikil mekanis',
    '🦵' => 'sikil',
    '🦶' => 'tlapakan sikil',
    '👂' => 'kuping',
    '🦻' => 'kuping sarwa piranti pangrungon',
    '👃' => 'irung',
    '🧠' => 'utek',
    '🫀' => 'jantung',
    '🫁' => 'paru',
    '🦷' => 'untu',
    '🦴' => 'balung',
    '👀' => 'mata sakloron',
    '👁' => 'mata',
    '👅' => 'ilat',
    '👄' => 'cangkem',
    '🫦' => 'nyokot lambe',
    '👶' => 'bayi',
    '🧒' => 'bocah',
    '👦' => 'bocah lanang',
    '👧' => 'bocah wadon',
    '🧑' => 'wong',
    '👱' => 'wong: rambute pirang',
    '👨' => 'wong lanang',
    '🧔' => 'wong: jenggot',
    '👩' => 'wong wadon',
    '🧓' => 'wong tuwa',
    '👴' => 'wong tuwa lanang',
    '👵' => 'wong wadon tuwa',
    '🙍' => 'wong sedhih',
    '🙎' => 'wong mbesengut',
    '🙅' => 'wong ngisaratake AJA',
    '🙆' => 'wong ngisaratake OK',
    '💁' => 'wong tangane anyangga',
    '🙋' => 'wong ngacungake tangan',
    '🧏' => 'wong budheg',
    '🙇' => 'wong mbungkuk ngurmati',
    '🤦' => 'wong anutup raine mawa dlamakan',
    '🤷' => 'wong angangkat pundhak',
    '👮' => 'pulisi',
    '🕵' => 'dhetektif',
    '💂' => 'panjaga',
    '🥷' => 'ninja',
    '👷' => 'buruh bangunan',
    '🫅' => 'wong nganggo makutha',
    '🤴' => 'pangeran',
    '👸' => 'putri',
    '👳' => 'wong serbanan',
    '👲' => 'wong lanang nganggo kethu Cina',
    '🧕' => 'wong wadon jilbaban',
    '🤵' => 'wong anganggo jas tuksedo',
    '👰' => 'wong nganggo kudhung manten',
    '🤰' => 'wong wadon ngandhut',
    '🫃' => 'wong lanang meteng',
    '🫄' => 'wong meteng',
    '🤱' => 'menthili',
    '👼' => 'malaékat bayi',
    '🎅' => 'Sinter Klas',
    '🤶' => 'Ibu Klas',
    '🦸' => 'satriya mandraguna',
    '🦹' => 'mungsuh digdaya',
    '🧙' => 'wong winasis',
    '🧚' => 'bangsa dewi',
    '🧛' => 'vampir',
    '🧜' => 'duyung',
    '🧝' => 'peri',
    '🧞' => 'bangsa jim',
    '🧟' => 'zombi',
    '🧌' => 'troll',
    '🫈' => 'makhluk wulunen',
    '💆' => 'wong dipijeti',
    '💇' => 'wong lagi dikethok rambute',
    '🚶' => 'wong mlaku',
    '🧍' => 'wong ngadeg',
    '🧎' => 'wong timpuh',
    '🏃' => 'wong mlayu',
    '💃' => 'wong wadon njoget',
    '🕺' => 'wong lanang njoget',
    '🕴' => 'wong lanang jas-jasan ora napak',
    '👯' => 'wong nganggo kuping terwelu',
    '🧖' => 'wong ing kamar kebak sumub',
    '🧗' => 'wong manjad',
    '🤺' => 'wong main anggar',
    '🏇' => 'balapan jaran',
    '⛷' => 'pemain ski',
    '🏂' => 'pemain slancar salju',
    '🏌' => 'wong main golf',
    '🏄' => 'wong slancar',
    '🚣' => 'wong ndhayung',
    '🏊' => 'wong nglangi',
    '⛹' => 'wong mentulake bal',
    '🏋' => 'wong ngangkat barbel',
    '🚴' => 'wong numpak pit',
    '🚵' => 'wong numpak sepedha gunung',
    '🤸' => 'wong engkang',
    '🤼' => 'wong gulat',
    '🤽' => 'wong main polo banyu',
    '🤾' => 'wong main bal tangan',
    '🤹' => 'wong main akrobat bal',
    '🧘' => 'wong njagong sila',
    '🛀' => 'wong adus kungkum',
    '🛌' => 'wong turu',
    '👭' => 'wong wadon loro gandhengan tangan',
    '👫' => 'wong lanang lan wadon gandhengan',
    '👬' => 'wong lanang loro gandhengan tangan',
    '💏' => 'ambung',
    '💑' => 'pasangan lan tandha ati',
    '🗣' => 'sirah omong',
    '👤' => 'bayangan patung sirah tekan dhadha',
    '👥' => 'bayangan patung sirah tekan dhadha loro',
    '🫂' => 'wong rangkulan',
    '👪' => 'kluwarga',
    '👣' => 'tipak sikil',
    '🫆' => 'tipak driji',
    '🦰' => 'rambut abang',
    '🦱' => 'rambut brintik',
    '🦳' => 'rambut putih',
    '🦲' => 'buthak',
    '🐵' => 'rai munyuk',
    '🐒' => 'munyuk',
    '🦍' => 'gorila',
    '🦧' => 'orang utan',
    '🐶' => 'rai asu',
    '🐕' => 'asu',
    '🦮' => 'asu pemandhu',
    '🐩' => 'pudel',
    '🐺' => 'asu ajag',
    '🦊' => 'rubah',
    '🦝' => 'rakun',
    '🐱' => 'rai kucing',
    '🐈' => 'kucing',
    '🦁' => 'singa',
    '🐯' => 'rai macan',
    '🐅' => 'macan',
    '🐆' => 'macan tutul',
    '🐴' => 'rai jaran',
    '🫎' => 'menjangan',
    '🫏' => 'kuldi',
    '🐎' => 'jaran',
    '🦄' => 'unicorn',
    '🦓' => 'zebra',
    '🦌' => 'kidang',
    '🦬' => 'bison',
    '🐮' => 'rai sapi wadon',
    '🐂' => 'sapi lanang',
    '🐃' => 'kebo',
    '🐄' => 'sapi wadon',
    '🐷' => 'rai babi',
    '🐖' => 'babi',
    '🐗' => 'celeng',
    '🐽' => 'irung babi',
    '🐏' => 'wedhus gembel lanang',
    '🐑' => 'wedhus gembel wadon',
    '🐐' => 'wedhus',
    '🐪' => 'onta',
    '🐫' => 'onta punuk loro',
    '🦙' => 'llama',
    '🦒' => 'jerapah',
    '🐘' => 'gajah',
    '🦣' => 'mamot',
    '🦏' => 'badhak',
    '🦛' => 'kuda nil',
    '🐭' => 'rai tikus',
    '🐁' => 'tikus',
    '🐀' => 'tikus got',
    '🐹' => 'hamster',
    '🐰' => 'rai terwelu',
    '🐇' => 'terwelu',
    '🐿' => 'bajing',
    '🦫' => 'singing',
    '🦔' => 'landhak',
    '🦇' => 'kalong',
    '🐻' => 'beruang',
    '🐨' => 'koala',
    '🐼' => 'panda',
    '🦥' => 'sloth',
    '🦦' => 'berang-berang',
    '🦨' => 'sigung',
    '🦘' => 'kanguru',
    '🦡' => 'luwak',
    '🐾' => 'tapak cakar',
    '🦃' => 'kalkun',
    '🐔' => 'pitik',
    '🐓' => 'pitik jago',
    '🐣' => 'kuthuk netes',
    '🐤' => 'kuthuk',
    '🐥' => 'kuthuk madhep ngarep',
    '🐦' => 'manuk',
    '🐧' => 'penguin',
    '🕊' => 'dara',
    '🦅' => 'elang',
    '🦆' => 'bebek',
    '🦢' => 'banyak',
    '🦉' => 'guwek',
    '🦤' => 'manuk dodo',
    '🪶' => 'wulu',
    '🦩' => 'flamingo',
    '🦚' => 'merak',
    '🦜' => 'beo',
    '🪽' => 'swiwi',
    '🪿' => 'menthog',
    '🐸' => 'kodhok',
    '🐊' => 'baya',
    '🐢' => 'kura-kura',
    '🦎' => 'cecak',
    '🐍' => 'ula',
    '🐲' => 'rai naga',
    '🐉' => 'naga',
    '🦕' => 'sauropod',
    '🦖' => 'T-Rex',
    '🐳' => 'paus nyembur',
    '🐋' => 'paus',
    '🐬' => 'lumba-lumba',
    '🫍' => 'orca',
    '🦭' => 'asu laut',
    '🐟' => 'iwak',
    '🐠' => 'iwak tropis',
    '🐡' => 'iwak buntal',
    '🦈' => 'hiu',
    '🐙' => 'gurita',
    '🐚' => 'keong spiral',
    '🪸' => 'koral',
    '🪼' => 'ubur-ubur',
    '🦀' => 'rajungan',
    '🦞' => 'lopster',
    '🦐' => 'urang',
    '🦑' => 'sotong',
    '🦪' => 'tiram',
    '🐌' => 'bekicot',
    '🦋' => 'kupu',
    '🐛' => 'uler',
    '🐜' => 'semut',
    '🐝' => 'lebah madu',
    '🪲' => 'kumbang',
    '🐞' => 'kepik',
    '🦗' => 'jangkrik',
    '🪳' => 'coro',
    '🕷' => 'angga-angga',
    '🕸' => 'jaring angga-angga',
    '🦂' => 'kalajengking',
    '🦟' => 'lemut',
    '🪰' => 'laler',
    '🪱' => 'cacing',
    '🦠' => 'mikroba',
    '💐' => 'buket',
    '🌸' => 'sakura',
    '💮' => 'kembang putih',
    '🪷' => 'teratai',
    '🏵' => 'roseta',
    '🌹' => 'mawar',
    '🥀' => 'kembang layu',
    '🌺' => 'kembang sepatu',
    '🌻' => 'kembang sengenge',
    '🌼' => 'sekar',
    '🌷' => 'tulip',
    '🪻' => 'hyacin',
    '🌱' => 'pembibitan',
    '🪴' => 'tanduran njero adah',
    '🌲' => 'wit cemara',
    '🌳' => 'wit godhonge rontok',
    '🌴' => 'wit kambil',
    '🌵' => 'kaktus',
    '🌾' => 'pari saiket',
    '🌿' => 'jamu',
    '☘' => 'semanggi',
    '🍀' => 'semanggi godhong papat',
    '🍁' => 'godhong mapel',
    '🍂' => 'godhong gogrok',
    '🍃' => 'godhong ngawe-ngawe kena angin',
    '🪹' => 'susuh kosong',
    '🪺' => 'susuh ono endoke',
    '🍄' => 'jamur',
    '🪾' => 'wit tanpa godhong',
    '🍇' => 'anggur',
    '🍈' => 'melon',
    '🍉' => 'semangka',
    '🍊' => 'jeruk keprok',
    '🍋' => 'jeruk lemon',
    '🍌' => 'gedhang',
    '🍍' => 'nanas',
    '🥭' => 'pelem',
    '🍎' => 'apel abang',
    '🍏' => 'apel ijo',
    '🍐' => 'pir',
    '🍑' => 'persik',
    '🍒' => 'ceri',
    '🍓' => 'stroberi',
    '🫐' => 'beri biru',
    '🥝' => 'woh kiwi',
    '🍅' => 'tomat',
    '🫒' => 'zaitun',
    '🥥' => 'kambil',
    '🥑' => 'avokad',
    '🍆' => 'terong',
    '🥔' => 'kenthang',
    '🥕' => 'wortel',
    '🌽' => 'tongkol jagung',
    '🌶' => 'lombok',
    '🫑' => 'paprika',
    '🥒' => 'timun',
    '🥬' => 'selada ijo',
    '🥦' => 'brokoli',
    '🧄' => 'bawang putih',
    '🧅' => 'bawang bombai',
    '🥜' => 'kacang brol',
    '🫘' => 'buncis',
    '🌰' => 'kenari',
    '🫚' => 'jahe',
    '🫛' => 'kacang polong',
    '🫜' => 'sayuran oyot',
    '🍞' => 'roti',
    '🥐' => 'kroasang',
    '🥖' => 'roti baget',
    '🫓' => 'roti warata',
    '🥨' => 'pretsel',
    '🥯' => 'roti bagel',
    '🥞' => 'panekuk',
    '🧇' => 'wafel',
    '🧀' => 'keju sairis',
    '🍖' => 'iwak daging sabalunge',
    '🍗' => 'pupu sempol',
    '🥩' => 'daging sairis',
    '🥓' => 'bakon',
    '🍔' => 'burger',
    '🍟' => 'balok kenthang goreng',
    '🍕' => 'pizza keju',
    '🌭' => 'roti sosis',
    '🥪' => 'sendwich',
    '🌮' => 'tako',
    '🌯' => 'burito',
    '🫔' => 'tamale',
    '🥙' => 'roti pita gulung',
    '🧆' => 'bakwan falafel',
    '🥚' => 'ndhog',
    '🍳' => 'masak',
    '🥘' => 'jangan sawajan cethek',
    '🍲' => 'jangan sapanci',
    '🫕' => 'pondue',
    '🥣' => 'mangkok karo sendhok',
    '🥗' => 'urap-urap sayur',
    '🍿' => 'brondong jagung',
    '🧈' => 'mertega',
    '🧂' => 'uyah',
    '🥫' => 'dhaharan kalengan',
    '🍱' => 'sakothak bento',
    '🍘' => 'rengginan',
    '🍙' => 'themlek sega',
    '🍚' => 'sega mateng',
    '🍛' => 'sega kare',
    '🍜' => 'mangkok kemepul',
    '🍝' => 'bakmi sepageti',
    '🍠' => 'tela pendhem panggang',
    '🍢' => 'sate oden',
    '🍣' => 'susi',
    '🍤' => 'urang goreng',
    '🍥' => 'bakso iwak Jepang',
    '🥮' => 'kuwih bulan',
    '🍡' => 'sate dango',
    '🥟' => 'siomay kukus',
    '🥠' => 'roti begja',
    '🥡' => 'kothak bungkus',
    '🍦' => 'es krim salju',
    '🍧' => 'es puter',
    '🍨' => 'es krim',
    '🍩' => 'donat',
    '🍪' => 'biskwit',
    '🎂' => 'roti ambal taun',
    '🍰' => 'kuwih lapis',
    '🧁' => 'kuwih mangkok',
    '🥧' => 'pai',
    '🍫' => 'sapapan soklat',
    '🍬' => 'permen',
    '🍭' => 'permen loli',
    '🍮' => 'ager-ager hungkwe',
    '🍯' => 'satoples madu',
    '🍼' => 'botol kempong',
    '🥛' => 'sagelas susu',
    '☕' => 'wedang panas',
    '🫖' => 'ceret',
    '🍵' => 'cangkir teh tanpa kuping',
    '🍶' => 'sabotol sake',
    '🍾' => 'botol mencelat subale',
    '🍷' => 'gelas anggur',
    '🍸' => 'gelas koktail',
    '🍹' => 'unjukan cara tropis',
    '🍺' => 'gelas bir',
    '🍻' => 'gelas-gelas bir ditutulake',
    '🥂' => 'gelas-gelas ditutulke',
    '🥃' => 'gelas sloki',
    '🫗' => 'nyuntak banyu',
    '🥤' => 'gelas mawa sedhotan',
    '🧋' => 'teh kocok',
    '🧃' => 'wedang kothakan',
    '🧉' => 'teh mate',
    '🧊' => 'es batu',
    '🥢' => 'sumpit',
    '🍽' => 'sendhok garpu sapiringe',
    '🍴' => 'garpu lan peso',
    '🥄' => 'sendhok',
    '🔪' => 'peso dhapur',
    '🫙' => 'wadhah',
    '🏺' => 'guci kuping loro',
    '🌍' => 'globe sing nuduhake benua Eropa-Afrika',
    '🌎' => 'globe sing nuduhake benua Amerika',
    '🌏' => 'globe sing nuduhake benua Asia-Australia',
    '🌐' => 'globe mawa garis meridian',
    '🗺' => 'peta donya',
    '🗾' => 'peta Jepang',
    '🧭' => 'kompas',
    '🏔' => 'gunung punthuke katutup salju',
    '⛰' => 'gunung',
    '🛘' => 'longsor',
    '🌋' => 'gunung geni',
    '🗻' => 'gunung fuji',
    '🏕' => 'kemah',
    '🏖' => 'pasisir karo payung tumancep',
    '🏜' => 'ara-ara',
    '🏝' => 'pulo ara-ara',
    '🏞' => 'taman nasional',
    '🏟' => 'stadion',
    '🏛' => 'wewangunan kuna',
    '🏗' => 'konstruksi wewangunan',
    '🧱' => 'bata',
    '🪨' => 'watu',
    '🪵' => 'kayu',
    '🛖' => 'pondhok',
    '🏘' => 'omah-omah',
    '🏚' => 'omah bobrok',
    '🏠' => 'omah',
    '🏡' => 'omah ana kebone',
    '🏢' => 'wewangunan kantor',
    '🏣' => 'kantor pos ing Jepang',
    '🏤' => 'kantor pos ing Eropa',
    '🏥' => 'griya sakit',
    '🏦' => 'wewangunan bank',
    '🏨' => 'wewangunan hotel',
    '🏩' => 'hotel sewan miturut jam',
    '🏪' => 'minimarket',
    '🏫' => 'sekolahan',
    '🏬' => 'supermarket',
    '🏭' => 'pabrik',
    '🏯' => 'puri Jepang',
    '🏰' => 'puri',
    '💒' => 'ngantenan',
    '🗼' => 'menara Tokyo',
    '🗽' => 'Patung Liberti',
    '⛪' => 'greja',
    '🕌' => 'mesjid',
    '🛕' => 'pura Hindu',
    '🕍' => 'sinagoga',
    '⛩' => 'kuil Shinto',
    '🕋' => 'Kakbah',
    '⛲' => 'banyu muncrat',
    '⛺' => 'tendha',
    '🌁' => 'katutup pedhut',
    '🌃' => 'bengi ana lintang',
    '🏙' => 'gedhung-gedhung anyakar mega',
    '🌄' => 'srengenge mlethek sadhuwuring kendheng',
    '🌅' => 'srengenge mlethek',
    '🌆' => 'gedhung-gedhung wayah sandhekala',
    '🌇' => 'srengenge mudhun',
    '🌉' => 'kreteg ing wayah bengi',
    '♨' => 'tuk banyu panas',
    '🎠' => 'jaran komidhi puter',
    '🛝' => 'plosotan',
    '🎡' => 'jinantra',
    '🎢' => 'kreta sluncur',
    '💈' => 'panandha kiyose tukang cukur',
    '🎪' => 'tendha sirkus',
    '🚂' => 'lokomotip',
    '🚃' => 'bis jalur ril',
    '🚄' => 'sepur rikat',
    '🚅' => 'sepur pelor',
    '🚆' => 'sepur',
    '🚇' => 'sepur metro',
    '🚈' => 'sepur LRT',
    '🚉' => 'setasiun',
    '🚊' => 'trem',
    '🚝' => 'monoril',
    '🚞' => 'jalur sepur nggunung',
    '🚋' => 'montor trem',
    '🚌' => 'bis',
    '🚍' => 'bis katon mara',
    '🚎' => 'bis troli',
    '🚐' => 'bis cilik',
    '🚑' => 'ambulan',
    '🚒' => 'blamwir',
    '🚓' => 'montor pulisi',
    '🚔' => 'montor pulisi katon mara',
    '🚕' => 'taksi',
    '🚖' => 'taksi mara',
    '🚗' => 'montor otomatis',
    '🚘' => 'montor otomatis mara',
    '🚙' => 'tetumpakan srana ulah raga',
    '🛻' => 'trek pikep',
    '🚚' => 'prahoto pangiriman',
    '🚛' => 'lori gandheng',
    '🚜' => 'traktor',
    '🏎' => 'montor balap',
    '🏍' => 'pit montor',
    '🛵' => 'pespa',
    '🦽' => 'kursi rodha manual',
    '🦼' => 'kursi rodha mesin',
    '🛺' => 'bemo',
    '🚲' => 'sepedha',
    '🛴' => 'otopet jejek',
    '🛹' => 'papan skate',
    '🛼' => 'sepatu rodha',
    '🚏' => 'halte bis',
    '🛣' => 'dalan gedhe',
    '🛤' => 'jalur ril',
    '🛢' => 'drim lenga',
    '⛽' => 'pompa bensin',
    '🛞' => 'rodha',
    '🚨' => 'lampu montor pulisi',
    '🚥' => 'lampu bangjo turu',
    '🚦' => 'lampu bangjo ngadeg',
    '🛑' => 'tandha setop',
    '🚧' => 'konstruksi',
    '⚓' => 'jangkar',
    '🛟' => 'ban pelampung',
    '⛵' => 'prau layar',
    '🛶' => 'kano',
    '🚤' => 'kapal rikat',
    '🛳' => 'kapal panumpang',
    '⛴' => 'kapal feri',
    '🛥' => 'kapal motor',
    '🚢' => 'kapal gedhe',
    '✈' => 'montor mabur',
    '🛩' => 'montor mabur cilik',
    '🛫' => 'montor mabur mangkat',
    '🛬' => 'montor mabur teka',
    '🪂' => 'terjun payung',
    '💺' => 'lungguhan',
    '🚁' => 'helikopter',
    '🚟' => 'jalur ril suspensi',
    '🚠' => 'gantole',
    '🚡' => 'jalur trem nggantung',
    '🛰' => 'satelit',
    '🚀' => 'roket',
    '🛸' => 'piring mabur',
    '🛎' => 'bel leladen',
    '🧳' => 'koper',
    '⌛' => 'jam pasir tuntas',
    '⏳' => 'jam pasir isih mlaku',
    '⌚' => 'erloji',
    '⏰' => 'jam weker',
    '⏱' => 'pangatur wektu',
    '⏲' => 'jam pangatur wektu',
    '🕰' => 'jam dhudhuk kuna',
    '🕛' => 'jam rolas',
    '🕧' => 'jam setengah siji',
    '🕐' => 'jam siji',
    '🕜' => 'jam setengah loro',
    '🕑' => 'jam loro',
    '🕝' => 'jam setengah telu',
    '🕒' => 'jam telu',
    '🕞' => 'jam setengah papat',
    '🕓' => 'jam papat',
    '🕟' => 'jam setengah lima',
    '🕔' => 'jam lima',
    '🕠' => 'jam setengah enem',
    '🕕' => 'jam enem',
    '🕡' => 'jam setengah pitu',
    '🕖' => 'jam pitu',
    '🕢' => 'jam setengah wolu',
    '🕗' => 'jam wolu',
    '🕣' => 'jam setengah sanga',
    '🕘' => 'jam sanga',
    '🕤' => 'jam setengah sepuluh',
    '🕙' => 'jam sepuluh',
    '🕥' => 'jam setengah sewelas',
    '🕚' => 'jam sewelas',
    '🕦' => 'jam setengah rolas',
    '🌑' => 'bulan kawitan',
    '🌒' => 'bulan tanggal sepisan',
    '🌓' => 'bulan separo',
    '🌔' => 'bulan separo luwih',
    '🌕' => 'purnama sidi',
    '🌖' => 'bulan ilang seprapat',
    '🌗' => 'bulan peteng separo',
    '🌘' => 'bulan gari seprapat',
    '🌙' => 'bulan nanggal sepisan',
    '🌚' => 'rai bulan kawitan',
    '🌛' => 'rai bulan separo marep ngiwa',
    '🌜' => 'rai bulan separo marep nengen',
    '🌡' => 'termometer',
    '☀' => 'srengenge',
    '🌝' => 'rai purnama sidi',
    '🌞' => 'srengenge katon raine',
    '🪐' => 'planet anganggo ali-ali',
    '⭐' => 'lintang',
    '🌟' => 'lintang cemlorot',
    '🌠' => 'lintang abuntut',
    '🌌' => 'bima sekti',
    '☁' => 'mega mendhung',
    '⛅' => 'srengenge saburine mega',
    '⛈' => 'mega ngemu bledhek lan udan',
    '🌤' => 'srengenge saburine mega cilik',
    '🌥' => 'srengenge saburine mega gedhe',
    '🌦' => 'srengenge saburine mega ngemu udan',
    '🌧' => 'mega ngemu udan',
    '🌨' => 'mega ngemu salju',
    '🌩' => 'mega ngemu bledhek',
    '🌪' => 'angin puyuh',
    '🌫' => 'pedhut',
    '🌬' => 'rai anyebul angin',
    '🌀' => 'angin siklon',
    '🌈' => 'kluwung',
    '🌂' => 'payung mingkup',
    '☂' => 'payung',
    '☔' => 'payung ketiban udan',
    '⛱' => 'payung tumancep lemah',
    '⚡' => 'tegangan dhuwur',
    '❄' => 'satesing salju',
    '☃' => 'wong-wongan salju',
    '⛄' => 'wong-wongan salju tanpa salju',
    '☄' => 'komet',
    '🔥' => 'geni',
    '💧' => 'tesing',
    '🌊' => 'ombak banyu',
    '🎃' => 'lampion jack-o-lantern',
    '🎄' => 'Uwit Natal',
    '🎆' => 'kembang api',
    '🎇' => 'bang api',
    '🧨' => 'petasan',
    '✨' => 'mbang api',
    '🎈' => 'balon',
    '🎉' => 'hiasan pesta',
    '🎊' => 'balon konfeti',
    '🎋' => 'wit tanabata',
    '🎍' => 'dekorasi pinus',
    '🎎' => 'boneka Jepang',
    '🎏' => 'gendera koinobori',
    '🎐' => 'klinthingan angin',
    '🎑' => 'upacara nyawang mbulan',
    '🧧' => 'ang pao',
    '🎀' => 'pita',
    '🎁' => 'kado dibungkus',
    '🎗' => 'pita pangeling',
    '🎟' => 'tiket mlebu',
    '🎫' => 'tiket',
    '🎖' => 'medali militer',
    '🏆' => 'trofi',
    '🏅' => 'medali olahraga',
    '🥇' => 'medali juara ka-1',
    '🥈' => 'medali juara ka-2',
    '🥉' => 'medali juara ka-3',
    '⚽' => 'bal sepak bola',
    '⚾' => 'bisbol',
    '🥎' => 'sofbol',
    '🏀' => 'bola basket',
    '🏐' => 'voli',
    '🏈' => 'sepak bola amerika',
    '🏉' => 'sepak bola rugby',
    '🎾' => 'tenis',
    '🥏' => 'cakram mabur',
    '🎳' => 'boling',
    '🏏' => 'game kriket',
    '🏑' => 'hoki lapangan',
    '🏒' => 'hoki es',
    '🥍' => 'lacrosse',
    '🏓' => 'ping pong',
    '🏸' => 'badminton',
    '🥊' => 'sarung tangan tinju',
    '🥋' => 'sragam bela diri',
    '🥅' => 'jaring gawang',
    '⛳' => 'gendera golf',
    '⛸' => 'luncur es',
    '🎣' => 'tongkat pancing',
    '🤿' => 'masker nyilem',
    '🎽' => 'kaos mlayu',
    '🎿' => 'ski',
    '🛷' => 'kreta luncur',
    '🥌' => 'watu curling stone',
    '🎯' => 'kena sasaran',
    '🪀' => 'yoyo',
    '🪁' => 'layangan',
    '🔫' => 'bedhil',
    '🎱' => 'pool bal 8',
    '🔮' => 'bal kristal',
    '🪄' => 'tongkat sihir',
    '🎮' => 'game video',
    '🕹' => 'tuas kontrol',
    '🎰' => 'mesin slot',
    '🎲' => 'dhadhu game',
    '🧩' => 'cuwilan teka-teki',
    '🧸' => 'beruang teddy',
    '🪅' => 'pinata',
    '🪩' => 'bal pangilon',
    '🪆' => 'boneka rusia',
    '♠' => 'kertu sekop',
    '♥' => 'kertu ati',
    '♦' => 'kertu berlian',
    '♣' => 'kertu waru',
    '♟' => 'pion',
    '🃏' => 'kertu joker',
    '🀄' => 'naga abang mahyong',
    '🎴' => 'kertu gambar kembang',
    '🎭' => 'seni pagelaran',
    '🖼' => 'gambar nganggo pigura',
    '🎨' => 'palet pelukis',
    '🧵' => 'benang',
    '🪡' => 'jarum jait',
    '🧶' => 'bolah',
    '🪢' => 'simpul',
    '👓' => 'kacamata',
    '🕶' => 'kacamata ireng',
    '🥽' => 'gogel',
    '🥼' => 'jas lab',
    '🦺' => 'rompi keslametan',
    '👔' => 'dasi',
    '👕' => 'kaos lengen cendhak',
    '👖' => 'jins',
    '🧣' => 'skarf',
    '🧤' => 'sarung tangan',
    '🧥' => 'mantel',
    '🧦' => 'kaos sikil',
    '👗' => 'rok',
    '👘' => 'kimono',
    '🥻' => 'sari',
    '🩱' => 'klambi nglangi terusan',
    '🩲' => 'kathok njero',
    '🩳' => 'kathok cendhak',
    '👙' => 'bikini',
    '👚' => 'sandhangan wong wadon',
    '🪭' => 'kipas lipat',
    '👛' => 'tas',
    '👜' => 'tas tangan',
    '👝' => 'tas jinjing',
    '🛍' => 'tas blanja',
    '🎒' => 'ransel',
    '🩴' => 'sandal japit',
    '👞' => 'sepatu lanang',
    '👟' => 'sepatu mlayu',
    '🥾' => 'sepatu bot hiking',
    '🥿' => 'sepatu trepes',
    '👠' => 'sepatu hak dhuwur',
    '👡' => 'sandhal wadon',
    '🩰' => 'sepatu balet',
    '👢' => 'sepatu bot wadon',
    '🪮' => 'jungkat',
    '👑' => 'makutha',
    '👒' => 'topi wadon',
    '🎩' => 'topi dhuwur',
    '🎓' => 'topi wisuda',
    '🧢' => 'topi pet',
    '🪖' => 'helm militer',
    '⛑' => 'helm tim SAR',
    '📿' => 'tesbih',
    '💄' => 'lipstik',
    '💍' => 'ali-ali',
    '💎' => 'permata',
    '🔇' => 'speaker bisu',
    '🔈' => 'volume lirih speaker',
    '🔉' => 'volume medium speaker',
    '🔊' => 'volume banter speaker',
    '📢' => 'speaker sero',
    '📣' => 'megapon',
    '📯' => 'trompet pos',
    '🔔' => 'lonceng',
    '🔕' => 'lonceng kacorek',
    '🎼' => 'notasi musik',
    '🎵' => 'tangga nada musik',
    '🎶' => 'tangga nada',
    '🎙' => 'mikropon studio',
    '🎚' => 'panggeser tingkat',
    '🎛' => 'kenop kontrol',
    '🎤' => 'mikropon',
    '🎧' => 'headphone',
    '📻' => 'radio',
    '🎷' => 'saksofon',
    '🎺' => 'trompet',
    '🪊' => 'trombon',
    '🪗' => 'akordion',
    '🎸' => 'gitar',
    '🎹' => 'kibor musik',
    '🎻' => 'biola',
    '🪕' => 'gitar banjo',
    '🥁' => 'dram',
    '🪘' => 'kendhang',
    '🪇' => 'marakas',
    '🪈' => 'suling',
    '🪉' => 'harpa',
    '📱' => 'telepon seluler',
    '📲' => 'telepon seluler nganggo panah',
    '☎' => 'telepon',
    '📞' => 'gagang telpon',
    '📟' => 'penyeranta',
    '📠' => 'mesin faks',
    '🔋' => 'baterai',
    '🪫' => 'baterai arep entek',
    '🔌' => 'colokan listrik',
    '💻' => 'komputer laptop',
    '🖥' => 'komputer desktop',
    '🖨' => 'printer',
    '⌨' => 'keyboard',
    '🖱' => 'mouse komputer',
    '🖲' => 'trakbal',
    '💽' => 'cakram komputer',
    '💾' => 'disket flopi',
    '💿' => 'cakram optikal',
    '📀' => 'cakram dvd',
    '🧮' => 'sempoa',
    '🎥' => 'kamera film',
    '🎞' => 'klise film',
    '📽' => 'proyektor film',
    '🎬' => 'papan aba-aba adhegan',
    '📺' => 'televisi',
    '📷' => 'kamera',
    '📸' => 'kamera mawa lampu jepret',
    '📹' => 'kamera vidio',
    '📼' => 'kaset vidio',
    '🔍' => 'suryakantha minger ngiwa',
    '🔎' => 'suryakantha minger nengen',
    '🕯' => 'lilin',
    '💡' => 'bohlam',
    '🔦' => 'senter',
    '🏮' => 'lampion kertas abang',
    '🪔' => 'lampu diyan',
    '📔' => 'notebook wadhahe motif apik',
    '📕' => 'tutup buku',
    '📖' => 'mbukak buku',
    '📗' => 'buku ijo',
    '📘' => 'buku biru',
    '📙' => 'buku kunir',
    '📚' => 'buku-buku',
    '📓' => 'buku cathetan',
    '📒' => 'buku besar',
    '📃' => 'salembar kertas nglunthung',
    '📜' => 'gulungan',
    '📄' => 'lembaran kertas katon ngarep',
    '📰' => 'koran',
    '🗞' => 'koran digulung',
    '📑' => 'tetenger',
    '🔖' => 'tenger',
    '🏷' => 'label tenger',
    '🪙' => 'koin',
    '💰' => 'kanthong dhuwit',
    '🪎' => 'pethi rajabrana',
    '💴' => 'dhuwit kertas yen',
    '💵' => 'dhuwit kertas dolar',
    '💶' => 'dhuwit kertas euro',
    '💷' => 'dhuwit kertas ponsterling',
    '💸' => 'dhuwit nduwe swiwi',
    '💳' => 'kertu kredhit',
    '🧾' => 'struk tetukon',
    '💹' => 'grafik mata uang yen mundhak',
    '✉' => 'amplop',
    '📧' => 'email',
    '📨' => 'amplop layang teka',
    '📩' => 'amplop mawa panah',
    '📤' => 'wadhah layang kakirim',
    '📥' => 'kothak layang teka',
    '📦' => 'paket',
    '📫' => 'kothak surat nutup genderane ngadeg',
    '📪' => 'kothak surat nutup genderane mudhun',
    '📬' => 'kothak surat menga genderane ngadeg',
    '📭' => 'kothak surat menga genderane mudhun',
    '📮' => 'kothak pos',
    '🗳' => 'kothak pemilu mawa layang swara',
    '✏' => 'potlot',
    '✒' => 'dom mangsi ireng',
    '🖋' => 'pen mangsi',
    '🖊' => 'pena',
    '🖌' => 'kuwas kanggo nglukis',
    '🖍' => 'krayon',
    '📝' => 'cathetan cilik',
    '💼' => 'tas koper',
    '📁' => 'map berkas',
    '📂' => 'map berkas mbukak',
    '🗂' => 'pambagi indeks kertu',
    '📅' => 'tanggalan',
    '📆' => 'tanggalan suwek',
    '🗒' => 'buku cathetan spiral',
    '🗓' => 'tanggalan spiral',
    '📇' => 'indeks kertu',
    '📈' => 'grafik mundhak',
    '📉' => 'grafik mudhun',
    '📊' => 'grafik balok',
    '📋' => 'papan lemek',
    '📌' => 'pines',
    '📍' => 'pines bendhul',
    '📎' => 'klip kertas',
    '🖇' => 'klip kertas karonce',
    '📏' => 'garisan jejeg',
    '📐' => 'garisan pesagi telu',
    '✂' => 'gunting',
    '🗃' => 'kothak berkas kertu',
    '🗄' => 'slorogan berkas',
    '🗑' => 'kranjang sampah',
    '🔒' => 'gembok ngunci',
    '🔓' => 'gembok mbukak',
    '🔏' => 'gembok nutup karo pen',
    '🔐' => 'gembok nutup karo kunci',
    '🔑' => 'kunci',
    '🗝' => 'kunci kuna',
    '🔨' => 'pukul',
    '🪓' => 'kampak',
    '⛏' => 'pipril',
    '⚒' => 'pukul lan pipril',
    '🛠' => 'pukul lan kunci pas',
    '🗡' => 'pedhang endhek',
    '⚔' => 'pedhang loro timpuk',
    '💣' => 'bom',
    '🪃' => 'bumerang',
    '🏹' => 'gendewa lan panah',
    '🛡' => 'tameng',
    '🪚' => 'graji kayu',
    '🔧' => 'kunci pas',
    '🪛' => 'obeng',
    '🔩' => 'mur lan baut',
    '⚙' => 'gir',
    '🗜' => 'cathok',
    '⚖' => 'timbangan',
    '🦯' => 'teken',
    '🔗' => 'sambungan rante',
    '⛓' => 'rante',
    '🪝' => 'pancing',
    '🧰' => 'kothak bekakas',
    '🧲' => 'wesi magnet',
    '🪜' => 'ondo',
    '🪏' => 'sekop',
    '⚗' => 'pranti suling alembik',
    '🧪' => 'tabung reaksi',
    '🧫' => 'cawan petri',
    '🧬' => 'adn',
    '🔬' => 'mikroskop',
    '🔭' => 'teleskop',
    '📡' => 'antena satelit',
    '💉' => 'siring',
    '🩸' => 'satetes getih',
    '💊' => 'pil',
    '🩹' => 'plester',
    '🩼' => 'kruk',
    '🩺' => 'stetoskop',
    '🩻' => 'sinar x',
    '🚪' => 'lawang',
    '🛗' => 'ondo mlaku',
    '🪞' => 'kaca pangilon',
    '🪟' => 'cendela',
    '🛏' => 'amben',
    '🛋' => 'sofa lan lampu',
    '🪑' => 'kursi',
    '🚽' => 'kakus',
    '🪠' => 'panyedot kakus',
    '🚿' => 'pancuran',
    '🛁' => 'bak kungkum',
    '🪤' => 'panjebak tikus',
    '🪒' => 'peso cukur',
    '🧴' => 'botol losion',
    '🧷' => 'peniti',
    '🧹' => 'sapu',
    '🧺' => 'kranjang',
    '🧻' => 'tisu gulung',
    '🪣' => 'ember',
    '🧼' => 'sabun',
    '🫧' => 'umpluk',
    '🪥' => 'sikat untu',
    '🧽' => 'sepon',
    '🧯' => 'pambasmi geni',
    '🛒' => 'troli blanja',
    '🚬' => 'rokok',
    '⚰' => 'pethi mati',
    '🪦' => 'kijeng',
    '⚱' => 'guci awu',
    '🧿' => 'jimat nazar',
    '🪬' => 'khamsa',
    '🗿' => 'patung moai',
    '🪧' => 'plakat',
    '🪪' => 'kertu identitas',
    '🏧' => 'tandha ATM',
    '🚮' => 'tandha mbuwang rereged ing wadhahe',
    '🚰' => 'banyu kran kena diombe',
    '♿' => 'tandha kursi rodha',
    '🚹' => 'pakiwan lanang',
    '🚺' => 'pakiwan wadon',
    '🚻' => 'pakiwan',
    '🚼' => 'tandha bayi',
    '🚾' => 'wese',
    '🛂' => 'priksa paspor',
    '🛃' => 'pabean',
    '🛄' => 'njupuk koper',
    '🛅' => 'koper ditinggal',
    '⚠' => 'pepenget',
    '🚸' => 'sabrangan bocah sekolah',
    '⛔' => 'aja mlebu',
    '🚫' => 'ora kena',
    '🚳' => 'pit ora kena liwat',
    '🚭' => 'ora kena ngrokok',
    '🚯' => 'ora kena mbuwang sampah',
    '🚱' => 'banyu kran ora kena diombe',
    '🚷' => 'wong mlaku ora kena liwat',
    '📵' => 'ora kena nguripke hp',
    '🔞' => 'sing umur sangisore 18 ora kena',
    '☢' => 'radhioaktip',
    '☣' => 'bebaya hayati',
    '⬆' => 'panah munggah',
    '↗' => 'panah munggah-nengen',
    '➡' => 'panah nengen',
    '↘' => 'panah mudhun-nengen',
    '⬇' => 'panah mudhun',
    '↙' => 'panah mudhun-ngiwa',
    '⬅' => 'panah ngiwa',
    '↖' => 'panah munggah-ngiwa',
    '↕' => 'panah munggah-mudhun',
    '↔' => 'panah ngiwa-nengen',
    '↩' => 'panah nengen menggok ngiwa',
    '↪' => 'panah ngiwa menggok nengen',
    '⤴' => 'panah nengen menggok munggah',
    '⤵' => 'panah nengen menggok mudhun',
    '🔃' => 'panah ngadeg arahe padha ubenge jam',
    '🔄' => 'tombol panah arahe walikan ubenge jam',
    '🔙' => 'panah MBALIK',
    '🔚' => 'panah MENTOK',
    '🔛' => 'panah ON!',
    '🔜' => 'panah SOON',
    '🔝' => 'panah TOP',
    '🛐' => 'papan sembahyang',
    '⚛' => 'tandha atom',
    '🕉' => 'Om',
    '✡' => 'lintang Dawud',
    '☸' => 'rodha darma',
    '☯' => 'yinyang',
    '✝' => 'salib latin',
    '☦' => 'salib ortodoks',
    '☪' => 'lintang lan mbulan anyaran',
    '☮' => 'tandha perdhamean',
    '🕎' => 'menorah lilin',
    '🔯' => 'lintang mata enem mawa titik tengah',
    '🪯' => 'tandha kanda',
    '♈' => 'Lintang Aries',
    '♉' => 'Lintang Taurus',
    '♊' => 'Lintang Gemini',
    '♋' => 'Lintang Cancer',
    '♌' => 'Lintang Leo',
    '♍' => 'Lintang Virgo',
    '♎' => 'Lintang Libra',
    '♏' => 'Lintang Scorpio',
    '♐' => 'Lintang Sagittarius',
    '♑' => 'Lintang Capricorn',
    '♒' => 'Lintang Aquarius',
    '♓' => 'Lintang Pisces',
    '⛎' => 'Lintang Ophiuchus',
    '🔀' => 'tombol ngacak lagu',
    '🔁' => 'tombol baleni',
    '🔂' => 'tombol baleni sepisan',
    '▶' => 'tombol main',
    '⏩' => 'tombol maju cepet',
    '⏭' => 'tombol lagu sabanjure',
    '⏯' => 'tombol main utawa mandheg',
    '◀' => 'tombol mbalik',
    '⏪' => 'tombol mbalik cepet',
    '⏮' => 'tombol lagu pungkasan',
    '🔼' => 'tombol munggah',
    '⏫' => 'tombol munggah cepet',
    '🔽' => 'tombol mudhun',
    '⏬' => 'tombol mudhun cepet',
    '⏸' => 'tombol mandheg',
    '⏹' => 'tombol mati',
    '⏺' => 'tombol rekam',
    '⏏' => 'tombol metu',
    '🎦' => 'film',
    '🔅' => 'tombol lamat-lamat',
    '🔆' => 'tombol padhang',
    '📶' => 'balok sinyal',
    '🛜' => 'nirkabel',
    '📳' => 'modhe kedher',
    '📴' => 'hp mati',
    '♀' => 'tandha wanita',
    '♂' => 'tandha priya',
    '⚧' => 'tandha wariya',
    '✖' => 'tandha ping-pingan',
    '➕' => 'tambah',
    '➖' => 'kurang',
    '➗' => 'tandha para',
    '🟰' => 'tandha padha karo',
    '♾' => 'tanpa wates',
    '‼' => 'tandha penthung dhobel',
    '⁉' => 'tandha penthung lan pitakon',
    '❓' => 'tandha pitakon abang',
    '❔' => 'tandha pitakon putih',
    '❕' => 'tandha penthung putih',
    '❗' => 'tandha penthung abang',
    '〰' => 'setrip ngeluk',
    '💱' => 'rega ijol mata uang',
    '💲' => 'tandha dolar kandel',
    '⚕' => 'tandha medhis',
    '♻' => 'tandha dhaur ulang',
    '⚜' => 'lambang fleur-de-lis [kembang Lili]',
    '🔱' => 'lambang trisula',
    '📛' => 'emblem jeneng',
    '🔰' => 'tandha wong anyaran cara Jepang',
    '⭕' => 'bunderan abang bolong',
    '✅' => 'tombol tenger centhang',
    '☑' => 'kothak centhang ana centhange',
    '✔' => 'tenger centhang',
    '❌' => 'tenger ping',
    '❎' => 'tombol tenger ping',
    '➰' => 'garis cunthel',
    '➿' => 'garis cunthel dhobel',
    '〽' => 'tandha rikala sindhen wiwit nyanyi',
    '✳' => 'asterisk kembang wolu',
    '✴' => 'lintang mata wolu',
    '❇' => 'kelip-kelip',
    '™' => 'merek dagang',
    '🫟' => 'cipratan',
    '🔠' => 'lebokake aksara latin gedhe',
    '🔡' => 'lebokake aksara latin cilik',
    '🔢' => 'lebokake angka',
    '🔣' => 'lebokake simbol',
    '🔤' => 'lebokake aksara latin',
    '🅰' => 'tombol A [golongane getih]',
    '🆎' => 'tombol AB [golongane getih]',
    '🅱' => 'tombol B [golongane getih]',
    '🆑' => 'tombol CL',
    '🆒' => 'tombol COOL',
    '🆓' => 'tombol FREE',
    'ℹ' => 'informasi',
    '🆔' => 'tombol ID',
    'Ⓜ' => 'M dibunderi',
    '🆕' => 'tombol NEW',
    '🆖' => 'tombol NG',
    '🅾' => 'tombol O [golongane getih]',
    '🆗' => 'tombol OK',
    '🅿' => 'tombol P',
    '🆘' => 'tombol SOS',
    '🆙' => 'tombol UP!',
    '🆚' => 'tombol VS',
    '🈁' => 'tombol Jepang "ing kene"',
    '🈂' => 'tombol Jepang "beya laden"',
    '🈷' => 'tombol Jepang "gunggung sesasen"',
    '🈶' => 'tombol Jepang "ora gratis"',
    '🈯' => 'tombol Jepang "wis dipesen"',
    '🉐' => 'tombol Jepang "rega murah"',
    '🈹' => 'tombol Jepang "diskon"',
    '🈚' => 'tombol Jepang "gratis"',
    '🈲' => 'tombol Jepang "larangan"',
    '🉑' => 'tombol Jepang "oleh"',
    '🈸' => 'tombol Jepang "aplikasi"',
    '🈴' => 'tombol Jepang "munggah kelas"',
    '🈳' => 'tombol Jepang "lowongan"',
    '㊗' => 'tombol Jepang "sugeng"',
    '㊙' => 'tombol Jepang "rahasia"',
    '🈺' => 'tombol Jepang "kantor bukak"',
    '🈵' => 'tombol Jepang "lowongan kosong"',
    '🔴' => 'bunderan abang',
    '🟠' => 'bunderan kunir',
    '🟡' => 'bunderan kuning',
    '🟢' => 'bunderan ijo',
    '🔵' => 'bunderan biru',
    '🟣' => 'bunderan wungu',
    '🟤' => 'bunderan soklat',
    '⚫' => 'bunderan ireng',
    '⚪' => 'bunderan putih',
    '🟥' => 'kothak abang',
    '🟧' => 'kothak kunir',
    '🟨' => 'kothak kuning',
    '🟩' => 'kothak ijo',
    '🟦' => 'kothak biru',
    '🟪' => 'kothak wungu',
    '🟫' => 'kothak soklat',
    '⬛' => 'kothak gedhe ireng',
    '⬜' => 'kothak gedhe putih',
    '◼' => 'kothak sedhengan ireng',
    '◻' => 'kothak sedhengan putih',
    '◾' => 'kothak cilik-sedhengan ireng',
    '◽' => 'kothak cilik-sedhengan putih',
    '▪' => 'kothak cilik ireng',
    '▫' => 'kothak cilik putih',
    '🔶' => 'kupatan gedhe kunir',
    '🔷' => 'kupatan gedhe biru',
    '🔸' => 'kupatan cilik kunir',
    '🔹' => 'kupatan cilik biru',
    '🔺' => 'pesagi telu abang pucuke marep ndhuwur',
    '🔻' => 'pesagi telu abang pucuke marep ngisor',
    '💠' => 'kupatan mawa titik ing tengah',
    '🔘' => 'tombol radio',
    '🔳' => 'tombol kothak putih',
    '🔲' => 'tombol kothak ireng',
    '🏁' => 'gendera kothak-kothak',
    '🚩' => 'gendera segi telu',
    '🎌' => 'gendera loro ditempuk',
    '🏴' => 'gendera ireng',
    '🏳' => 'gendera putih',
];
